
#line 1 "zscanner/scanner.rl"
/*  Copyright (C) 2011 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "zscanner/scanner.h"

#include <stdint.h>			// uint32_t
#include <stdlib.h>			// calloc
#include <stdio.h>			// sprintf
#include <libgen.h>			// dirname
#include <stdbool.h>			// bool
#include <math.h>			// pow
#include <string.h>			// strdup
#include <sys/types.h>			// (OpenBSD)
#include <sys/socket.h>			// AF_INET (BSD)
#include <netinet/in.h>			// in_addr (BSD)
#include <arpa/inet.h>			// inet_pton

#include "common/errcode.h"		// error codes
#include "common/descriptor.h"		// KNOT_RRTYPE_A
#include "zscanner/file_loader.h"	// file_loader
#include "zscanner/scanner_functions.h"	// Base64

/*! \brief Shorthand for setting warning data. */
#define SCANNER_WARNING(code) { s->error_code = code; }
/*! \brief Shorthand for setting error data. */
#define SCANNER_ERROR(code)   { s->error_code = code; s->stop = true; }

/*!
 * \brief Writes record type number to r_data.
 *
 * \param type		Type number.
 * \param rdata_tail	Position where to write type number to.
 */
static inline void type_num(const uint16_t type, uint8_t **rdata_tail)
{
	*((uint16_t *)*rdata_tail) = htons(type);
	*rdata_tail += 2;
}

/*!
 * \brief Sets bit to bitmap window.
 *
 * \param type		Type number.
 * \param s		Scanner context.
 */
static inline void window_add_bit(const uint16_t type, scanner_t *s) {
	uint8_t win      = type / 256;
	uint8_t bit_pos  = type % 256;
	uint8_t byte_pos = bit_pos / 8;

	((s->windows[win]).bitmap)[byte_pos] |= 128 >> (bit_pos % 8);

	if ((s->windows[win]).length < byte_pos + 1) {
		(s->windows[win]).length = byte_pos + 1;
	}

	if (s->last_window < win) {
		s->last_window = win;
	}
}

// Include scanner file (in Ragel).

#line 80 "zscanner/scanner.c"
static const short _zone_scanner_actions[] = {
	0, 1, 0, 1, 1, 1, 2, 1, 
	3, 1, 4, 1, 6, 1, 9, 1, 
	10, 1, 11, 1, 13, 1, 14, 1, 
	16, 1, 19, 1, 20, 1, 22, 1, 
	23, 1, 26, 1, 27, 1, 28, 1, 
	30, 1, 31, 1, 40, 1, 41, 1, 
	42, 1, 44, 1, 46, 1, 47, 1, 
	48, 1, 49, 1, 51, 1, 53, 1, 
	54, 1, 56, 1, 58, 1, 60, 1, 
	61, 1, 65, 1, 66, 1, 69, 1, 
	70, 1, 72, 1, 73, 1, 76, 1, 
	78, 1, 79, 1, 80, 1, 81, 1, 
	82, 1, 83, 1, 84, 1, 85, 1, 
	87, 1, 89, 1, 91, 1, 95, 1, 
	96, 1, 100, 1, 101, 1, 105, 1, 
	106, 1, 107, 1, 108, 1, 109, 1, 
	110, 1, 111, 1, 112, 1, 113, 1, 
	114, 1, 115, 1, 116, 1, 117, 1, 
	118, 1, 120, 1, 121, 1, 122, 1, 
	123, 1, 148, 1, 149, 1, 150, 1, 
	151, 1, 152, 1, 153, 1, 154, 1, 
	155, 1, 156, 1, 157, 1, 158, 1, 
	159, 1, 160, 1, 161, 1, 162, 1, 
	163, 1, 164, 1, 165, 1, 166, 1, 
	167, 1, 168, 1, 169, 1, 170, 1, 
	171, 1, 172, 1, 173, 1, 174, 1, 
	175, 1, 176, 1, 177, 1, 178, 1, 
	179, 1, 180, 1, 181, 1, 182, 1, 
	183, 1, 184, 1, 185, 1, 186, 1, 
	187, 1, 188, 1, 189, 1, 190, 1, 
	191, 1, 192, 1, 193, 1, 194, 1, 
	195, 1, 196, 1, 197, 1, 198, 1, 
	199, 1, 200, 1, 201, 1, 202, 1, 
	203, 1, 204, 1, 205, 1, 206, 1, 
	207, 1, 208, 1, 209, 1, 210, 1, 
	211, 1, 212, 1, 213, 1, 214, 1, 
	215, 1, 216, 1, 217, 1, 219, 1, 
	221, 1, 222, 1, 223, 1, 224, 1, 
	231, 1, 232, 1, 237, 1, 239, 1, 
	242, 1, 243, 1, 244, 1, 245, 1, 
	247, 1, 248, 1, 249, 1, 250, 1, 
	252, 2, 0, 44, 2, 1, 0, 2, 
	1, 27, 2, 1, 248, 2, 1, 287, 
	2, 2, 27, 2, 2, 250, 2, 3, 
	27, 2, 3, 250, 2, 4, 65, 2, 
	4, 69, 2, 5, 6, 2, 9, 10, 
	2, 12, 13, 2, 14, 10, 2, 14, 
	11, 2, 15, 20, 2, 15, 69, 2, 
	15, 76, 2, 16, 0, 2, 16, 2, 
	2, 16, 3, 2, 16, 75, 2, 18, 
	0, 2, 19, 9, 2, 22, 63, 2, 
	22, 100, 2, 22, 111, 2, 23, 0, 
	2, 23, 1, 2, 23, 2, 2, 23, 
	3, 2, 23, 24, 2, 23, 220, 2, 
	25, 21, 2, 26, 1, 2, 26, 2, 
	2, 26, 3, 2, 26, 85, 2, 26, 
	250, 2, 27, 1, 2, 27, 2, 2, 
	27, 3, 2, 28, 4, 2, 28, 247, 
	2, 28, 252, 2, 29, 21, 2, 30, 
	0, 2, 30, 1, 2, 30, 2, 2, 
	30, 3, 2, 30, 24, 2, 31, 36, 
	2, 32, 31, 2, 33, 65, 2, 33, 
	237, 2, 33, 247, 2, 33, 252, 2, 
	37, 225, 2, 37, 226, 2, 37, 227, 
	2, 37, 228, 2, 37, 229, 2, 37, 
	230, 2, 40, 0, 2, 40, 1, 2, 
	40, 2, 2, 40, 3, 2, 41, 0, 
	2, 41, 1, 2, 41, 2, 2, 41, 
	3, 2, 41, 24, 2, 42, 0, 2, 
	42, 1, 2, 42, 2, 2, 42, 3, 
	2, 43, 246, 2, 44, 1, 2, 44, 
	2, 2, 44, 3, 2, 51, 2, 2, 
	51, 3, 2, 51, 42, 2, 51, 85, 
	2, 52, 53, 2, 54, 1, 2, 54, 
	2, 2, 54, 3, 2, 55, 247, 2, 
	56, 0, 2, 57, 58, 2, 59, 60, 
	2, 61, 0, 2, 61, 56, 2, 67, 
	19, 2, 71, 63, 2, 72, 2, 2, 
	72, 3, 2, 73, 4, 2, 74, 19, 
	2, 76, 4, 2, 80, 1, 2, 80, 
	27, 2, 82, 83, 2, 84, 1, 2, 
	84, 2, 2, 84, 3, 2, 85, 1, 
	2, 85, 2, 2, 85, 3, 2, 85, 
	250, 2, 86, 87, 2, 88, 247, 2, 
	89, 90, 2, 91, 92, 2, 93, 94, 
	2, 93, 95, 2, 93, 96, 2, 97, 
	98, 2, 99, 247, 2, 102, 247, 2, 
	103, 0, 2, 119, 247, 2, 121, 0, 
	2, 122, 0, 2, 123, 0, 2, 124, 
	0, 2, 125, 0, 2, 126, 0, 2, 
	127, 0, 2, 128, 0, 2, 129, 0, 
	2, 130, 0, 2, 131, 0, 2, 132, 
	0, 2, 133, 0, 2, 134, 0, 2, 
	135, 0, 2, 136, 0, 2, 137, 0, 
	2, 138, 0, 2, 139, 0, 2, 140, 
	0, 2, 141, 0, 2, 142, 0, 2, 
	143, 0, 2, 144, 0, 2, 145, 247, 
	2, 146, 247, 2, 147, 247, 2, 148, 
	1, 2, 148, 2, 2, 148, 3, 2, 
	149, 1, 2, 149, 2, 2, 149, 3, 
	2, 150, 1, 2, 150, 2, 2, 150, 
	3, 2, 151, 1, 2, 151, 2, 2, 
	151, 3, 2, 152, 1, 2, 152, 2, 
	2, 152, 3, 2, 153, 1, 2, 153, 
	2, 2, 153, 3, 2, 154, 1, 2, 
	154, 2, 2, 154, 3, 2, 155, 1, 
	2, 155, 2, 2, 155, 3, 2, 156, 
	1, 2, 156, 2, 2, 156, 3, 2, 
	157, 1, 2, 157, 2, 2, 157, 3, 
	2, 158, 1, 2, 158, 2, 2, 158, 
	3, 2, 159, 1, 2, 159, 2, 2, 
	159, 3, 2, 160, 1, 2, 160, 2, 
	2, 160, 3, 2, 161, 1, 2, 161, 
	2, 2, 161, 3, 2, 162, 1, 2, 
	162, 2, 2, 162, 3, 2, 163, 1, 
	2, 163, 2, 2, 163, 3, 2, 164, 
	1, 2, 164, 2, 2, 164, 3, 2, 
	165, 1, 2, 165, 2, 2, 165, 3, 
	2, 166, 1, 2, 166, 2, 2, 166, 
	3, 2, 167, 1, 2, 167, 2, 2, 
	167, 3, 2, 168, 1, 2, 168, 2, 
	2, 168, 3, 2, 169, 1, 2, 169, 
	2, 2, 169, 3, 2, 170, 1, 2, 
	170, 2, 2, 170, 3, 2, 171, 1, 
	2, 171, 2, 2, 171, 3, 2, 172, 
	1, 2, 172, 2, 2, 172, 3, 2, 
	173, 1, 2, 173, 2, 2, 173, 3, 
	2, 174, 1, 2, 174, 2, 2, 174, 
	3, 2, 175, 1, 2, 175, 2, 2, 
	175, 3, 2, 176, 1, 2, 176, 2, 
	2, 176, 3, 2, 177, 1, 2, 177, 
	2, 2, 177, 3, 2, 178, 1, 2, 
	178, 2, 2, 178, 3, 2, 179, 1, 
	2, 179, 2, 2, 179, 3, 2, 180, 
	1, 2, 180, 2, 2, 180, 3, 2, 
	181, 1, 2, 181, 2, 2, 181, 3, 
	2, 182, 1, 2, 182, 2, 2, 182, 
	3, 2, 183, 1, 2, 183, 2, 2, 
	183, 3, 2, 184, 1, 2, 184, 2, 
	2, 184, 3, 2, 185, 1, 2, 185, 
	2, 2, 185, 3, 2, 186, 1, 2, 
	186, 2, 2, 186, 3, 2, 187, 1, 
	2, 187, 2, 2, 187, 3, 2, 188, 
	1, 2, 188, 2, 2, 188, 3, 2, 
	189, 1, 2, 189, 2, 2, 189, 3, 
	2, 190, 1, 2, 190, 2, 2, 190, 
	3, 2, 191, 1, 2, 191, 2, 2, 
	191, 3, 2, 192, 1, 2, 192, 2, 
	2, 192, 3, 2, 193, 1, 2, 193, 
	2, 2, 193, 3, 2, 194, 1, 2, 
	194, 2, 2, 194, 3, 2, 195, 1, 
	2, 195, 2, 2, 195, 3, 2, 196, 
	1, 2, 196, 2, 2, 196, 3, 2, 
	197, 1, 2, 197, 2, 2, 197, 3, 
	2, 198, 1, 2, 198, 2, 2, 198, 
	3, 2, 199, 1, 2, 199, 2, 2, 
	199, 3, 2, 200, 1, 2, 200, 2, 
	2, 200, 3, 2, 201, 1, 2, 201, 
	2, 2, 201, 3, 2, 202, 1, 2, 
	202, 2, 2, 202, 3, 2, 203, 1, 
	2, 203, 2, 2, 203, 3, 2, 204, 
	1, 2, 204, 2, 2, 204, 3, 2, 
	205, 1, 2, 205, 2, 2, 205, 3, 
	2, 206, 1, 2, 206, 2, 2, 206, 
	3, 2, 207, 1, 2, 207, 2, 2, 
	207, 3, 2, 208, 1, 2, 208, 2, 
	2, 208, 3, 2, 209, 1, 2, 209, 
	2, 2, 209, 3, 2, 210, 1, 2, 
	210, 2, 2, 210, 3, 2, 211, 1, 
	2, 211, 2, 2, 211, 3, 2, 212, 
	1, 2, 212, 2, 2, 212, 3, 2, 
	213, 1, 2, 213, 2, 2, 213, 3, 
	2, 214, 1, 2, 214, 2, 2, 214, 
	3, 2, 215, 1, 2, 215, 2, 2, 
	215, 3, 2, 216, 1, 2, 216, 2, 
	2, 216, 3, 2, 217, 1, 2, 217, 
	2, 2, 217, 3, 2, 218, 0, 2, 
	221, 1, 2, 221, 2, 2, 221, 3, 
	2, 222, 1, 2, 222, 2, 2, 222, 
	3, 2, 223, 1, 2, 223, 2, 2, 
	223, 3, 2, 224, 1, 2, 224, 2, 
	2, 224, 3, 2, 231, 1, 2, 231, 
	2, 2, 231, 3, 2, 232, 1, 2, 
	232, 2, 2, 232, 3, 2, 235, 0, 
	2, 236, 247, 2, 238, 100, 2, 247, 
	4, 2, 248, 1, 2, 248, 27, 2, 
	250, 2, 2, 250, 3, 2, 251, 248, 
	2, 252, 4, 2, 252, 247, 2, 253, 
	246, 2, 254, 246, 2, 255, 246, 2, 
	256, 246, 2, 257, 246, 2, 258, 246, 
	2, 259, 246, 2, 260, 246, 2, 261, 
	246, 2, 262, 246, 2, 263, 246, 2, 
	264, 246, 2, 265, 246, 2, 266, 246, 
	2, 267, 246, 2, 268, 246, 2, 269, 
	246, 2, 270, 246, 2, 271, 246, 2, 
	272, 246, 2, 273, 246, 2, 274, 246, 
	2, 275, 246, 2, 276, 246, 2, 277, 
	246, 2, 278, 246, 2, 279, 246, 2, 
	280, 246, 2, 281, 246, 2, 282, 246, 
	2, 283, 246, 2, 284, 246, 2, 285, 
	246, 2, 286, 246, 2, 287, 1, 3, 
	0, 44, 1, 3, 0, 44, 2, 3, 
	0, 44, 3, 3, 1, 77, 0, 3, 
	1, 103, 0, 3, 1, 218, 0, 3, 
	1, 235, 0, 3, 1, 248, 27, 3, 
	1, 248, 287, 3, 1, 250, 287, 3, 
	1, 287, 27, 3, 7, 1, 8, 3, 
	11, 17, 0, 3, 16, 75, 2, 3, 
	16, 75, 3, 3, 19, 9, 10, 3, 
	23, 1, 0, 3, 23, 24, 1, 3, 
	23, 24, 2, 3, 23, 24, 3, 3, 
	26, 1, 85, 3, 26, 2, 85, 3, 
	26, 2, 250, 3, 26, 3, 85, 3, 
	26, 3, 250, 3, 26, 85, 250, 3, 
	26, 251, 248, 3, 26, 253, 246, 3, 
	28, 81, 4, 3, 28, 247, 4, 3, 
	28, 252, 4, 3, 28, 252, 247, 3, 
	30, 1, 0, 3, 30, 24, 1, 3, 
	30, 24, 2, 3, 30, 24, 3, 3, 
	30, 24, 220, 3, 32, 31, 248, 3, 
	33, 145, 247, 3, 33, 147, 247, 3, 
	33, 252, 4, 3, 33, 252, 247, 3, 
	35, 37, 225, 3, 35, 37, 226, 3, 
	35, 37, 227, 3, 35, 37, 228, 3, 
	35, 37, 229, 3, 35, 37, 230, 3, 
	37, 225, 1, 3, 37, 225, 2, 3, 
	37, 225, 3, 3, 37, 226, 1, 3, 
	37, 226, 2, 3, 37, 226, 3, 3, 
	37, 227, 1, 3, 37, 227, 2, 3, 
	37, 227, 3, 3, 37, 228, 1, 3, 
	37, 228, 2, 3, 37, 228, 3, 3, 
	37, 229, 1, 3, 37, 229, 2, 3, 
	37, 229, 3, 3, 37, 230, 1, 3, 
	37, 230, 2, 3, 37, 230, 3, 3, 
	41, 24, 1, 3, 41, 24, 2, 3, 
	41, 24, 3, 3, 43, 246, 1, 3, 
	43, 246, 2, 3, 43, 246, 3, 3, 
	43, 246, 248, 3, 45, 33, 65, 3, 
	45, 33, 247, 3, 45, 33, 252, 3, 
	50, 32, 31, 3, 51, 42, 0, 3, 
	51, 42, 1, 3, 51, 42, 2, 3, 
	51, 42, 3, 3, 51, 85, 1, 3, 
	51, 85, 2, 3, 51, 85, 3, 3, 
	61, 56, 0, 3, 62, 57, 58, 3, 
	64, 0, 1, 3, 67, 19, 9, 3, 
	68, 0, 1, 3, 74, 19, 9, 3, 
	77, 0, 1, 3, 80, 25, 21, 3, 
	80, 27, 1, 3, 80, 27, 2, 3, 
	80, 27, 3, 3, 82, 25, 21, 3, 
	82, 83, 248, 3, 85, 2, 250, 3, 
	85, 3, 250, 3, 88, 99, 247, 3, 
	88, 145, 247, 3, 89, 90, 0, 3, 
	89, 90, 1, 3, 89, 90, 2, 3, 
	89, 90, 3, 3, 91, 92, 0, 3, 
	91, 92, 1, 3, 91, 92, 2, 3, 
	91, 92, 3, 3, 97, 98, 0, 3, 
	97, 98, 1, 3, 97, 98, 2, 3, 
	97, 98, 3, 3, 102, 104, 237, 3, 
	145, 146, 247, 3, 182, 218, 0, 3, 
	183, 218, 0, 3, 184, 218, 0, 3, 
	185, 218, 0, 3, 186, 218, 0, 3, 
	187, 218, 0, 3, 188, 218, 0, 3, 
	189, 218, 0, 3, 190, 218, 0, 3, 
	191, 218, 0, 3, 192, 218, 0, 3, 
	193, 218, 0, 3, 194, 218, 0, 3, 
	195, 218, 0, 3, 196, 218, 0, 3, 
	197, 218, 0, 3, 198, 218, 0, 3, 
	199, 218, 0, 3, 200, 218, 0, 3, 
	201, 218, 0, 3, 202, 218, 0, 3, 
	203, 218, 0, 3, 204, 218, 0, 3, 
	205, 218, 0, 3, 206, 218, 0, 3, 
	207, 218, 0, 3, 208, 218, 0, 3, 
	209, 218, 0, 3, 210, 218, 0, 3, 
	211, 218, 0, 3, 212, 218, 0, 3, 
	213, 218, 0, 3, 214, 218, 0, 3, 
	215, 218, 0, 3, 216, 218, 0, 3, 
	217, 218, 0, 3, 234, 32, 31, 3, 
	239, 240, 0, 3, 239, 241, 0, 3, 
	247, 4, 81, 3, 248, 25, 21, 3, 
	248, 287, 1, 3, 250, 287, 1, 3, 
	252, 247, 4, 3, 253, 246, 1, 3, 
	253, 246, 2, 3, 253, 246, 3, 3, 
	253, 246, 248, 3, 253, 246, 250, 3, 
	254, 246, 1, 3, 254, 246, 2, 3, 
	254, 246, 3, 3, 254, 246, 248, 3, 
	255, 246, 1, 3, 255, 246, 2, 3, 
	255, 246, 3, 3, 255, 246, 248, 3, 
	256, 246, 1, 3, 256, 246, 2, 3, 
	256, 246, 3, 3, 256, 246, 248, 3, 
	257, 246, 1, 3, 257, 246, 2, 3, 
	257, 246, 3, 3, 257, 246, 248, 3, 
	258, 246, 1, 3, 258, 246, 2, 3, 
	258, 246, 3, 3, 258, 246, 248, 3, 
	259, 246, 1, 3, 259, 246, 2, 3, 
	259, 246, 3, 3, 259, 246, 248, 3, 
	260, 246, 1, 3, 260, 246, 2, 3, 
	260, 246, 3, 3, 260, 246, 248, 3, 
	261, 246, 1, 3, 261, 246, 2, 3, 
	261, 246, 3, 3, 261, 246, 248, 3, 
	262, 246, 1, 3, 262, 246, 2, 3, 
	262, 246, 3, 3, 262, 246, 248, 3, 
	263, 246, 1, 3, 263, 246, 2, 3, 
	263, 246, 3, 3, 263, 246, 248, 3, 
	264, 246, 1, 3, 264, 246, 2, 3, 
	264, 246, 3, 3, 264, 246, 248, 3, 
	265, 246, 1, 3, 265, 246, 2, 3, 
	265, 246, 3, 3, 265, 246, 248, 3, 
	266, 246, 1, 3, 266, 246, 2, 3, 
	266, 246, 3, 3, 266, 246, 248, 3, 
	267, 246, 1, 3, 267, 246, 2, 3, 
	267, 246, 3, 3, 267, 246, 248, 3, 
	268, 246, 1, 3, 268, 246, 2, 3, 
	268, 246, 3, 3, 268, 246, 248, 3, 
	269, 246, 1, 3, 269, 246, 2, 3, 
	269, 246, 3, 3, 269, 246, 248, 3, 
	270, 246, 1, 3, 270, 246, 2, 3, 
	270, 246, 3, 3, 270, 246, 248, 3, 
	271, 246, 1, 3, 271, 246, 2, 3, 
	271, 246, 3, 3, 271, 246, 248, 3, 
	272, 246, 1, 3, 272, 246, 2, 3, 
	272, 246, 3, 3, 272, 246, 248, 3, 
	273, 246, 1, 3, 273, 246, 2, 3, 
	273, 246, 3, 3, 273, 246, 248, 3, 
	274, 246, 1, 3, 274, 246, 2, 3, 
	274, 246, 3, 3, 274, 246, 248, 3, 
	275, 246, 1, 3, 275, 246, 2, 3, 
	275, 246, 3, 3, 275, 246, 248, 3, 
	276, 246, 1, 3, 276, 246, 2, 3, 
	276, 246, 3, 3, 276, 246, 248, 3, 
	277, 246, 1, 3, 277, 246, 2, 3, 
	277, 246, 3, 3, 277, 246, 248, 3, 
	278, 246, 1, 3, 278, 246, 2, 3, 
	278, 246, 3, 3, 278, 246, 248, 3, 
	279, 246, 1, 3, 279, 246, 2, 3, 
	279, 246, 3, 3, 279, 246, 248, 3, 
	280, 246, 1, 3, 280, 246, 2, 3, 
	280, 246, 3, 3, 280, 246, 248, 3, 
	281, 246, 1, 3, 281, 246, 2, 3, 
	281, 246, 3, 3, 281, 246, 248, 3, 
	282, 246, 1, 3, 282, 246, 2, 3, 
	282, 246, 3, 3, 282, 246, 248, 3, 
	283, 246, 1, 3, 283, 246, 2, 3, 
	283, 246, 3, 3, 283, 246, 248, 3, 
	284, 246, 1, 3, 284, 246, 2, 3, 
	284, 246, 3, 3, 284, 246, 248, 3, 
	285, 246, 1, 3, 285, 246, 2, 3, 
	285, 246, 3, 3, 285, 246, 248, 3, 
	286, 246, 1, 3, 286, 246, 2, 3, 
	286, 246, 3, 3, 286, 246, 248, 3, 
	287, 1, 27, 4, 5, 7, 1, 8, 
	4, 14, 11, 17, 0, 4, 16, 68, 
	0, 1, 4, 26, 1, 250, 287, 4, 
	26, 1, 251, 248, 4, 26, 1, 253, 
	246, 4, 26, 2, 85, 250, 4, 26, 
	2, 251, 248, 4, 26, 2, 253, 246, 
	4, 26, 3, 85, 250, 4, 26, 3, 
	251, 248, 4, 26, 3, 253, 246, 4, 
	26, 253, 246, 248, 4, 26, 253, 246, 
	250, 4, 28, 33, 252, 4, 4, 28, 
	45, 33, 252, 4, 28, 252, 247, 4, 
	4, 32, 31, 25, 21, 4, 33, 252, 
	247, 4, 4, 35, 32, 31, 36, 4, 
	35, 37, 225, 1, 4, 35, 37, 225, 
	2, 4, 35, 37, 225, 3, 4, 35, 
	37, 226, 1, 4, 35, 37, 226, 2, 
	4, 35, 37, 226, 3, 4, 35, 37, 
	227, 1, 4, 35, 37, 227, 2, 4, 
	35, 37, 227, 3, 4, 35, 37, 228, 
	1, 4, 35, 37, 228, 2, 4, 35, 
	37, 228, 3, 4, 35, 37, 229, 1, 
	4, 35, 37, 229, 2, 4, 35, 37, 
	229, 3, 4, 35, 37, 230, 1, 4, 
	35, 37, 230, 2, 4, 35, 37, 230, 
	3, 4, 37, 227, 235, 0, 4, 37, 
	228, 235, 0, 4, 37, 229, 235, 0, 
	4, 37, 230, 235, 0, 4, 38, 34, 
	32, 31, 4, 39, 34, 32, 31, 4, 
	43, 246, 1, 248, 4, 45, 33, 4, 
	65, 4, 51, 50, 32, 31, 4, 51, 
	64, 0, 1, 4, 67, 19, 9, 10, 
	4, 72, 77, 0, 1, 4, 74, 19, 
	9, 10, 4, 82, 83, 25, 21, 4, 
	85, 1, 250, 287, 4, 88, 145, 146, 
	247, 4, 89, 90, 1, 0, 4, 91, 
	92, 1, 0, 4, 97, 98, 1, 0, 
	4, 182, 1, 218, 0, 4, 183, 1, 
	218, 0, 4, 184, 1, 218, 0, 4, 
	185, 1, 218, 0, 4, 186, 1, 218, 
	0, 4, 187, 1, 218, 0, 4, 188, 
	1, 218, 0, 4, 189, 1, 218, 0, 
	4, 190, 1, 218, 0, 4, 191, 1, 
	218, 0, 4, 192, 1, 218, 0, 4, 
	193, 1, 218, 0, 4, 194, 1, 218, 
	0, 4, 195, 1, 218, 0, 4, 196, 
	1, 218, 0, 4, 197, 1, 218, 0, 
	4, 198, 1, 218, 0, 4, 199, 1, 
	218, 0, 4, 200, 1, 218, 0, 4, 
	201, 1, 218, 0, 4, 202, 1, 218, 
	0, 4, 203, 1, 218, 0, 4, 204, 
	1, 218, 0, 4, 205, 1, 218, 0, 
	4, 206, 1, 218, 0, 4, 207, 1, 
	218, 0, 4, 208, 1, 218, 0, 4, 
	209, 1, 218, 0, 4, 210, 1, 218, 
	0, 4, 211, 1, 218, 0, 4, 212, 
	1, 218, 0, 4, 213, 1, 218, 0, 
	4, 214, 1, 218, 0, 4, 215, 1, 
	218, 0, 4, 216, 1, 218, 0, 4, 
	217, 1, 218, 0, 4, 253, 246, 1, 
	248, 4, 253, 246, 2, 250, 4, 253, 
	246, 3, 250, 4, 253, 246, 250, 248, 
	4, 254, 246, 1, 248, 4, 255, 246, 
	1, 248, 4, 256, 246, 1, 248, 4, 
	257, 246, 1, 248, 4, 258, 246, 1, 
	248, 4, 259, 246, 1, 248, 4, 260, 
	246, 1, 248, 4, 261, 246, 1, 248, 
	4, 262, 246, 1, 248, 4, 263, 246, 
	1, 248, 4, 264, 246, 1, 248, 4, 
	265, 246, 1, 248, 4, 266, 246, 1, 
	248, 4, 267, 246, 1, 248, 4, 268, 
	246, 1, 248, 4, 269, 246, 1, 248, 
	4, 270, 246, 1, 248, 4, 271, 246, 
	1, 248, 4, 272, 246, 1, 248, 4, 
	273, 246, 1, 248, 4, 274, 246, 1, 
	248, 4, 275, 246, 1, 248, 4, 276, 
	246, 1, 248, 4, 277, 246, 1, 248, 
	4, 278, 246, 1, 248, 4, 279, 246, 
	1, 248, 4, 280, 246, 1, 248, 4, 
	281, 246, 1, 248, 4, 282, 246, 1, 
	248, 4, 283, 246, 1, 248, 4, 284, 
	246, 1, 248, 4, 285, 246, 1, 248, 
	4, 286, 246, 1, 248, 5, 16, 75, 
	77, 0, 1, 5, 26, 1, 85, 250, 
	287, 5, 26, 1, 253, 246, 248, 5, 
	26, 2, 253, 246, 250, 5, 26, 3, 
	253, 246, 250, 5, 26, 253, 246, 250, 
	248, 5, 28, 33, 252, 247, 4, 5, 
	32, 31, 248, 25, 21, 5, 35, 37, 
	227, 235, 0, 5, 35, 37, 228, 235, 
	0, 5, 35, 37, 229, 235, 0, 5, 
	35, 37, 230, 235, 0, 5, 37, 227, 
	1, 235, 0, 5, 37, 228, 1, 235, 
	0, 5, 37, 229, 1, 235, 0, 5, 
	37, 230, 1, 235, 0, 5, 45, 33, 
	252, 247, 4, 5, 82, 83, 248, 25, 
	21, 5, 233, 38, 34, 32, 31, 5, 
	253, 246, 1, 250, 287, 6, 26, 1, 
	253, 246, 250, 287, 6, 28, 45, 33, 
	252, 247, 4, 6, 35, 37, 227, 1, 
	235, 0, 6, 35, 37, 228, 1, 235, 
	0, 6, 35, 37, 229, 1, 235, 0, 
	6, 35, 37, 230, 1, 235, 0, 6, 
	253, 246, 1, 250, 248, 287, 6, 253, 
	246, 250, 248, 287, 1, 7, 26, 1, 
	253, 246, 250, 248, 287
};

static const short _zone_scanner_cond_offsets[] = {
	0, 0, 2, 4, 6, 8, 10, 12, 
	14, 14, 14, 16, 19, 21, 24, 26, 
	28, 30, 30, 30, 30, 32, 37, 37, 
	37, 37, 39, 39, 39, 39, 39, 41, 
	41, 41, 41, 43, 43, 43, 43, 45, 
	47, 47, 47, 47, 47, 49, 49, 51, 
	51, 51, 51, 51, 53, 53, 55, 57, 
	57, 57, 57, 57, 57, 57, 57, 59, 
	59, 59, 61, 63, 63, 63, 65, 65, 
	65, 65, 65, 67, 69, 69, 69, 69, 
	69, 71, 73, 73, 75, 77, 77, 77, 
	77, 77, 79, 79, 79, 81, 81, 83, 
	83, 83, 83, 85, 87, 87, 87, 89, 
	89, 91, 91, 93, 93, 93, 93, 95, 
	95, 95, 95, 97, 97, 99, 99, 99, 
	99, 101, 104, 106, 106, 108, 110, 112, 
	114, 114, 116, 119, 119, 119, 119, 119, 
	119, 119, 119, 119, 119, 121, 123, 126, 
	128, 130, 133, 135, 135, 137, 140, 142, 
	144, 146, 148, 150, 153, 155, 157, 159, 
	161, 163, 165, 167, 169, 171, 173, 175, 
	177, 179, 181, 183, 185, 188, 190, 190, 
	190, 190, 190, 190, 190, 190, 190, 190, 
	192, 194, 196, 199, 201, 203, 205, 207, 
	209, 211, 213, 215, 217, 219, 221, 223, 
	225, 227, 229, 231, 233, 238, 243, 248, 
	248, 248, 250, 250, 250, 250, 252, 252, 
	254, 257, 259, 261, 266, 271, 274, 279, 
	281, 283, 285, 287, 289, 291, 293, 295, 
	297, 299, 301, 303, 305, 308, 311, 313, 
	316, 316, 316, 316, 316, 316, 316, 316, 
	316, 316, 316, 316, 316, 316, 316, 316, 
	316, 316, 316, 317, 317, 317, 317, 317, 
	318, 320, 322, 324, 326, 326, 328, 328, 
	330, 333, 335, 337, 337, 339, 341, 341, 
	341, 341, 341, 341, 341, 343, 346, 348, 
	350, 352, 354, 354, 356, 358, 358, 358, 
	358, 358, 358, 358, 360, 363, 365, 368, 
	371, 371, 371, 371, 371, 373, 376, 376, 
	378, 380, 382, 382, 382, 384, 387, 387, 
	387, 387, 389, 389, 389, 389, 391, 391, 
	391, 391, 391, 393, 393, 393, 393, 395, 
	395, 395, 395, 397, 399, 399, 399, 399, 
	399, 401, 401, 403, 403, 403, 403, 403, 
	405, 405, 405, 405, 405, 405, 405, 405, 
	407, 407, 407, 409, 411, 411, 411, 413, 
	413, 413, 413, 413, 415, 417, 417, 417, 
	417, 417, 419, 421, 421, 423, 425, 425, 
	425, 425, 425, 427, 427, 427, 429, 429, 
	431, 431, 431, 431, 433, 435, 435, 435, 
	437, 437, 439, 439, 441, 441, 441, 441, 
	443, 443, 443, 443, 445, 445, 447, 447, 
	447, 447, 449, 449, 449, 449, 451, 451, 
	453, 455, 457, 459, 461, 461, 463, 466, 
	469, 472, 474, 476, 478, 480, 480, 482, 
	485, 488, 490, 493, 493, 493, 493, 493, 
	493, 493, 493, 493, 493, 493, 493, 493, 
	493, 493, 493, 493, 493, 493, 493, 493, 
	493, 493, 493, 493, 493, 493, 493, 493, 
	493, 493, 493, 493, 493, 493, 493, 493, 
	493, 493, 493, 493, 493, 493, 493, 493, 
	493, 493, 493, 493, 493, 493, 493, 493, 
	493, 493, 493, 493, 493, 493, 493, 493, 
	493, 493, 493, 493, 493, 493, 493, 493, 
	493, 493, 493, 493, 493, 493, 493, 493, 
	493, 493, 493, 493, 493, 493, 493, 493, 
	493, 493, 493, 493, 493, 493, 493, 493, 
	493, 493, 493, 493, 493, 493, 493, 493, 
	493, 493, 493, 493, 493, 493, 493, 493, 
	493, 493, 493, 493, 493, 493, 493, 493, 
	493, 493, 493, 493, 493, 493, 493, 493, 
	493, 493, 493, 493, 493, 493, 493, 493, 
	493, 493, 493, 493, 493, 493, 493, 493, 
	493, 495, 497, 499, 501, 503, 505, 507, 
	509, 511, 513, 515, 517, 517, 517, 517, 
	517, 520, 522, 522, 524, 527, 529, 529, 
	531, 534, 536, 536, 538, 541, 544, 547, 
	547, 549, 551, 551, 554, 554, 556, 558, 
	558, 561, 561, 563, 565, 565, 568, 568, 
	570, 572, 575, 575, 575, 575, 577, 579, 
	581, 583, 585, 587, 589, 591, 593, 595, 
	597, 599, 601, 603, 605, 607, 607, 609, 
	611, 613, 615, 617, 619, 621, 623, 626, 
	628, 630, 633, 635, 637, 639, 642, 644, 
	646, 648, 651, 653, 655, 657, 660, 662, 
	665, 667, 669, 672, 675, 678, 680, 683, 
	685, 687, 690, 693, 693, 695, 697, 699, 
	701, 703, 705, 705, 708, 711, 714, 714, 
	716, 718, 720, 722, 724, 726, 728, 730, 
	732, 734, 734, 737, 740, 743, 746, 749, 
	749, 751, 753, 755, 757, 759, 761, 763, 
	766, 769, 772, 774, 774, 774, 774, 774, 
	774, 776, 779, 779, 779, 779, 779, 781, 
	783, 785, 787, 789, 791, 791, 793, 796, 
	799, 802, 805, 805, 807, 809, 811, 813, 
	813, 815, 818, 821, 824, 824, 826, 828, 
	830, 832, 834, 836, 842, 853, 855, 858, 
	864, 867, 878, 881, 884, 887, 889, 891, 
	893, 895, 901, 904, 907, 909, 911, 913, 
	915, 921, 924, 927, 929, 931, 933, 935, 
	941, 944, 947, 950, 950, 952, 954, 956, 
	958, 960, 962, 964, 966, 968, 970, 972, 
	974, 976, 978, 980, 982, 984, 987, 990, 
	993, 996, 999, 1002, 1005, 1008, 1008, 1008, 
	1010, 1010, 1010, 1010, 1012, 1012, 1014, 1014, 
	1014, 1014, 1016, 1016, 1016, 1016, 1018, 1018, 
	1018, 1018, 1018, 1020, 1020, 1020, 1020, 1022, 
	1022, 1022, 1022, 1024, 1026, 1026, 1026, 1026, 
	1026, 1028, 1028, 1030, 1030, 1030, 1030, 1030, 
	1032, 1032, 1032, 1032, 1032, 1032, 1032, 1032, 
	1034, 1034, 1034, 1036, 1038, 1038, 1038, 1040, 
	1040, 1040, 1040, 1040, 1042, 1044, 1044, 1044, 
	1044, 1044, 1046, 1048, 1048, 1050, 1052, 1052, 
	1052, 1052, 1052, 1054, 1054, 1054, 1056, 1056, 
	1058, 1058, 1058, 1058, 1060, 1062, 1062, 1062, 
	1064, 1064, 1066, 1066, 1068, 1068, 1068, 1068, 
	1070, 1070, 1070, 1070, 1072, 1072, 1074, 1074, 
	1074, 1074, 1076, 1076, 1076, 1076, 1076, 1078, 
	1080, 1082, 1084, 1086, 1088, 1090, 1093, 1096, 
	1099, 1099, 1101, 1101, 1103, 1105, 1107, 1109, 
	1111, 1113, 1115, 1117, 1117, 1117, 1117, 1117, 
	1117, 1117, 1117, 1117, 1117, 1117, 1117, 1117, 
	1117, 1117, 1120, 1120, 1122, 1125, 1128, 1131, 
	1131, 1133, 1135, 1137, 1139, 1141, 1143, 1143, 
	1143, 1143, 1146, 1149, 1152, 1152, 1154, 1156, 
	1158, 1160, 1162, 1164, 1164, 1166, 1169, 1172, 
	1175, 1178, 1178, 1178, 1178, 1178, 1178, 1178, 
	1178, 1178, 1178, 1178, 1178, 1178, 1180, 1182, 
	1184, 1186, 1188, 1190, 1192, 1194, 1196, 1198, 
	1198, 1198, 1198, 1198, 1198, 1198, 1198, 1200, 
	1200, 1202, 1205, 1205, 1207, 1210, 1210, 1212, 
	1215, 1217, 1217, 1219, 1222, 1225, 1225, 1225, 
	1225, 1225, 1225, 1225, 1225, 1225, 1225, 1227, 
	1230, 1230, 1230, 1232, 1235, 1237, 1240, 1242, 
	1245, 1247, 1250, 1250, 1250, 1250, 1250, 1252, 
	1255, 1255, 1257, 1260, 1260, 1262, 1265, 1265, 
	1271, 1274, 1285, 1288, 1299, 1302, 1302, 1302, 
	1302, 1302, 1302, 1302, 1302, 1304, 1307, 1307
};

static const char _zone_scanner_cond_lengths[] = {
	0, 2, 2, 2, 2, 2, 2, 2, 
	0, 0, 2, 3, 2, 3, 2, 2, 
	2, 0, 0, 0, 2, 5, 0, 0, 
	0, 2, 0, 0, 0, 0, 2, 0, 
	0, 0, 2, 0, 0, 0, 2, 2, 
	0, 0, 0, 0, 2, 0, 2, 0, 
	0, 0, 0, 2, 0, 2, 2, 0, 
	0, 0, 0, 0, 0, 0, 2, 0, 
	0, 2, 2, 0, 0, 2, 0, 0, 
	0, 0, 2, 2, 0, 0, 0, 0, 
	2, 2, 0, 2, 2, 0, 0, 0, 
	0, 2, 0, 0, 2, 0, 2, 0, 
	0, 0, 2, 2, 0, 0, 2, 0, 
	2, 0, 2, 0, 0, 0, 2, 0, 
	0, 0, 2, 0, 2, 0, 0, 0, 
	2, 3, 2, 0, 2, 2, 2, 2, 
	0, 2, 3, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 2, 2, 3, 2, 
	2, 3, 2, 0, 2, 3, 2, 2, 
	2, 2, 2, 3, 2, 2, 2, 2, 
	2, 2, 2, 2, 2, 2, 2, 2, 
	2, 2, 2, 2, 3, 2, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 2, 
	2, 2, 3, 2, 2, 2, 2, 2, 
	2, 2, 2, 2, 2, 2, 2, 2, 
	2, 2, 2, 2, 5, 5, 5, 0, 
	0, 2, 0, 0, 0, 2, 0, 2, 
	3, 2, 2, 5, 5, 3, 5, 2, 
	2, 2, 2, 2, 2, 2, 2, 2, 
	2, 2, 2, 2, 3, 3, 2, 3, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 1, 0, 0, 0, 0, 1, 
	2, 2, 2, 2, 0, 2, 0, 2, 
	3, 2, 2, 0, 2, 2, 0, 0, 
	0, 0, 0, 0, 2, 3, 2, 2, 
	2, 2, 0, 2, 2, 0, 0, 0, 
	0, 0, 0, 2, 3, 2, 3, 3, 
	0, 0, 0, 0, 2, 3, 0, 2, 
	2, 2, 0, 0, 2, 3, 0, 0, 
	0, 2, 0, 0, 0, 2, 0, 0, 
	0, 0, 2, 0, 0, 0, 2, 0, 
	0, 0, 2, 2, 0, 0, 0, 0, 
	2, 0, 2, 0, 0, 0, 0, 2, 
	0, 0, 0, 0, 0, 0, 0, 2, 
	0, 0, 2, 2, 0, 0, 2, 0, 
	0, 0, 0, 2, 2, 0, 0, 0, 
	0, 2, 2, 0, 2, 2, 0, 0, 
	0, 0, 2, 0, 0, 2, 0, 2, 
	0, 0, 0, 2, 2, 0, 0, 2, 
	0, 2, 0, 2, 0, 0, 0, 2, 
	0, 0, 0, 2, 0, 2, 0, 0, 
	0, 2, 0, 0, 0, 2, 0, 2, 
	2, 2, 2, 2, 0, 2, 3, 3, 
	3, 2, 2, 2, 2, 0, 2, 3, 
	3, 2, 3, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	2, 2, 2, 2, 2, 2, 2, 2, 
	2, 2, 2, 2, 0, 0, 0, 0, 
	3, 2, 0, 2, 3, 2, 0, 2, 
	3, 2, 0, 2, 3, 3, 3, 0, 
	2, 2, 0, 3, 0, 2, 2, 0, 
	3, 0, 2, 2, 0, 3, 0, 2, 
	2, 3, 0, 0, 0, 2, 2, 2, 
	2, 2, 2, 2, 2, 2, 2, 2, 
	2, 2, 2, 2, 2, 0, 2, 2, 
	2, 2, 2, 2, 2, 2, 3, 2, 
	2, 3, 2, 2, 2, 3, 2, 2, 
	2, 3, 2, 2, 2, 3, 2, 3, 
	2, 2, 3, 3, 3, 2, 3, 2, 
	2, 3, 3, 0, 2, 2, 2, 2, 
	2, 2, 0, 3, 3, 3, 0, 2, 
	2, 2, 2, 2, 2, 2, 2, 2, 
	2, 0, 3, 3, 3, 3, 3, 0, 
	2, 2, 2, 2, 2, 2, 2, 3, 
	3, 3, 2, 0, 0, 0, 0, 0, 
	2, 3, 0, 0, 0, 0, 2, 2, 
	2, 2, 2, 2, 0, 2, 3, 3, 
	3, 3, 0, 2, 2, 2, 2, 0, 
	2, 3, 3, 3, 0, 2, 2, 2, 
	2, 2, 2, 6, 11, 2, 3, 6, 
	3, 11, 3, 3, 3, 2, 2, 2, 
	2, 6, 3, 3, 2, 2, 2, 2, 
	6, 3, 3, 2, 2, 2, 2, 6, 
	3, 3, 3, 0, 2, 2, 2, 2, 
	2, 2, 2, 2, 2, 2, 2, 2, 
	2, 2, 2, 2, 2, 3, 3, 3, 
	3, 3, 3, 3, 3, 0, 0, 2, 
	0, 0, 0, 2, 0, 2, 0, 0, 
	0, 2, 0, 0, 0, 2, 0, 0, 
	0, 0, 2, 0, 0, 0, 2, 0, 
	0, 0, 2, 2, 0, 0, 0, 0, 
	2, 0, 2, 0, 0, 0, 0, 2, 
	0, 0, 0, 0, 0, 0, 0, 2, 
	0, 0, 2, 2, 0, 0, 2, 0, 
	0, 0, 0, 2, 2, 0, 0, 0, 
	0, 2, 2, 0, 2, 2, 0, 0, 
	0, 0, 2, 0, 0, 2, 0, 2, 
	0, 0, 0, 2, 2, 0, 0, 2, 
	0, 2, 0, 2, 0, 0, 0, 2, 
	0, 0, 0, 2, 0, 2, 0, 0, 
	0, 2, 0, 0, 0, 0, 2, 2, 
	2, 2, 2, 2, 2, 3, 3, 3, 
	0, 2, 0, 2, 2, 2, 2, 2, 
	2, 2, 2, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 3, 0, 2, 3, 3, 3, 0, 
	2, 2, 2, 2, 2, 2, 0, 0, 
	0, 3, 3, 3, 0, 2, 2, 2, 
	2, 2, 2, 0, 2, 3, 3, 3, 
	3, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 2, 2, 2, 
	2, 2, 2, 2, 2, 2, 2, 0, 
	0, 0, 0, 0, 0, 0, 2, 0, 
	2, 3, 0, 2, 3, 0, 2, 3, 
	2, 0, 2, 3, 3, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 2, 3, 
	0, 0, 2, 3, 2, 3, 2, 3, 
	2, 3, 0, 0, 0, 0, 2, 3, 
	0, 2, 3, 0, 2, 3, 0, 6, 
	3, 11, 3, 11, 3, 0, 0, 0, 
	0, 0, 0, 0, 2, 3, 0, 0
};

static const short _zone_scanner_cond_keys[] = {
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	-128, 9, 10, 10, 11, 127, 10, 10, 
	59, 59, -128, 9, 10, 10, 11, 127, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	-128, 9, 10, 10, 11, 58, 59, 59, 
	60, 127, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, -128, 9, 10, 10, 11, 127, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	-128, 9, 10, 10, 11, 127, 10, 10, 
	59, 59, 10, 10, 59, 59, -128, 9, 
	10, 10, 11, 127, 10, 10, 59, 59, 
	10, 10, 59, 59, -128, 9, 10, 10, 
	11, 127, 10, 10, 59, 59, 10, 10, 
	59, 59, -128, 9, 10, 10, 11, 127, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, -128, 9, 10, 10, 
	11, 127, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, -128, 9, 10, 10, 11, 127, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	-128, 9, 10, 10, 11, 127, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, -128, 9, 10, 10, 11, 58, 
	59, 59, 60, 127, -128, 9, 10, 10, 
	11, 58, 59, 59, 60, 127, -128, 9, 
	10, 10, 11, 58, 59, 59, 60, 127, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, -128, 9, 10, 10, 
	11, 127, 10, 10, 59, 59, 10, 10, 
	59, 59, -128, 9, 10, 10, 11, 58, 
	59, 59, 60, 127, -128, 9, 10, 10, 
	11, 58, 59, 59, 60, 127, -128, 9, 
	10, 10, 11, 127, -128, 9, 10, 10, 
	11, 58, 59, 59, 60, 127, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, -128, 9, 10, 10, 11, 127, 
	-128, 9, 10, 10, 11, 127, 10, 10, 
	59, 59, -128, 9, 10, 10, 11, 127, 
	10, 10, 10, 10, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, -128, 9, 10, 10, 
	11, 127, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, -128, 9, 
	10, 10, 11, 127, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	-128, 9, 10, 10, 11, 127, 10, 10, 
	59, 59, -128, 9, 10, 10, 11, 127, 
	-128, 9, 10, 10, 11, 127, 10, 10, 
	59, 59, -128, 9, 10, 10, 11, 127, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	-128, 9, 10, 10, 11, 127, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, -128, 9, 
	10, 10, 11, 127, -128, 9, 10, 10, 
	11, 127, -128, 9, 10, 10, 11, 127, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, -128, 9, 10, 10, 
	11, 127, -128, 9, 10, 10, 11, 127, 
	10, 10, 59, 59, -128, 9, 10, 10, 
	11, 127, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, -128, 9, 10, 10, 11, 127, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	-128, 9, 10, 10, 11, 127, 10, 10, 
	59, 59, 10, 10, 59, 59, -128, 9, 
	10, 10, 11, 127, 10, 10, 59, 59, 
	10, 10, 59, 59, -128, 9, 10, 10, 
	11, 127, -128, 9, 10, 10, 11, 127, 
	-128, 9, 10, 10, 11, 127, 10, 10, 
	59, 59, 10, 10, 59, 59, -128, 9, 
	10, 10, 11, 127, 10, 10, 59, 59, 
	10, 10, 59, 59, -128, 9, 10, 10, 
	11, 127, 10, 10, 59, 59, 10, 10, 
	59, 59, -128, 9, 10, 10, 11, 127, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	-128, 9, 10, 10, 11, 127, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, -128, 9, 
	10, 10, 11, 127, 10, 10, 59, 59, 
	10, 10, 59, 59, -128, 9, 10, 10, 
	11, 127, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, -128, 9, 
	10, 10, 11, 127, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	-128, 9, 10, 10, 11, 127, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, -128, 9, 10, 10, 11, 127, 
	10, 10, 59, 59, -128, 9, 10, 10, 
	11, 127, 10, 10, 59, 59, 10, 10, 
	59, 59, -128, 9, 10, 10, 11, 127, 
	-128, 9, 10, 10, 11, 127, -128, 9, 
	10, 10, 11, 127, 10, 10, 59, 59, 
	-128, 9, 10, 10, 11, 127, 10, 10, 
	59, 59, 10, 10, 59, 59, -128, 9, 
	10, 10, 11, 127, -128, 9, 10, 10, 
	11, 127, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, -128, 9, 10, 10, 11, 127, 
	-128, 9, 10, 10, 11, 127, -128, 9, 
	10, 10, 11, 127, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, -128, 9, 10, 10, 
	11, 127, -128, 9, 10, 10, 11, 127, 
	-128, 9, 10, 10, 11, 127, -128, 9, 
	10, 10, 11, 127, -128, 9, 10, 10, 
	11, 127, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, -128, 9, 
	10, 10, 11, 127, -128, 9, 10, 10, 
	11, 127, -128, 9, 10, 10, 11, 127, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	-128, 9, 10, 10, 11, 127, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, -128, 9, 10, 10, 11, 127, 
	-128, 9, 10, 10, 11, 127, -128, 9, 
	10, 10, 11, 127, -128, 9, 10, 10, 
	11, 127, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, -128, 9, 
	10, 10, 11, 127, -128, 9, 10, 10, 
	11, 127, -128, 9, 10, 10, 11, 127, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	9, 9, 10, 10, 32, 32, 40, 40, 
	41, 41, 59, 59, 9, 9, 10, 10, 
	32, 32, 40, 40, 41, 41, 43, 43, 
	47, 47, 48, 57, 59, 59, 65, 90, 
	97, 122, 10, 10, 59, 59, -128, 9, 
	10, 10, 11, 127, 9, 9, 10, 10, 
	32, 32, 40, 40, 41, 41, 59, 59, 
	-128, 9, 10, 10, 11, 127, 9, 9, 
	10, 10, 32, 32, 40, 40, 41, 41, 
	43, 43, 47, 47, 48, 57, 59, 59, 
	65, 90, 97, 122, -128, 9, 10, 10, 
	11, 127, -128, 9, 10, 10, 11, 127, 
	-128, 9, 10, 10, 11, 127, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 9, 9, 
	10, 10, 32, 32, 40, 40, 41, 41, 
	59, 59, -128, 9, 10, 10, 11, 127, 
	-128, 9, 10, 10, 11, 127, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 9, 9, 
	10, 10, 32, 32, 40, 40, 41, 41, 
	59, 59, -128, 9, 10, 10, 11, 127, 
	-128, 9, 10, 10, 11, 127, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 9, 9, 
	10, 10, 32, 32, 40, 40, 41, 41, 
	59, 59, -128, 9, 10, 10, 11, 127, 
	-128, 9, 10, 10, 11, 127, -128, 9, 
	10, 10, 11, 127, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	-128, 9, 10, 10, 11, 127, -128, 9, 
	10, 10, 11, 127, -128, 9, 10, 10, 
	11, 127, -128, 9, 10, 10, 11, 127, 
	-128, 9, 10, 10, 11, 127, -128, 9, 
	10, 10, 11, 127, -128, 9, 10, 10, 
	11, 127, -128, 9, 10, 10, 11, 127, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, -128, 9, 10, 10, 
	11, 127, -128, 9, 10, 10, 11, 127, 
	-128, 9, 10, 10, 11, 127, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, -128, 9, 10, 10, 11, 127, 
	10, 10, 59, 59, -128, 9, 10, 10, 
	11, 127, -128, 9, 10, 10, 11, 127, 
	-128, 9, 10, 10, 11, 127, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, 10, 10, 
	59, 59, 10, 10, 59, 59, -128, 9, 
	10, 10, 11, 127, -128, 9, 10, 10, 
	11, 127, -128, 9, 10, 10, 11, 127, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, -128, 9, 10, 10, 
	11, 127, -128, 9, 10, 10, 11, 127, 
	-128, 9, 10, 10, 11, 127, -128, 9, 
	10, 10, 11, 127, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, 10, 10, 59, 59, 
	10, 10, 59, 59, -128, 9, 10, 10, 
	11, 127, 10, 10, 59, 59, -128, 9, 
	10, 10, 11, 127, 10, 10, 59, 59, 
	-128, 9, 10, 10, 11, 127, 10, 10, 
	59, 59, 10, 10, 59, 59, -128, 9, 
	10, 10, 11, 127, -128, 9, 10, 10, 
	11, 127, 10, 10, 59, 59, -128, 9, 
	10, 10, 11, 127, 10, 10, 59, 59, 
	-128, 9, 10, 10, 11, 127, 10, 10, 
	59, 59, -128, 9, 10, 10, 11, 127, 
	10, 10, 59, 59, -128, 9, 10, 10, 
	11, 127, 10, 10, 59, 59, -128, 9, 
	10, 10, 11, 127, 10, 10, 59, 59, 
	-128, 9, 10, 10, 11, 127, 10, 10, 
	59, 59, -128, 9, 10, 10, 11, 127, 
	10, 10, 59, 59, -128, 9, 10, 10, 
	11, 127, 9, 9, 10, 10, 32, 32, 
	40, 40, 41, 41, 59, 59, -128, 9, 
	10, 10, 11, 127, 9, 9, 10, 10, 
	32, 32, 40, 40, 41, 41, 43, 43, 
	47, 47, 48, 57, 59, 59, 65, 90, 
	97, 122, -128, 9, 10, 10, 11, 127, 
	9, 9, 10, 10, 32, 32, 40, 40, 
	41, 41, 43, 43, 47, 47, 48, 57, 
	59, 59, 65, 90, 97, 122, -128, 9, 
	10, 10, 11, 127, 10, 10, 59, 59, 
	-128, 9, 10, 10, 11, 127, 0
};

static const char _zone_scanner_cond_spaces[] = {
	0, 0, 0, 0, 0, 0, 5, 5, 
	5, 5, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 5, 5, 0, 0, 0, 
	5, 5, 0, 0, 0, 0, 5, 5, 
	0, 0, 0, 0, 0, 5, 5, 5, 
	5, 5, 5, 5, 5, 5, 5, 5, 
	5, 5, 5, 5, 5, 0, 0, 0, 
	0, 5, 5, 5, 5, 5, 5, 5, 
	5, 5, 5, 5, 5, 5, 5, 5, 
	5, 5, 5, 5, 5, 5, 5, 5, 
	5, 5, 5, 5, 5, 5, 5, 5, 
	5, 5, 5, 5, 5, 5, 5, 5, 
	5, 5, 5, 5, 5, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 5, 5, 5, 5, 
	5, 5, 5, 5, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 5, 5, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 5, 
	5, 5, 5, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	5, 5, 5, 5, 5, 5, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 2, 2, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 5, 5, 0, 0, 0, 
	5, 5, 5, 5, 5, 5, 5, 5, 
	0, 0, 0, 5, 5, 5, 5, 5, 
	5, 5, 5, 5, 5, 5, 5, 5, 
	5, 5, 5, 5, 5, 5, 5, 5, 
	5, 5, 5, 5, 5, 5, 5, 5, 
	5, 5, 5, 5, 5, 5, 5, 5, 
	5, 5, 5, 5, 5, 5, 5, 5, 
	5, 5, 5, 5, 5, 5, 5, 5, 
	5, 5, 5, 5, 5, 5, 5, 5, 
	5, 5, 5, 5, 5, 0, 0, 0, 
	0, 0, 0, 0, 0, 5, 5, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	5, 5, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	5, 5, 5, 5, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 5, 
	5, 5, 5, 5, 5, 5, 5, 5, 
	5, 5, 5, 5, 5, 5, 5, 0, 
	0, 0, 5, 5, 5, 5, 0, 0, 
	0, 5, 5, 5, 5, 5, 5, 0, 
	0, 0, 5, 5, 5, 5, 5, 5, 
	0, 0, 0, 5, 5, 5, 5, 5, 
	5, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 1, 1, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 5, 5, 5, 5, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 5, 
	5, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 5, 5, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 8, 11, 8, 8, 
	8, 11, 3, 6, 3, 3, 3, 3, 
	3, 3, 6, 3, 3, 1, 1, 6, 
	6, 6, 4, 9, 4, 4, 4, 9, 
	7, 7, 7, 8, 11, 8, 8, 8, 
	3, 3, 3, 11, 3, 3, 10, 10, 
	10, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 8, 
	11, 8, 8, 8, 11, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 8, 11, 8, 8, 8, 
	11, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 8, 
	11, 8, 8, 8, 11, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 1, 1, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	1, 1, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 1, 1, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 5, 5, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 5, 5, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	5, 5, 5, 5, 5, 5, 0, 0, 
	5, 5, 0, 0, 0, 5, 5, 0, 
	0, 0, 5, 5, 0, 0, 0, 0, 
	0, 5, 5, 0, 0, 0, 0, 0, 
	0, 5, 5, 0, 0, 0, 5, 5, 
	0, 0, 0, 5, 5, 0, 0, 0, 
	5, 5, 0, 0, 0, 5, 5, 0, 
	0, 0, 5, 5, 0, 0, 0, 5, 
	5, 0, 0, 0, 5, 5, 0, 0, 
	0, 4, 9, 4, 4, 4, 9, 7, 
	7, 7, 3, 6, 3, 3, 3, 3, 
	3, 3, 6, 3, 3, 6, 6, 6, 
	8, 11, 8, 8, 8, 3, 3, 3, 
	11, 3, 3, 10, 10, 10, 5, 5, 
	0, 0, 0, 0
};

static const short _zone_scanner_key_offsets[] = {
	0, 0, 38, 56, 90, 106, 123, 131, 
	139, 140, 141, 149, 152, 171, 177, 227, 
	247, 283, 287, 289, 291, 301, 315, 317, 
	319, 321, 331, 337, 339, 341, 343, 353, 
	357, 359, 361, 371, 373, 375, 377, 387, 
	397, 399, 401, 403, 404, 414, 415, 425, 
	427, 429, 431, 433, 443, 447, 453, 487, 
	489, 491, 493, 495, 497, 499, 501, 511, 
	515, 517, 527, 537, 539, 541, 551, 555, 
	557, 559, 561, 571, 581, 585, 587, 589, 
	591, 601, 613, 615, 626, 638, 640, 642, 
	644, 646, 656, 658, 660, 670, 676, 686, 
	688, 690, 692, 702, 712, 720, 722, 732, 
	734, 744, 746, 756, 758, 760, 762, 772, 
	778, 780, 782, 792, 794, 804, 806, 808, 
	810, 822, 825, 863, 867, 873, 909, 927, 
	935, 947, 955, 958, 959, 965, 967, 969, 
	971, 973, 975, 977, 983, 989, 1025, 1028, 
	1046, 1082, 1085, 1093, 1105, 1113, 1116, 1132, 
	1180, 1198, 1217, 1255, 1261, 1275, 1289, 1339, 
	1351, 1365, 1375, 1385, 1397, 1409, 1419, 1431, 
	1443, 1453, 1467, 1483, 1497, 1503, 1517, 1519, 
	1521, 1523, 1525, 1527, 1533, 1535, 1537, 1543, 
	1551, 1571, 1609, 1615, 1633, 1683, 1695, 1709, 
	1719, 1729, 1741, 1753, 1763, 1775, 1787, 1797, 
	1811, 1827, 1841, 1856, 1894, 1908, 1922, 1936, 
	1938, 1940, 1950, 1952, 1954, 1956, 1966, 1968, 
	1978, 1984, 1998, 2012, 2028, 2042, 2045, 2059, 
	2069, 2081, 2089, 2097, 2107, 2117, 2125, 2135, 
	2145, 2153, 2165, 2179, 2191, 2197, 2203, 2213, 
	2219, 2220, 2221, 2232, 2239, 2255, 2270, 2272, 
	2274, 2276, 2291, 2297, 2303, 2309, 2321, 2323, 
	2325, 2327, 2339, 2345, 2351, 2353, 2355, 2357, 
	2363, 2369, 2377, 2397, 2405, 2406, 2416, 2428, 
	2438, 2441, 2447, 2463, 2464, 2482, 2490, 2491, 
	2500, 2502, 2504, 2506, 2515, 2523, 2526, 2532, 
	2544, 2552, 2570, 2571, 2589, 2597, 2598, 2607, 
	2609, 2611, 2613, 2622, 2630, 2636, 2652, 2655, 
	2658, 2665, 2672, 2680, 2688, 2705, 2708, 2709, 
	2719, 2757, 2773, 2775, 2777, 2787, 2790, 2794, 
	2796, 2798, 2808, 2810, 2812, 2814, 2824, 2830, 
	2832, 2834, 2836, 2846, 2850, 2852, 2854, 2864, 
	2866, 2868, 2870, 2880, 2890, 2892, 2894, 2896, 
	2897, 2907, 2908, 2918, 2920, 2922, 2924, 2926, 
	2936, 2938, 2940, 2942, 2944, 2946, 2948, 2950, 
	2960, 2964, 2966, 2976, 2986, 2988, 2990, 3000, 
	3004, 3006, 3008, 3010, 3020, 3030, 3034, 3036, 
	3038, 3040, 3050, 3062, 3064, 3075, 3087, 3089, 
	3091, 3093, 3095, 3105, 3107, 3109, 3119, 3125, 
	3135, 3137, 3139, 3141, 3151, 3161, 3169, 3171, 
	3181, 3183, 3193, 3195, 3205, 3207, 3209, 3211, 
	3221, 3227, 3229, 3231, 3241, 3243, 3253, 3255, 
	3257, 3259, 3271, 3273, 3275, 3277, 3287, 3289, 
	3299, 3305, 3313, 3321, 3333, 3339, 3355, 3358, 
	3361, 3364, 3370, 3379, 3389, 3401, 3407, 3423, 
	3426, 3429, 3437, 3440, 3452, 3460, 3464, 3470, 
	3472, 3479, 3481, 3483, 3485, 3487, 3488, 3489, 
	3491, 3493, 3495, 3496, 3502, 3504, 3508, 3509, 
	3511, 3513, 3515, 3517, 3523, 3525, 3527, 3529, 
	3531, 3532, 3533, 3535, 3537, 3539, 3540, 3541, 
	3542, 3548, 3549, 3550, 3552, 3554, 3556, 3557, 
	3558, 3559, 3565, 3567, 3569, 3571, 3573, 3575, 
	3577, 3579, 3585, 3587, 3589, 3591, 3593, 3595, 
	3597, 3601, 3603, 3605, 3611, 3613, 3615, 3621, 
	3623, 3625, 3629, 3631, 3632, 3638, 3640, 3642, 
	3645, 3652, 3654, 3656, 3658, 3660, 3661, 3662, 
	3664, 3666, 3668, 3669, 3675, 3676, 3677, 3683, 
	3684, 3685, 3691, 3705, 3713, 3715, 3717, 3719, 
	3721, 3723, 3729, 3735, 3737, 3739, 3741, 3743, 
	3745, 3751, 3755, 3757, 3763, 3765, 3767, 3773, 
	3775, 3777, 3779, 3785, 3787, 3789, 3795, 3799, 
	3801, 3807, 3809, 3811, 3817, 3819, 3821, 3823, 
	3829, 3831, 3833, 3839, 3842, 3851, 3860, 3866, 
	3875, 3881, 3896, 3902, 3910, 3918, 3926, 3944, 
	3952, 3970, 3978, 3996, 4004, 4022, 4030, 4042, 
	4050, 4053, 4061, 4073, 4081, 4084, 4092, 4104, 
	4112, 4115, 4123, 4135, 4143, 4146, 4149, 4152, 
	4158, 4164, 4176, 4182, 4185, 4194, 4200, 4215, 
	4221, 4224, 4226, 4234, 4249, 4255, 4258, 4264, 
	4274, 4290, 4293, 4300, 4313, 4315, 4323, 4333, 
	4341, 4351, 4360, 4368, 4374, 4382, 4390, 4400, 
	4408, 4418, 4427, 4435, 4441, 4450, 4452, 4466, 
	4478, 4492, 4504, 4518, 4530, 4544, 4554, 4557, 
	4570, 4583, 4586, 4599, 4612, 4622, 4625, 4638, 
	4651, 4661, 4664, 4677, 4690, 4700, 4703, 4709, 
	4712, 4720, 4728, 4731, 4734, 4737, 4743, 4746, 
	4754, 4762, 4765, 4768, 4770, 4778, 4786, 4794, 
	4802, 4810, 4825, 4831, 4834, 4837, 4840, 4842, 
	4850, 4858, 4866, 4878, 4884, 4896, 4902, 4914, 
	4920, 4935, 4941, 4944, 4947, 4950, 4953, 4956, 
	4962, 4968, 4976, 4984, 4996, 5002, 5015, 5017, 
	5020, 5023, 5026, 5039, 5041, 5042, 5045, 5048, 
	5050, 5062, 5065, 5066, 5073, 5080, 5082, 5090, 
	5102, 5108, 5116, 5124, 5136, 5142, 5158, 5161, 
	5164, 5167, 5170, 5172, 5180, 5188, 5196, 5208, 
	5214, 5230, 5233, 5236, 5239, 5241, 5249, 5259, 
	5265, 5273, 5281, 5288, 5322, 5335, 5337, 5340, 
	5354, 5357, 5398, 5407, 5410, 5413, 5419, 5427, 
	5435, 5444, 5481, 5484, 5487, 5493, 5501, 5509, 
	5522, 5563, 5566, 5569, 5575, 5583, 5591, 5606, 
	5640, 5643, 5646, 5649, 5677, 5689, 5701, 5707, 
	5715, 5723, 5731, 5739, 5747, 5755, 5763, 5771, 
	5779, 5787, 5802, 5808, 5821, 5823, 5826, 5829, 
	5832, 5835, 5838, 5841, 5844, 5847, 5849, 5851, 
	5857, 5859, 5861, 5863, 5869, 5871, 5877, 5881, 
	5883, 5885, 5891, 5893, 5895, 5897, 5903, 5909, 
	5911, 5913, 5915, 5921, 5925, 5927, 5929, 5935, 
	5937, 5939, 5941, 5947, 5953, 5955, 5957, 5959, 
	5960, 5966, 5967, 5973, 5975, 5977, 5979, 5981, 
	5987, 5989, 5991, 5993, 5995, 5997, 5999, 6001, 
	6007, 6011, 6013, 6019, 6025, 6027, 6029, 6035, 
	6039, 6041, 6043, 6045, 6051, 6057, 6061, 6063, 
	6065, 6067, 6073, 6081, 6083, 6090, 6098, 6100, 
	6102, 6104, 6106, 6112, 6114, 6116, 6122, 6128, 
	6134, 6136, 6138, 6140, 6146, 6152, 6160, 6162, 
	6168, 6170, 6176, 6178, 6184, 6186, 6188, 6190, 
	6196, 6202, 6204, 6206, 6212, 6214, 6220, 6222, 
	6224, 6226, 6234, 6243, 6249, 6255, 6257, 6265, 
	6273, 6281, 6293, 6299, 6312, 6314, 6317, 6320, 
	6323, 6330, 6332, 6334, 6342, 6350, 6358, 6366, 
	6374, 6387, 6393, 6405, 6411, 6418, 6424, 6431, 
	6438, 6444, 6451, 6463, 6469, 6470, 6471, 6472, 
	6473, 6474, 6477, 6483, 6495, 6498, 6501, 6504, 
	6506, 6514, 6522, 6530, 6538, 6546, 6559, 6565, 
	6571, 6583, 6586, 6589, 6592, 6594, 6602, 6610, 
	6618, 6626, 6634, 6646, 6652, 6668, 6671, 6674, 
	6677, 6680, 6686, 6692, 6693, 6699, 6705, 6712, 
	6718, 6724, 6725, 6731, 6737, 6744, 6762, 6795, 
	6841, 6889, 6907, 6955, 6973, 7006, 7069, 7132, 
	7132, 7132, 7132, 7144, 7144, 7144, 7144, 7160, 
	7160, 7177, 7180, 7180, 7218, 7221, 7221, 7237, 
	7240, 7252, 7252, 7268, 7271, 7274, 7274, 7274, 
	7274, 7274, 7274, 7274, 7274, 7274, 7274, 7290, 
	7293, 7293, 7293, 7303, 7306, 7318, 7321, 7333, 
	7336, 7348, 7351, 7351, 7351, 7351, 7351, 7364, 
	7367, 7367, 7383, 7386, 7386, 7402, 7405, 7405, 
	7419, 7422, 7435, 7438, 7479, 7488, 7488, 7488, 
	7488, 7488, 7488, 7488, 7488, 7504, 7507, 7507
};

static const short _zone_scanner_trans_keys[] = {
	9, 32, 40, 41, 65, 67, 68, 69, 
	72, 73, 75, 76, 77, 78, 80, 82, 
	83, 84, 97, 99, 100, 101, 104, 105, 
	107, 108, 109, 110, 112, 114, 115, 116, 
	778, 827, 1034, 1083, 48, 57, 9, 32, 
	40, 41, 68, 72, 77, 83, 87, 100, 
	104, 109, 115, 119, 1034, 1083, 48, 57, 
	9, 32, 40, 41, 65, 67, 68, 69, 
	72, 73, 75, 76, 77, 78, 80, 82, 
	83, 84, 97, 99, 100, 101, 104, 105, 
	107, 108, 109, 110, 112, 114, 115, 116, 
	1034, 1083, 9, 32, 40, 41, 65, 70, 
	80, 97, 102, 112, 2058, 2107, 2314, 2363, 
	2570, 2619, 9, 32, 40, 41, 92, 2058, 
	2107, 2314, 2363, 2570, 2619, -128, 8, 11, 
	58, 60, 127, 9, 32, 40, 41, 778, 
	827, 1034, 1083, 9, 32, 40, 41, 778, 
	827, 1034, 1083, 10, 35, 9, 32, 40, 
	41, 778, 827, 1034, 1083, 1034, 896, 1151, 
	9, 32, 40, 41, 92, 1802, 1851, 2058, 
	2107, 2314, 2363, 2570, 2619, -128, 8, 11, 
	58, 60, 127, 778, 1034, 640, 895, 896, 
	1151, 9, 32, 40, 41, 58, 65, 67, 
	68, 69, 72, 73, 75, 76, 77, 78, 
	80, 82, 83, 84, 92, 97, 99, 100, 
	101, 104, 105, 107, 108, 109, 110, 112, 
	114, 115, 116, 1802, 1851, 2058, 2107, 2314, 
	2363, 2570, 2619, -128, 8, 11, 47, 48, 
	57, 60, 127, 9, 32, 40, 41, 68, 
	72, 77, 83, 87, 100, 104, 109, 115, 
	119, 778, 827, 1034, 1083, 48, 57, 9, 
	32, 40, 41, 65, 67, 68, 69, 72, 
	73, 75, 76, 77, 78, 80, 82, 83, 
	84, 97, 99, 100, 101, 104, 105, 107, 
	108, 109, 110, 112, 114, 115, 116, 778, 
	827, 1034, 1083, 69, 78, 101, 110, 82, 
	114, 84, 116, 9, 32, 40, 41, 2058, 
	2107, 2314, 2363, 2570, 2619, 777, 778, 800, 
	808, 809, 827, 1033, 1034, 1056, 1064, 1065, 
	1083, 896, 1151, 65, 97, 77, 109, 69, 
	101, 9, 32, 40, 41, 2058, 2107, 2314, 
	2363, 2570, 2619, 72, 78, 83, 104, 110, 
	115, 67, 99, 73, 105, 68, 100, 9, 
	32, 40, 41, 2058, 2107, 2314, 2363, 2570, 
	2619, 65, 83, 97, 115, 77, 109, 69, 
	101, 9, 32, 40, 41, 2058, 2107, 2314, 
	2363, 2570, 2619, 75, 107, 69, 101, 89, 
	121, 9, 32, 40, 41, 2058, 2107, 2314, 
	2363, 2570, 2619, 9, 32, 40, 41, 2058, 
	2107, 2314, 2363, 2570, 2619, 85, 117, 73, 
	105, 52, 54, 56, 9, 32, 40, 41, 
	2058, 2107, 2314, 2363, 2570, 2619, 52, 9, 
	32, 40, 41, 2058, 2107, 2314, 2363, 2570, 
	2619, 73, 105, 78, 110, 70, 102, 79, 
	111, 9, 32, 40, 41, 2058, 2107, 2314, 
	2363, 2570, 2619, 78, 80, 110, 112, 9, 
	32, 40, 41, 1034, 1083, 9, 32, 40, 
	41, 65, 67, 68, 69, 72, 73, 75, 
	76, 77, 78, 80, 82, 83, 84, 97, 
	99, 100, 101, 104, 105, 107, 108, 109, 
	110, 112, 114, 115, 116, 1034, 1083, 80, 
	112, 83, 115, 69, 101, 67, 99, 75, 
	107, 69, 101, 89, 121, 9, 32, 40, 
	41, 2058, 2107, 2314, 2363, 2570, 2619, 69, 
	88, 101, 120, 89, 121, 9, 32, 40, 
	41, 2058, 2107, 2314, 2363, 2570, 2619, 9, 
	32, 40, 41, 2058, 2107, 2314, 2363, 2570, 
	2619, 79, 111, 67, 99, 9, 32, 40, 
	41, 2058, 2107, 2314, 2363, 2570, 2619, 73, 
	88, 105, 120, 78, 110, 70, 102, 79, 
	111, 9, 32, 40, 41, 2058, 2107, 2314, 
	2363, 2570, 2619, 9, 32, 40, 41, 2058, 
	2107, 2314, 2363, 2570, 2619, 65, 83, 97, 
	115, 80, 112, 84, 116, 82, 114, 9, 
	32, 40, 41, 2058, 2107, 2314, 2363, 2570, 
	2619, 9, 32, 40, 41, 69, 101, 2058, 
	2107, 2314, 2363, 2570, 2619, 67, 99, 9, 
	32, 40, 41, 51, 2058, 2107, 2314, 2363, 
	2570, 2619, 9, 32, 40, 41, 80, 112, 
	2058, 2107, 2314, 2363, 2570, 2619, 65, 97, 
	82, 114, 65, 97, 77, 109, 9, 32, 
	40, 41, 2058, 2107, 2314, 2363, 2570, 2619, 
	84, 116, 82, 114, 9, 32, 40, 41, 
	2058, 2107, 2314, 2363, 2570, 2619, 80, 82, 
	84, 112, 114, 116, 9, 32, 40, 41, 
	2058, 2107, 2314, 2363, 2570, 2619, 83, 115, 
	73, 105, 71, 103, 9, 32, 40, 41, 
	2058, 2107, 2314, 2363, 2570, 2619, 9, 32, 
	40, 41, 2058, 2107, 2314, 2363, 2570, 2619, 
	79, 80, 82, 83, 111, 112, 114, 115, 
	65, 97, 9, 32, 40, 41, 2058, 2107, 
	2314, 2363, 2570, 2619, 70, 102, 9, 32, 
	40, 41, 2058, 2107, 2314, 2363, 2570, 2619, 
	86, 118, 9, 32, 40, 41, 2058, 2107, 
	2314, 2363, 2570, 2619, 72, 104, 70, 102, 
	80, 112, 9, 32, 40, 41, 2058, 2107, 
	2314, 2363, 2570, 2619, 76, 88, 89, 108, 
	120, 121, 83, 115, 65, 97, 9, 32, 
	40, 41, 2058, 2107, 2314, 2363, 2570, 2619, 
	84, 116, 9, 32, 40, 41, 2058, 2107, 
	2314, 2363, 2570, 2619, 80, 112, 69, 101, 
	48, 57, 9, 32, 40, 41, 2058, 2107, 
	2314, 2363, 2570, 2619, 48, 57, 1034, 896, 
	1151, 9, 32, 40, 41, 65, 67, 68, 
	69, 72, 73, 75, 76, 77, 78, 80, 
	82, 83, 84, 97, 99, 100, 101, 104, 
	105, 107, 108, 109, 110, 112, 114, 115, 
	116, 778, 827, 1034, 1083, 48, 57, 78, 
	80, 110, 112, 9, 32, 40, 41, 1034, 
	1083, 9, 32, 40, 41, 65, 67, 68, 
	69, 72, 73, 75, 76, 77, 78, 80, 
	82, 83, 84, 97, 99, 100, 101, 104, 
	105, 107, 108, 109, 110, 112, 114, 115, 
	116, 1034, 1083, 48, 57, 9, 32, 40, 
	41, 68, 72, 77, 83, 87, 100, 104, 
	109, 115, 119, 1034, 1083, 48, 57, 9, 
	32, 40, 41, 1034, 1083, 48, 57, 68, 
	72, 77, 83, 87, 100, 104, 109, 115, 
	119, 48, 57, 9, 32, 40, 41, 1034, 
	1083, 48, 57, 1034, 896, 1151, 10, 73, 
	79, 84, 105, 111, 116, 78, 110, 67, 
	99, 76, 108, 85, 117, 68, 100, 69, 
	101, 32, 59, 9, 10, 40, 41, 9, 
	32, 40, 41, 1034, 1083, 9, 32, 40, 
	41, 65, 67, 68, 69, 72, 73, 75, 
	76, 77, 78, 80, 82, 83, 84, 97, 
	99, 100, 101, 104, 105, 107, 108, 109, 
	110, 112, 114, 115, 116, 1034, 1083, 48, 
	57, 1034, 896, 1151, 9, 32, 40, 41, 
	68, 72, 77, 83, 87, 100, 104, 109, 
	115, 119, 1034, 1083, 48, 57, 9, 32, 
	40, 41, 65, 67, 68, 69, 72, 73, 
	75, 76, 77, 78, 80, 82, 83, 84, 
	97, 99, 100, 101, 104, 105, 107, 108, 
	109, 110, 112, 114, 115, 116, 1034, 1083, 
	48, 57, 1034, 896, 1151, 9, 32, 40, 
	41, 1034, 1083, 48, 57, 68, 72, 77, 
	83, 87, 100, 104, 109, 115, 119, 48, 
	57, 9, 32, 40, 41, 1034, 1083, 48, 
	57, 1034, 896, 1151, 9, 32, 40, 41, 
	65, 70, 80, 97, 102, 112, 2058, 2107, 
	2314, 2363, 2570, 2619, 9, 32, 40, 41, 
	58, 65, 67, 68, 69, 72, 73, 75, 
	76, 77, 78, 80, 82, 83, 84, 92, 
	97, 99, 100, 101, 104, 105, 107, 108, 
	109, 110, 112, 114, 115, 116, 2058, 2107, 
	2314, 2363, 2570, 2619, -128, 8, 11, 47, 
	48, 57, 60, 127, 9, 32, 40, 41, 
	65, 70, 80, 97, 102, 112, 1802, 1851, 
	2058, 2107, 2314, 2363, 2570, 2619, 9, 32, 
	40, 41, 92, 1802, 1851, 2058, 2107, 2314, 
	2363, 2570, 2619, -128, 8, 11, 58, 60, 
	127, 9, 32, 40, 41, 65, 67, 68, 
	69, 72, 73, 75, 76, 77, 78, 80, 
	82, 83, 84, 97, 99, 100, 101, 104, 
	105, 107, 108, 109, 110, 112, 114, 115, 
	116, 778, 827, 1034, 1083, 48, 57, 778, 
	1034, 640, 895, 896, 1151, 9, 32, 40, 
	41, 778, 827, 1034, 1083, -128, 8, 11, 
	58, 60, 127, 9, 32, 40, 41, 778, 
	827, 1034, 1083, -128, 8, 11, 58, 60, 
	127, 9, 32, 40, 41, 58, 65, 67, 
	68, 69, 72, 73, 75, 76, 77, 78, 
	80, 82, 83, 84, 92, 97, 99, 100, 
	101, 104, 105, 107, 108, 109, 110, 112, 
	114, 115, 116, 1802, 1851, 2058, 2107, 2314, 
	2363, 2570, 2619, -128, 8, 11, 47, 48, 
	57, 60, 127, 9, 32, 40, 41, 69, 
	78, 101, 110, 778, 827, 1034, 1083, 9, 
	32, 40, 41, 72, 78, 83, 104, 110, 
	115, 778, 827, 1034, 1083, 9, 32, 40, 
	41, 85, 117, 778, 827, 1034, 1083, 9, 
	32, 40, 41, 73, 105, 778, 827, 1034, 
	1083, 9, 32, 40, 41, 78, 80, 110, 
	112, 778, 827, 1034, 1083, 9, 32, 40, 
	41, 69, 88, 101, 120, 778, 827, 1034, 
	1083, 9, 32, 40, 41, 79, 111, 778, 
	827, 1034, 1083, 9, 32, 40, 41, 73, 
	88, 105, 120, 778, 827, 1034, 1083, 9, 
	32, 40, 41, 65, 83, 97, 115, 778, 
	827, 1034, 1083, 9, 32, 40, 41, 84, 
	116, 778, 827, 1034, 1083, 9, 32, 40, 
	41, 80, 82, 84, 112, 114, 116, 778, 
	827, 1034, 1083, 9, 32, 40, 41, 79, 
	80, 82, 83, 111, 112, 114, 115, 778, 
	827, 1034, 1083, 9, 32, 40, 41, 76, 
	88, 89, 108, 120, 121, 778, 827, 1034, 
	1083, 778, 1034, 640, 895, 896, 1151, 9, 
	32, 40, 41, 73, 79, 84, 105, 111, 
	116, 778, 827, 1034, 1083, 82, 114, 73, 
	105, 71, 103, 73, 105, 78, 110, 32, 
	59, 9, 10, 40, 41, 84, 116, 76, 
	108, 32, 59, 9, 10, 40, 41, 9, 
	32, 40, 41, 778, 827, 1034, 1083, 9, 
	32, 40, 41, 68, 72, 77, 83, 87, 
	100, 104, 109, 115, 119, 778, 827, 1034, 
	1083, 48, 57, 9, 32, 40, 41, 65, 
	67, 68, 69, 72, 73, 75, 76, 77, 
	78, 80, 82, 83, 84, 97, 99, 100, 
	101, 104, 105, 107, 108, 109, 110, 112, 
	114, 115, 116, 778, 827, 1034, 1083, 48, 
	57, 778, 1034, 640, 895, 896, 1151, 9, 
	32, 40, 41, 65, 70, 80, 97, 102, 
	112, 1802, 1851, 2058, 2107, 2314, 2363, 2570, 
	2619, 9, 32, 40, 41, 58, 65, 67, 
	68, 69, 72, 73, 75, 76, 77, 78, 
	80, 82, 83, 84, 92, 97, 99, 100, 
	101, 104, 105, 107, 108, 109, 110, 112, 
	114, 115, 116, 1802, 1851, 2058, 2107, 2314, 
	2363, 2570, 2619, -128, 8, 11, 47, 48, 
	57, 60, 127, 9, 32, 40, 41, 69, 
	78, 101, 110, 778, 827, 1034, 1083, 9, 
	32, 40, 41, 72, 78, 83, 104, 110, 
	115, 778, 827, 1034, 1083, 9, 32, 40, 
	41, 85, 117, 778, 827, 1034, 1083, 9, 
	32, 40, 41, 73, 105, 778, 827, 1034, 
	1083, 9, 32, 40, 41, 78, 80, 110, 
	112, 778, 827, 1034, 1083, 9, 32, 40, 
	41, 69, 88, 101, 120, 778, 827, 1034, 
	1083, 9, 32, 40, 41, 79, 111, 778, 
	827, 1034, 1083, 9, 32, 40, 41, 73, 
	88, 105, 120, 778, 827, 1034, 1083, 9, 
	32, 40, 41, 65, 83, 97, 115, 778, 
	827, 1034, 1083, 9, 32, 40, 41, 84, 
	116, 778, 827, 1034, 1083, 9, 32, 40, 
	41, 80, 82, 84, 112, 114, 116, 778, 
	827, 1034, 1083, 9, 32, 40, 41, 79, 
	80, 82, 83, 111, 112, 114, 115, 778, 
	827, 1034, 1083, 9, 32, 40, 41, 76, 
	88, 89, 108, 120, 121, 778, 827, 1034, 
	1083, 9, 32, 35, 40, 41, 778, 827, 
	1034, 1083, -128, 8, 11, 58, 60, 127, 
	9, 32, 40, 41, 65, 67, 68, 69, 
	72, 73, 75, 76, 77, 78, 80, 82, 
	83, 84, 97, 99, 100, 101, 104, 105, 
	107, 108, 109, 110, 112, 114, 115, 116, 
	778, 827, 1034, 1083, 48, 57, 777, 778, 
	800, 808, 809, 827, 1033, 1034, 1056, 1064, 
	1065, 1083, 896, 1151, 777, 778, 800, 808, 
	809, 827, 1033, 1034, 1056, 1064, 1065, 1083, 
	896, 1151, 777, 778, 800, 808, 809, 1033, 
	1034, 1056, 1064, 1065, 640, 895, 896, 1151, 
	65, 97, 65, 97, 9, 32, 40, 41, 
	2058, 2107, 2314, 2363, 2570, 2619, 83, 115, 
	68, 100, 66, 98, 9, 32, 40, 41, 
	2058, 2107, 2314, 2363, 2570, 2619, 76, 108, 
	9, 32, 40, 41, 2058, 2107, 2314, 2363, 
	2570, 2619, 778, 1034, 640, 895, 896, 1151, 
	9, 32, 40, 41, 778, 827, 1034, 1083, 
	-128, 8, 11, 58, 60, 127, 9, 32, 
	40, 41, 778, 827, 1034, 1083, -128, 8, 
	11, 58, 60, 127, 777, 778, 800, 808, 
	809, 827, 1033, 1034, 1056, 1064, 1065, 1083, 
	640, 895, 896, 1151, 777, 778, 800, 808, 
	809, 1033, 1034, 1056, 1064, 1065, 640, 895, 
	896, 1151, 1034, 896, 1151, 777, 778, 800, 
	808, 809, 827, 1033, 1034, 1056, 1064, 1065, 
	1083, 896, 1151, 9, 32, 40, 41, 69, 
	78, 101, 110, 1034, 1083, 9, 32, 40, 
	41, 72, 78, 83, 104, 110, 115, 1034, 
	1083, 9, 32, 40, 41, 85, 117, 1034, 
	1083, 9, 32, 40, 41, 73, 105, 1034, 
	1083, 9, 32, 40, 41, 78, 80, 110, 
	112, 1034, 1083, 9, 32, 40, 41, 69, 
	88, 101, 120, 1034, 1083, 9, 32, 40, 
	41, 79, 111, 1034, 1083, 9, 32, 40, 
	41, 73, 88, 105, 120, 1034, 1083, 9, 
	32, 40, 41, 65, 83, 97, 115, 1034, 
	1083, 9, 32, 40, 41, 84, 116, 1034, 
	1083, 9, 32, 40, 41, 80, 82, 84, 
	112, 114, 116, 1034, 1083, 9, 32, 40, 
	41, 79, 80, 82, 83, 111, 112, 114, 
	115, 1034, 1083, 9, 32, 40, 41, 76, 
	88, 89, 108, 120, 121, 1034, 1083, 778, 
	1034, 640, 895, 896, 1151, 778, 1034, 640, 
	895, 896, 1151, 9, 32, 40, 41, 78, 
	80, 110, 112, 1034, 1083, 778, 1034, 640, 
	895, 896, 1151, 10, 10, 42, 46, 64, 
	92, 95, 45, 57, 65, 90, 97, 122, 
	32, 46, 59, 9, 10, 40, 41, 32, 
	42, 45, 59, 92, 95, 9, 10, 40, 
	41, 47, 57, 65, 90, 97, 122, 32, 
	46, 59, 92, 95, 9, 10, 40, 41, 
	45, 57, 65, 90, 97, 122, 48, 57, 
	48, 57, 48, 57, 32, 46, 59, 92, 
	95, 9, 10, 40, 41, 45, 57, 65, 
	90, 97, 122, 32, 59, 9, 10, 40, 
	41, 32, 59, 9, 10, 40, 41, 34, 
	92, 33, 58, 60, 126, 32, 33, 59, 
	92, 9, 10, 35, 39, 40, 41, 42, 
	126, 48, 57, 48, 57, 48, 57, 32, 
	33, 59, 92, 9, 10, 35, 39, 40, 
	41, 42, 126, 9, 34, 92, 522, 32, 
	126, 32, 59, 9, 10, 40, 41, 48, 
	57, 48, 57, 48, 57, 9, 34, 92, 
	522, 32, 126, 9, 32, 40, 41, 1034, 
	1083, 9, 32, 40, 41, 1034, 1083, 48, 
	57, 9, 32, 40, 41, 68, 72, 77, 
	83, 87, 100, 104, 109, 115, 119, 778, 
	827, 1034, 1083, 48, 57, 9, 32, 40, 
	41, 778, 827, 1034, 1083, 10, 9, 32, 
	40, 41, 778, 827, 1034, 1083, 48, 57, 
	68, 72, 77, 83, 87, 100, 104, 109, 
	115, 119, 48, 57, 9, 32, 40, 41, 
	778, 827, 1034, 1083, 48, 57, 1034, 896, 
	1151, 9, 32, 40, 41, 1034, 1083, 9, 
	32, 40, 41, 42, 46, 92, 95, 1034, 
	1083, 45, 57, 65, 90, 97, 122, 46, 
	9, 32, 40, 41, 42, 45, 92, 95, 
	778, 827, 1034, 1083, 47, 57, 65, 90, 
	97, 122, 9, 32, 40, 41, 778, 827, 
	1034, 1083, 10, 46, 92, 95, 45, 57, 
	65, 90, 97, 122, 48, 57, 48, 57, 
	48, 57, 46, 92, 95, 45, 57, 65, 
	90, 97, 122, 9, 32, 40, 41, 778, 
	827, 1034, 1083, 1034, 896, 1151, 9, 32, 
	40, 41, 1034, 1083, 9, 32, 40, 41, 
	1034, 1083, -128, 8, 11, 58, 60, 127, 
	9, 32, 40, 41, 778, 827, 1034, 1083, 
	9, 32, 40, 41, 42, 46, 92, 95, 
	778, 827, 1034, 1083, 45, 57, 65, 90, 
	97, 122, 46, 9, 32, 40, 41, 42, 
	45, 92, 95, 778, 827, 1034, 1083, 47, 
	57, 65, 90, 97, 122, 9, 32, 40, 
	41, 778, 827, 1034, 1083, 10, 46, 92, 
	95, 45, 57, 65, 90, 97, 122, 48, 
	57, 48, 57, 48, 57, 46, 92, 95, 
	45, 57, 65, 90, 97, 122, 9, 32, 
	40, 41, 778, 827, 1034, 1083, 778, 1034, 
	640, 895, 896, 1151, 9, 32, 40, 41, 
	42, 46, 92, 95, 1034, 1083, 45, 57, 
	65, 90, 97, 122, 1034, 896, 1151, 1034, 
	896, 1151, 43, 47, 57, 65, 90, 97, 
	122, 43, 47, 57, 65, 90, 97, 122, 
	43, 61, 47, 57, 65, 90, 97, 122, 
	43, 61, 47, 57, 65, 90, 97, 122, 
	9, 32, 40, 41, 43, 2058, 2107, 2314, 
	2363, 2570, 2619, 47, 57, 65, 90, 97, 
	122, 1034, 896, 1151, 61, 9, 32, 40, 
	41, 2058, 2107, 2314, 2363, 2570, 2619, 9, 
	32, 40, 41, 65, 67, 68, 69, 72, 
	73, 75, 76, 77, 78, 80, 82, 83, 
	84, 97, 99, 100, 101, 104, 105, 107, 
	108, 109, 110, 112, 114, 115, 116, 2058, 
	2107, 2314, 2363, 2570, 2619, 9, 32, 40, 
	41, 65, 70, 80, 97, 102, 112, 2058, 
	2107, 2314, 2363, 2570, 2619, 65, 97, 65, 
	97, 9, 32, 40, 41, 2058, 2107, 2314, 
	2363, 2570, 2619, 1034, 896, 1151, 69, 78, 
	101, 110, 82, 114, 84, 116, 9, 32, 
	40, 41, 2058, 2107, 2314, 2363, 2570, 2619, 
	65, 97, 77, 109, 69, 101, 9, 32, 
	40, 41, 2058, 2107, 2314, 2363, 2570, 2619, 
	72, 78, 83, 104, 110, 115, 67, 99, 
	73, 105, 68, 100, 9, 32, 40, 41, 
	2058, 2107, 2314, 2363, 2570, 2619, 65, 83, 
	97, 115, 77, 109, 69, 101, 9, 32, 
	40, 41, 2058, 2107, 2314, 2363, 2570, 2619, 
	75, 107, 69, 101, 89, 121, 9, 32, 
	40, 41, 2058, 2107, 2314, 2363, 2570, 2619, 
	9, 32, 40, 41, 2058, 2107, 2314, 2363, 
	2570, 2619, 85, 117, 73, 105, 52, 54, 
	56, 9, 32, 40, 41, 2058, 2107, 2314, 
	2363, 2570, 2619, 52, 9, 32, 40, 41, 
	2058, 2107, 2314, 2363, 2570, 2619, 73, 105, 
	78, 110, 70, 102, 79, 111, 9, 32, 
	40, 41, 2058, 2107, 2314, 2363, 2570, 2619, 
	80, 112, 83, 115, 69, 101, 67, 99, 
	75, 107, 69, 101, 89, 121, 9, 32, 
	40, 41, 2058, 2107, 2314, 2363, 2570, 2619, 
	69, 88, 101, 120, 89, 121, 9, 32, 
	40, 41, 2058, 2107, 2314, 2363, 2570, 2619, 
	9, 32, 40, 41, 2058, 2107, 2314, 2363, 
	2570, 2619, 79, 111, 67, 99, 9, 32, 
	40, 41, 2058, 2107, 2314, 2363, 2570, 2619, 
	73, 88, 105, 120, 78, 110, 70, 102, 
	79, 111, 9, 32, 40, 41, 2058, 2107, 
	2314, 2363, 2570, 2619, 9, 32, 40, 41, 
	2058, 2107, 2314, 2363, 2570, 2619, 65, 83, 
	97, 115, 80, 112, 84, 116, 82, 114, 
	9, 32, 40, 41, 2058, 2107, 2314, 2363, 
	2570, 2619, 9, 32, 40, 41, 69, 101, 
	2058, 2107, 2314, 2363, 2570, 2619, 67, 99, 
	9, 32, 40, 41, 51, 2058, 2107, 2314, 
	2363, 2570, 2619, 9, 32, 40, 41, 80, 
	112, 2058, 2107, 2314, 2363, 2570, 2619, 65, 
	97, 82, 114, 65, 97, 77, 109, 9, 
	32, 40, 41, 2058, 2107, 2314, 2363, 2570, 
	2619, 84, 116, 82, 114, 9, 32, 40, 
	41, 2058, 2107, 2314, 2363, 2570, 2619, 80, 
	82, 84, 112, 114, 116, 9, 32, 40, 
	41, 2058, 2107, 2314, 2363, 2570, 2619, 83, 
	115, 73, 105, 71, 103, 9, 32, 40, 
	41, 2058, 2107, 2314, 2363, 2570, 2619, 9, 
	32, 40, 41, 2058, 2107, 2314, 2363, 2570, 
	2619, 79, 80, 82, 83, 111, 112, 114, 
	115, 65, 97, 9, 32, 40, 41, 2058, 
	2107, 2314, 2363, 2570, 2619, 70, 102, 9, 
	32, 40, 41, 2058, 2107, 2314, 2363, 2570, 
	2619, 86, 118, 9, 32, 40, 41, 2058, 
	2107, 2314, 2363, 2570, 2619, 72, 104, 70, 
	102, 80, 112, 9, 32, 40, 41, 2058, 
	2107, 2314, 2363, 2570, 2619, 76, 88, 89, 
	108, 120, 121, 83, 115, 65, 97, 9, 
	32, 40, 41, 2058, 2107, 2314, 2363, 2570, 
	2619, 84, 116, 9, 32, 40, 41, 2058, 
	2107, 2314, 2363, 2570, 2619, 80, 112, 69, 
	101, 48, 57, 9, 32, 40, 41, 2058, 
	2107, 2314, 2363, 2570, 2619, 48, 57, 83, 
	115, 68, 100, 66, 98, 9, 32, 40, 
	41, 2058, 2107, 2314, 2363, 2570, 2619, 76, 
	108, 9, 32, 40, 41, 2058, 2107, 2314, 
	2363, 2570, 2619, 9, 32, 40, 41, 1034, 
	1083, 9, 32, 40, 41, 1034, 1083, 48, 
	57, 9, 32, 40, 41, 1034, 1083, 48, 
	57, 9, 32, 40, 41, 1034, 1083, 48, 
	57, 65, 70, 97, 102, 48, 57, 65, 
	70, 97, 102, 9, 32, 40, 41, 2058, 
	2107, 2314, 2363, 2570, 2619, 48, 57, 65, 
	70, 97, 102, 1034, 896, 1151, 1034, 896, 
	1151, 1034, 896, 1151, 9, 32, 40, 41, 
	1034, 1083, 9, 32, 40, 41, 48, 1034, 
	1083, 49, 57, 9, 32, 40, 41, 778, 
	827, 1034, 1083, 48, 57, 9, 32, 40, 
	41, 1034, 1083, 48, 57, 65, 70, 97, 
	102, 48, 57, 65, 70, 97, 102, 9, 
	32, 40, 41, 2058, 2107, 2314, 2363, 2570, 
	2619, 48, 57, 65, 70, 97, 102, 1034, 
	896, 1151, 1034, 896, 1151, 9, 32, 40, 
	41, 1034, 1083, 48, 57, 1034, 896, 1151, 
	68, 69, 73, 80, 82, 100, 101, 105, 
	112, 114, 48, 57, 32, 59, 9, 10, 
	40, 41, 48, 57, 72, 83, 104, 115, 
	32, 59, 9, 10, 40, 41, 65, 97, 
	32, 45, 59, 9, 10, 40, 41, 78, 
	110, 83, 115, 69, 101, 67, 99, 51, 
	45, 83, 115, 72, 104, 65, 97, 49, 
	32, 59, 9, 10, 40, 41, 67, 99, 
	67, 68, 99, 100, 45, 71, 103, 79, 
	111, 83, 115, 84, 116, 32, 59, 9, 
	10, 40, 41, 83, 115, 65, 97, 80, 
	112, 50, 51, 53, 54, 83, 115, 72, 
	104, 65, 97, 50, 53, 54, 32, 59, 
	9, 10, 40, 41, 56, 52, 83, 115, 
	72, 104, 65, 97, 51, 56, 52, 32, 
	59, 9, 10, 40, 41, 78, 110, 68, 
	100, 73, 105, 82, 114, 69, 101, 67, 
	99, 84, 116, 32, 59, 9, 10, 40, 
	41, 82, 114, 73, 105, 86, 118, 65, 
	97, 84, 116, 69, 101, 68, 79, 100, 
	111, 78, 110, 83, 115, 32, 59, 9, 
	10, 40, 41, 73, 105, 68, 100, 32, 
	59, 9, 10, 40, 41, 83, 115, 65, 
	97, 77, 83, 109, 115, 68, 100, 53, 
	32, 59, 9, 10, 40, 41, 72, 104, 
	65, 97, 49, 50, 53, 32, 45, 59, 
	9, 10, 40, 41, 78, 110, 83, 115, 
	69, 101, 67, 99, 51, 45, 83, 115, 
	72, 104, 65, 97, 49, 32, 59, 9, 
	10, 40, 41, 53, 54, 32, 59, 9, 
	10, 40, 41, 49, 50, 32, 59, 9, 
	10, 40, 41, 65, 73, 79, 80, 83, 
	85, 97, 105, 111, 112, 115, 117, 48, 
	57, 32, 59, 9, 10, 40, 41, 48, 
	57, 67, 99, 80, 112, 75, 107, 73, 
	105, 88, 120, 32, 59, 9, 10, 40, 
	41, 65, 80, 83, 97, 112, 115, 67, 
	99, 80, 112, 75, 107, 73, 105, 88, 
	120, 32, 59, 9, 10, 40, 41, 71, 
	75, 103, 107, 80, 112, 32, 59, 9, 
	10, 40, 41, 73, 105, 88, 120, 32, 
	59, 9, 10, 40, 41, 80, 112, 75, 
	107, 73, 105, 32, 59, 9, 10, 40, 
	41, 73, 105, 68, 100, 32, 59, 9, 
	10, 40, 41, 71, 75, 103, 107, 80, 
	112, 32, 59, 9, 10, 40, 41, 73, 
	105, 88, 120, 32, 59, 9, 10, 40, 
	41, 80, 112, 75, 107, 73, 105, 32, 
	59, 9, 10, 40, 41, 82, 114, 73, 
	105, 32, 59, 9, 10, 40, 41, 46, 
	48, 57, 32, 46, 59, 9, 10, 40, 
	41, 48, 57, 42, 92, 95, 45, 57, 
	64, 90, 97, 122, 32, 59, 9, 10, 
	40, 41, 42, 92, 95, 45, 57, 64, 
	90, 97, 122, 9, 32, 40, 41, 1034, 
	1083, 9, 32, 40, 41, 42, 92, 95, 
	1034, 1083, 45, 57, 64, 90, 97, 122, 
	9, 32, 40, 41, 1034, 1083, 9, 32, 
	40, 41, 1034, 1083, 48, 57, 9, 32, 
	40, 41, 1034, 1083, 48, 57, 9, 32, 
	40, 41, 1034, 1083, 48, 57, 9, 32, 
	40, 41, 68, 72, 77, 83, 87, 100, 
	104, 109, 115, 119, 1034, 1083, 48, 57, 
	9, 32, 40, 41, 1034, 1083, 48, 57, 
	9, 32, 40, 41, 68, 72, 77, 83, 
	87, 100, 104, 109, 115, 119, 1034, 1083, 
	48, 57, 9, 32, 40, 41, 1034, 1083, 
	48, 57, 9, 32, 40, 41, 68, 72, 
	77, 83, 87, 100, 104, 109, 115, 119, 
	1034, 1083, 48, 57, 9, 32, 40, 41, 
	1034, 1083, 48, 57, 32, 59, 68, 72, 
	77, 83, 87, 100, 104, 109, 115, 119, 
	9, 10, 40, 41, 48, 57, 32, 59, 
	9, 10, 40, 41, 48, 57, 68, 72, 
	77, 83, 87, 100, 104, 109, 115, 119, 
	48, 57, 32, 59, 9, 10, 40, 41, 
	48, 57, 1034, 896, 1151, 9, 32, 40, 
	41, 1034, 1083, 48, 57, 68, 72, 77, 
	83, 87, 100, 104, 109, 115, 119, 48, 
	57, 9, 32, 40, 41, 1034, 1083, 48, 
	57, 1034, 896, 1151, 9, 32, 40, 41, 
	1034, 1083, 48, 57, 68, 72, 77, 83, 
	87, 100, 104, 109, 115, 119, 48, 57, 
	9, 32, 40, 41, 1034, 1083, 48, 57, 
	1034, 896, 1151, 9, 32, 40, 41, 1034, 
	1083, 48, 57, 68, 72, 77, 83, 87, 
	100, 104, 109, 115, 119, 48, 57, 9, 
	32, 40, 41, 1034, 1083, 48, 57, 1034, 
	896, 1151, 1034, 896, 1151, 1034, 896, 1151, 
	32, 59, 9, 10, 40, 41, 9, 32, 
	40, 41, 1034, 1083, 9, 32, 40, 41, 
	1034, 1083, -128, 8, 11, 58, 60, 127, 
	32, 59, 9, 10, 40, 41, 1034, 896, 
	1151, 42, 92, 95, 45, 57, 64, 90, 
	97, 122, 9, 32, 40, 41, 1034, 1083, 
	9, 32, 40, 41, 42, 92, 95, 1034, 
	1083, 45, 57, 64, 90, 97, 122, 32, 
	59, 9, 10, 40, 41, 1034, 896, 1151, 
	48, 57, 9, 32, 40, 41, 1034, 1083, 
	48, 57, 9, 32, 40, 41, 42, 92, 
	95, 1034, 1083, 45, 57, 64, 90, 97, 
	122, 32, 59, 9, 10, 40, 41, 1034, 
	896, 1151, 32, 59, 9, 10, 40, 41, 
	9, 32, 40, 41, 2058, 2107, 2314, 2363, 
	2570, 2619, 9, 32, 40, 41, 2058, 2107, 
	2314, 2363, 2570, 2619, -128, 8, 11, 58, 
	60, 127, 1034, 896, 1151, 46, 48, 58, 
	65, 70, 97, 102, 32, 46, 59, 9, 
	10, 40, 41, 48, 58, 65, 70, 97, 
	102, 48, 57, 9, 32, 40, 41, 1034, 
	1083, 48, 57, 9, 32, 40, 41, 78, 
	83, 1034, 1083, 48, 57, 9, 32, 40, 
	41, 1034, 1083, 48, 57, 9, 32, 40, 
	41, 78, 83, 1034, 1083, 48, 57, 9, 
	32, 40, 41, 46, 1034, 1083, 48, 57, 
	9, 32, 40, 41, 78, 83, 1034, 1083, 
	9, 32, 40, 41, 1034, 1083, 9, 32, 
	40, 41, 1034, 1083, 48, 57, 9, 32, 
	40, 41, 1034, 1083, 48, 57, 9, 32, 
	40, 41, 69, 87, 1034, 1083, 48, 57, 
	9, 32, 40, 41, 1034, 1083, 48, 57, 
	9, 32, 40, 41, 69, 87, 1034, 1083, 
	48, 57, 9, 32, 40, 41, 46, 1034, 
	1083, 48, 57, 9, 32, 40, 41, 69, 
	87, 1034, 1083, 9, 32, 40, 41, 1034, 
	1083, 9, 32, 40, 41, 45, 1034, 1083, 
	48, 57, 48, 57, 9, 32, 40, 41, 
	46, 109, 2058, 2107, 2314, 2363, 2570, 2619, 
	48, 57, 9, 32, 40, 41, 2058, 2107, 
	2314, 2363, 2570, 2619, 48, 57, 9, 32, 
	40, 41, 46, 109, 2058, 2107, 2314, 2363, 
	2570, 2619, 48, 57, 9, 32, 40, 41, 
	2058, 2107, 2314, 2363, 2570, 2619, 48, 57, 
	9, 32, 40, 41, 46, 109, 2058, 2107, 
	2314, 2363, 2570, 2619, 48, 57, 9, 32, 
	40, 41, 2058, 2107, 2314, 2363, 2570, 2619, 
	48, 57, 9, 32, 40, 41, 46, 109, 
	2058, 2107, 2314, 2363, 2570, 2619, 48, 57, 
	9, 32, 40, 41, 2058, 2107, 2314, 2363, 
	2570, 2619, 1034, 896, 1151, 9, 32, 40, 
	41, 109, 2058, 2107, 2314, 2363, 2570, 2619, 
	48, 57, 9, 32, 40, 41, 109, 2058, 
	2107, 2314, 2363, 2570, 2619, 48, 57, 1034, 
	896, 1151, 9, 32, 40, 41, 109, 2058, 
	2107, 2314, 2363, 2570, 2619, 48, 57, 9, 
	32, 40, 41, 109, 2058, 2107, 2314, 2363, 
	2570, 2619, 48, 57, 9, 32, 40, 41, 
	2058, 2107, 2314, 2363, 2570, 2619, 1034, 896, 
	1151, 9, 32, 40, 41, 109, 2058, 2107, 
	2314, 2363, 2570, 2619, 48, 57, 9, 32, 
	40, 41, 109, 2058, 2107, 2314, 2363, 2570, 
	2619, 48, 57, 9, 32, 40, 41, 2058, 
	2107, 2314, 2363, 2570, 2619, 1034, 896, 1151, 
	9, 32, 40, 41, 109, 2058, 2107, 2314, 
	2363, 2570, 2619, 48, 57, 9, 32, 40, 
	41, 109, 2058, 2107, 2314, 2363, 2570, 2619, 
	48, 57, 9, 32, 40, 41, 2058, 2107, 
	2314, 2363, 2570, 2619, 1034, 896, 1151, 9, 
	32, 40, 41, 1034, 1083, 1034, 896, 1151, 
	9, 32, 40, 41, 1034, 1083, 48, 57, 
	9, 32, 40, 41, 1034, 1083, 48, 57, 
	1034, 896, 1151, 1034, 896, 1151, 1034, 896, 
	1151, 9, 32, 40, 41, 1034, 1083, 1034, 
	896, 1151, 9, 32, 40, 41, 1034, 1083, 
	48, 57, 9, 32, 40, 41, 1034, 1083, 
	48, 57, 1034, 896, 1151, 1034, 896, 1151, 
	48, 57, 9, 32, 40, 41, 1034, 1083, 
	48, 57, 9, 32, 40, 41, 1034, 1083, 
	48, 57, 9, 32, 40, 41, 1034, 1083, 
	48, 57, 9, 32, 40, 41, 1034, 1083, 
	48, 57, 9, 32, 40, 41, 1034, 1083, 
	48, 57, 9, 32, 40, 41, 42, 92, 
	95, 1034, 1083, 45, 57, 64, 90, 97, 
	122, 32, 59, 9, 10, 40, 41, 1034, 
	896, 1151, 1034, 896, 1151, 1034, 896, 1151, 
	48, 57, 9, 32, 40, 41, 1034, 1083, 
	48, 57, 9, 32, 40, 41, 1034, 1083, 
	48, 57, 9, 32, 40, 41, 1034, 1083, 
	48, 57, 9, 32, 40, 41, 1034, 1083, 
	-128, 8, 11, 58, 60, 127, 9, 32, 
	40, 41, 1034, 1083, 9, 32, 40, 41, 
	1034, 1083, -128, 8, 11, 58, 60, 127, 
	9, 32, 40, 41, 1034, 1083, 9, 32, 
	40, 41, 1034, 1083, -128, 8, 11, 58, 
	60, 127, 9, 32, 40, 41, 1034, 1083, 
	9, 32, 40, 41, 42, 92, 95, 1034, 
	1083, 45, 57, 64, 90, 97, 122, 32, 
	59, 9, 10, 40, 41, 1034, 896, 1151, 
	1034, 896, 1151, 1034, 896, 1151, 1034, 896, 
	1151, 1034, 896, 1151, 48, 57, 65, 90, 
	97, 122, 9, 32, 40, 41, 1034, 1083, 
	9, 32, 40, 41, 1034, 1083, 48, 57, 
	9, 32, 40, 41, 1034, 1083, 48, 57, 
	9, 32, 40, 41, 1034, 1083, 48, 57, 
	65, 90, 97, 122, 9, 32, 40, 41, 
	1034, 1083, 9, 32, 40, 41, 43, 1034, 
	1083, 47, 57, 65, 90, 97, 122, 1546, 
	1595, 1034, 896, 1151, 1034, 896, 1151, 1034, 
	896, 1151, 9, 32, 33, 40, 41, 49, 
	50, 2058, 2107, 2314, 2363, 2570, 2619, 49, 
	50, 58, 46, 48, 57, 47, 46, 57, 
	48, 57, 9, 32, 40, 41, 2058, 2107, 
	2314, 2363, 2570, 2619, 48, 57, 1034, 896, 
	1151, 58, 46, 48, 58, 65, 70, 97, 
	102, 47, 46, 58, 65, 70, 97, 102, 
	48, 57, 9, 32, 40, 41, 1034, 1083, 
	48, 57, 9, 32, 40, 41, 1034, 1083, 
	48, 57, 65, 90, 97, 122, 9, 32, 
	40, 41, 1034, 1083, 9, 32, 40, 41, 
	1034, 1083, 48, 57, 9, 32, 40, 41, 
	1034, 1083, 48, 57, 9, 32, 40, 41, 
	1034, 1083, 48, 57, 65, 70, 97, 102, 
	48, 57, 65, 70, 97, 102, 9, 32, 
	40, 41, 2058, 2107, 2314, 2363, 2570, 2619, 
	48, 57, 65, 70, 97, 102, 1034, 896, 
	1151, 1034, 896, 1151, 1034, 896, 1151, 1034, 
	896, 1151, 48, 57, 9, 32, 40, 41, 
	1034, 1083, 48, 57, 9, 32, 40, 41, 
	1034, 1083, 48, 57, 9, 32, 40, 41, 
	1034, 1083, 48, 57, 9, 32, 40, 41, 
	1034, 1083, 48, 57, 65, 70, 97, 102, 
	48, 57, 65, 70, 97, 102, 9, 32, 
	40, 41, 2058, 2107, 2314, 2363, 2570, 2619, 
	48, 57, 65, 70, 97, 102, 1034, 896, 
	1151, 1034, 896, 1151, 1034, 896, 1151, 48, 
	57, 9, 32, 40, 41, 1034, 1083, 48, 
	57, 9, 32, 40, 41, 48, 49, 50, 
	51, 1034, 1083, 9, 32, 40, 41, 1034, 
	1083, 9, 32, 40, 41, 1034, 1083, 48, 
	57, 9, 32, 40, 41, 1034, 1083, 48, 
	57, 9, 32, 40, 41, 46, 1034, 1083, 
	6153, 6176, 6184, 6185, 6409, 6432, 6440, 6441, 
	6665, 6688, 6696, 6697, 9482, 9531, 9738, 9787, 
	10250, 10299, 10506, 10555, 10762, 10811, 11274, 11323, 
	11530, 11579, 11786, 11835, 12298, 12347, 12554, 12603, 
	12810, 12859, 3081, 3104, 3112, 3113, 3115, 4106, 
	4155, 3119, 3129, 3137, 3162, 3169, 3194, 1546, 
	1595, 4106, 3968, 4223, 4617, 4640, 4648, 4649, 
	13578, 13627, 13834, 13883, 14346, 14395, 14602, 14651, 
	14858, 14907, 5642, 5504, 5759, 3115, 6153, 6176, 
	6184, 6185, 6409, 6432, 6440, 6441, 6665, 6688, 
	6696, 6697, 9482, 9531, 9738, 9787, 10250, 10299, 
	10506, 10555, 10762, 10811, 11274, 11323, 11530, 11579, 
	11786, 11835, 12298, 12347, 12554, 12603, 12810, 12859, 
	3119, 3129, 3137, 3162, 3169, 3194, 7690, 8202, 
	8714, 7552, 7807, 8064, 8319, 8576, 8831, 1034, 
	896, 1151, 1034, 896, 1151, 9, 32, 40, 
	41, 1034, 1083, 9, 32, 40, 41, 1034, 
	1083, 48, 57, 9, 32, 40, 41, 1034, 
	1083, 48, 57, 9, 32, 40, 41, 46, 
	1034, 1083, 48, 57, 46, 6153, 6176, 6184, 
	6185, 6409, 6432, 6440, 6441, 6665, 6688, 6696, 
	6697, 9482, 9531, 9738, 9787, 10250, 10299, 10506, 
	10555, 10762, 10811, 11274, 11323, 11530, 11579, 11786, 
	11835, 12298, 12347, 12554, 12603, 12810, 12859, 48, 
	57, 1034, 896, 1151, 1034, 896, 1151, 9, 
	32, 40, 41, 1034, 1083, 9, 32, 40, 
	41, 1034, 1083, 48, 57, 9, 32, 40, 
	41, 1034, 1083, 48, 57, 9, 32, 40, 
	41, 46, 1034, 1083, 48, 58, 65, 70, 
	97, 102, 46, 6153, 6176, 6184, 6185, 6409, 
	6432, 6440, 6441, 6665, 6688, 6696, 6697, 9482, 
	9531, 9738, 9787, 10250, 10299, 10506, 10555, 10762, 
	10811, 11274, 11323, 11530, 11579, 11786, 11835, 12298, 
	12347, 12554, 12603, 12810, 12859, 48, 58, 65, 
	70, 97, 102, 1034, 896, 1151, 1034, 896, 
	1151, 9, 32, 40, 41, 1034, 1083, 9, 
	32, 40, 41, 1034, 1083, 48, 57, 9, 
	32, 40, 41, 1034, 1083, 48, 57, 9, 
	32, 40, 41, 42, 92, 95, 1034, 1083, 
	45, 57, 64, 90, 97, 122, 6153, 6176, 
	6184, 6185, 6409, 6432, 6440, 6441, 6665, 6688, 
	6696, 6697, 9482, 9531, 9738, 9787, 10250, 10299, 
	10506, 10555, 10762, 10811, 11274, 11323, 11530, 11579, 
	11786, 11835, 12298, 12347, 12554, 12603, 12810, 12859, 
	1034, 896, 1151, 1034, 896, 1151, 1034, 896, 
	1151, 65, 67, 68, 69, 72, 73, 75, 
	76, 77, 78, 80, 82, 83, 84, 97, 
	99, 100, 101, 104, 105, 107, 108, 109, 
	110, 112, 114, 115, 116, 9, 32, 40, 
	41, 65, 70, 80, 97, 102, 112, 1034, 
	1083, 9, 32, 40, 41, 1034, 1083, 48, 
	57, 65, 90, 97, 122, 9, 32, 40, 
	41, 1034, 1083, 9, 32, 40, 41, 1034, 
	1083, 48, 57, 9, 32, 40, 41, 1034, 
	1083, 48, 57, 9, 32, 40, 41, 1034, 
	1083, 48, 57, 9, 32, 40, 41, 1034, 
	1083, 48, 57, 9, 32, 40, 41, 1034, 
	1083, 48, 57, 9, 32, 40, 41, 1034, 
	1083, 48, 57, 9, 32, 40, 41, 1034, 
	1083, 48, 57, 9, 32, 40, 41, 1034, 
	1083, 48, 57, 9, 32, 40, 41, 1034, 
	1083, 48, 57, 9, 32, 40, 41, 1034, 
	1083, 48, 57, 9, 32, 40, 41, 42, 
	92, 95, 1034, 1083, 45, 57, 64, 90, 
	97, 122, 9, 32, 40, 41, 1034, 1083, 
	9, 32, 40, 41, 43, 1034, 1083, 47, 
	57, 65, 90, 97, 122, 1546, 1595, 1034, 
	896, 1151, 1034, 896, 1151, 1034, 896, 1151, 
	1034, 896, 1151, 1034, 896, 1151, 1034, 896, 
	1151, 1034, 896, 1151, 1034, 896, 1151, 65, 
	97, 65, 97, 9, 32, 40, 41, 1034, 
	1083, 83, 115, 68, 100, 66, 98, 9, 
	32, 40, 41, 1034, 1083, 76, 108, 9, 
	32, 40, 41, 1034, 1083, 69, 78, 101, 
	110, 82, 114, 84, 116, 9, 32, 40, 
	41, 1034, 1083, 65, 97, 77, 109, 69, 
	101, 9, 32, 40, 41, 1034, 1083, 72, 
	78, 83, 104, 110, 115, 67, 99, 73, 
	105, 68, 100, 9, 32, 40, 41, 1034, 
	1083, 65, 83, 97, 115, 77, 109, 69, 
	101, 9, 32, 40, 41, 1034, 1083, 75, 
	107, 69, 101, 89, 121, 9, 32, 40, 
	41, 1034, 1083, 9, 32, 40, 41, 1034, 
	1083, 85, 117, 73, 105, 52, 54, 56, 
	9, 32, 40, 41, 1034, 1083, 52, 9, 
	32, 40, 41, 1034, 1083, 73, 105, 78, 
	110, 70, 102, 79, 111, 9, 32, 40, 
	41, 1034, 1083, 80, 112, 83, 115, 69, 
	101, 67, 99, 75, 107, 69, 101, 89, 
	121, 9, 32, 40, 41, 1034, 1083, 69, 
	88, 101, 120, 89, 121, 9, 32, 40, 
	41, 1034, 1083, 9, 32, 40, 41, 1034, 
	1083, 79, 111, 67, 99, 9, 32, 40, 
	41, 1034, 1083, 73, 88, 105, 120, 78, 
	110, 70, 102, 79, 111, 9, 32, 40, 
	41, 1034, 1083, 9, 32, 40, 41, 1034, 
	1083, 65, 83, 97, 115, 80, 112, 84, 
	116, 82, 114, 9, 32, 40, 41, 1034, 
	1083, 9, 32, 40, 41, 69, 101, 1034, 
	1083, 67, 99, 9, 32, 40, 41, 51, 
	1034, 1083, 9, 32, 40, 41, 80, 112, 
	1034, 1083, 65, 97, 82, 114, 65, 97, 
	77, 109, 9, 32, 40, 41, 1034, 1083, 
	84, 116, 82, 114, 9, 32, 40, 41, 
	1034, 1083, 80, 82, 84, 112, 114, 116, 
	9, 32, 40, 41, 1034, 1083, 83, 115, 
	73, 105, 71, 103, 9, 32, 40, 41, 
	1034, 1083, 9, 32, 40, 41, 1034, 1083, 
	79, 80, 82, 83, 111, 112, 114, 115, 
	65, 97, 9, 32, 40, 41, 1034, 1083, 
	70, 102, 9, 32, 40, 41, 1034, 1083, 
	86, 118, 9, 32, 40, 41, 1034, 1083, 
	72, 104, 70, 102, 80, 112, 9, 32, 
	40, 41, 1034, 1083, 76, 88, 89, 108, 
	120, 121, 83, 115, 65, 97, 9, 32, 
	40, 41, 1034, 1083, 84, 116, 9, 32, 
	40, 41, 1034, 1083, 80, 112, 69, 101, 
	48, 57, 9, 32, 40, 41, 1034, 1083, 
	48, 57, 42, 92, 95, 45, 57, 64, 
	90, 97, 122, 32, 59, 9, 10, 40, 
	41, 32, 59, 9, 10, 40, 41, 48, 
	57, 9, 32, 40, 41, 1034, 1083, 48, 
	57, 9, 32, 40, 41, 1034, 1083, 48, 
	57, 9, 32, 40, 41, 1034, 1083, 48, 
	57, 9, 32, 40, 41, 1034, 1083, 48, 
	57, 65, 90, 97, 122, 9, 32, 40, 
	41, 1034, 1083, 9, 32, 40, 41, 43, 
	1034, 1083, 47, 57, 65, 90, 97, 122, 
	1546, 1595, 1034, 896, 1151, 1034, 896, 1151, 
	1034, 896, 1151, 43, 47, 57, 65, 90, 
	97, 122, 1546, 1595, 48, 57, 9, 32, 
	40, 41, 1034, 1083, 48, 57, 9, 32, 
	40, 41, 1034, 1083, 48, 57, 9, 32, 
	40, 41, 1034, 1083, 48, 57, 9, 32, 
	40, 41, 1034, 1083, 48, 57, 9, 32, 
	40, 41, 1034, 1083, 48, 57, 9, 32, 
	40, 41, 45, 1034, 1083, 48, 57, 65, 
	70, 97, 102, 9, 32, 40, 41, 1034, 
	1083, 9, 32, 40, 41, 1034, 1083, 48, 
	57, 65, 86, 97, 118, 48, 57, 65, 
	86, 97, 118, 61, 48, 57, 65, 86, 
	97, 118, 48, 57, 65, 86, 97, 118, 
	61, 48, 57, 65, 86, 97, 118, 61, 
	48, 57, 65, 86, 97, 118, 48, 57, 
	65, 86, 97, 118, 61, 48, 57, 65, 
	86, 97, 118, 32, 59, 9, 10, 40, 
	41, 48, 57, 65, 86, 97, 118, 32, 
	59, 9, 10, 40, 41, 61, 61, 61, 
	61, 61, 1034, 896, 1151, 48, 57, 65, 
	70, 97, 102, 9, 32, 40, 41, 1034, 
	1083, 48, 57, 65, 70, 97, 102, 1034, 
	896, 1151, 1034, 896, 1151, 1034, 896, 1151, 
	48, 57, 9, 32, 40, 41, 1034, 1083, 
	48, 57, 9, 32, 40, 41, 1034, 1083, 
	48, 57, 9, 32, 40, 41, 1034, 1083, 
	48, 57, 9, 32, 40, 41, 1034, 1083, 
	48, 57, 9, 32, 40, 41, 1034, 1083, 
	48, 57, 9, 32, 40, 41, 45, 1034, 
	1083, 48, 57, 65, 70, 97, 102, 32, 
	59, 9, 10, 40, 41, 48, 57, 65, 
	70, 97, 102, 32, 59, 9, 10, 40, 
	41, 48, 57, 65, 70, 97, 102, 1034, 
	896, 1151, 1034, 896, 1151, 1034, 896, 1151, 
	48, 57, 9, 32, 40, 41, 1034, 1083, 
	48, 57, 9, 32, 40, 41, 1034, 1083, 
	48, 57, 9, 32, 40, 41, 1034, 1083, 
	48, 57, 9, 32, 40, 41, 1034, 1083, 
	48, 57, 9, 32, 40, 41, 1034, 1083, 
	48, 57, 9, 32, 40, 41, 1034, 1083, 
	48, 57, 65, 70, 97, 102, 48, 57, 
	65, 70, 97, 102, 9, 32, 40, 41, 
	2058, 2107, 2314, 2363, 2570, 2619, 48, 57, 
	65, 70, 97, 102, 1034, 896, 1151, 1034, 
	896, 1151, 1034, 896, 1151, 1034, 896, 1151, 
	48, 57, 65, 70, 97, 102, 48, 57, 
	65, 70, 97, 102, 45, 48, 57, 65, 
	70, 97, 102, 48, 57, 65, 70, 97, 
	102, 32, 45, 59, 9, 10, 40, 41, 
	48, 57, 65, 70, 97, 102, 48, 57, 
	65, 70, 97, 102, 45, 48, 57, 65, 
	70, 97, 102, 48, 57, 65, 70, 97, 
	102, 32, 45, 59, 9, 10, 40, 41, 
	9, 32, 36, 40, 41, 42, 92, 95, 
	778, 827, 1034, 1083, 45, 57, 64, 90, 
	97, 122, 9, 32, 36, 40, 41, 42, 
	58, 92, 95, 1802, 1851, 2058, 2107, 2314, 
	2363, 2570, 2619, -128, 8, 11, 44, 45, 
	57, 60, 63, 64, 90, 91, 96, 97, 
	122, 123, 127, 9, 32, 36, 40, 41, 
	42, 65, 67, 68, 69, 72, 73, 75, 
	76, 77, 78, 80, 82, 83, 84, 92, 
	95, 97, 99, 100, 101, 104, 105, 107, 
	108, 109, 110, 112, 114, 115, 116, 778, 
	827, 1034, 1083, 45, 57, 64, 90, 98, 
	122, 9, 32, 36, 40, 41, 42, 65, 
	67, 68, 69, 72, 73, 75, 76, 77, 
	78, 80, 82, 83, 84, 92, 95, 97, 
	99, 100, 101, 104, 105, 107, 108, 109, 
	110, 112, 114, 115, 116, 778, 827, 1034, 
	1083, 45, 47, 48, 57, 64, 90, 98, 
	122, 9, 32, 36, 40, 41, 42, 92, 
	95, 778, 827, 1034, 1083, 45, 57, 64, 
	90, 97, 122, 9, 32, 36, 40, 41, 
	42, 65, 67, 68, 69, 72, 73, 75, 
	76, 77, 78, 80, 82, 83, 84, 92, 
	95, 97, 99, 100, 101, 104, 105, 107, 
	108, 109, 110, 112, 114, 115, 116, 778, 
	827, 1034, 1083, 45, 47, 48, 57, 64, 
	90, 98, 122, 9, 32, 36, 40, 41, 
	42, 92, 95, 778, 827, 1034, 1083, 45, 
	57, 64, 90, 97, 122, 9, 32, 36, 
	40, 41, 42, 58, 92, 95, 1802, 1851, 
	2058, 2107, 2314, 2363, 2570, 2619, -128, 8, 
	11, 44, 45, 57, 60, 63, 64, 90, 
	91, 96, 97, 122, 123, 127, 9, 32, 
	36, 40, 41, 42, 58, 65, 67, 68, 
	69, 72, 73, 75, 76, 77, 78, 80, 
	82, 83, 84, 92, 95, 97, 99, 100, 
	101, 104, 105, 107, 108, 109, 110, 112, 
	114, 115, 116, 1802, 1851, 2058, 2107, 2314, 
	2363, 2570, 2619, -128, 8, 11, 44, 45, 
	47, 48, 57, 60, 63, 64, 90, 91, 
	96, 98, 122, 123, 127, 9, 32, 36, 
	40, 41, 42, 58, 65, 67, 68, 69, 
	72, 73, 75, 76, 77, 78, 80, 82, 
	83, 84, 92, 95, 97, 99, 100, 101, 
	104, 105, 107, 108, 109, 110, 112, 114, 
	115, 116, 1802, 1851, 2058, 2107, 2314, 2363, 
	2570, 2619, -128, 8, 11, 44, 45, 47, 
	48, 57, 60, 63, 64, 90, 91, 96, 
	98, 122, 123, 127, 32, 33, 59, 92, 
	9, 10, 35, 39, 40, 41, 42, 126, 
	9, 32, 40, 41, 42, 46, 92, 95, 
	1034, 1083, 45, 57, 65, 90, 97, 122, 
	9, 32, 40, 41, 43, 2058, 2107, 2314, 
	2363, 2570, 2619, 47, 57, 65, 90, 97, 
	122, 1034, 896, 1151, 9, 32, 40, 41, 
	65, 67, 68, 69, 72, 73, 75, 76, 
	77, 78, 80, 82, 83, 84, 97, 99, 
	100, 101, 104, 105, 107, 108, 109, 110, 
	112, 114, 115, 116, 2058, 2107, 2314, 2363, 
	2570, 2619, 1034, 896, 1151, 9, 32, 40, 
	41, 2058, 2107, 2314, 2363, 2570, 2619, 48, 
	57, 65, 70, 97, 102, 1034, 896, 1151, 
	9, 32, 40, 41, 1034, 1083, 48, 57, 
	65, 70, 97, 102, 9, 32, 40, 41, 
	2058, 2107, 2314, 2363, 2570, 2619, 48, 57, 
	65, 70, 97, 102, 1034, 896, 1151, 1034, 
	896, 1151, 9, 32, 40, 41, 2058, 2107, 
	2314, 2363, 2570, 2619, -128, 8, 11, 58, 
	60, 127, 1034, 896, 1151, 9, 32, 40, 
	41, 2058, 2107, 2314, 2363, 2570, 2619, 1034, 
	896, 1151, 9, 32, 40, 41, 2058, 2107, 
	2314, 2363, 2570, 2619, 48, 57, 1034, 896, 
	1151, 9, 32, 40, 41, 2058, 2107, 2314, 
	2363, 2570, 2619, 48, 57, 1034, 896, 1151, 
	9, 32, 40, 41, 2058, 2107, 2314, 2363, 
	2570, 2619, 48, 57, 1034, 896, 1151, 9, 
	32, 33, 40, 41, 49, 50, 2058, 2107, 
	2314, 2363, 2570, 2619, 1034, 896, 1151, 9, 
	32, 40, 41, 2058, 2107, 2314, 2363, 2570, 
	2619, 48, 57, 65, 70, 97, 102, 1034, 
	896, 1151, 9, 32, 40, 41, 2058, 2107, 
	2314, 2363, 2570, 2619, 48, 57, 65, 70, 
	97, 102, 1034, 896, 1151, 4617, 4640, 4648, 
	4649, 13578, 13627, 13834, 13883, 14346, 14395, 14602, 
	14651, 14858, 14907, 5642, 5504, 5759, 3081, 3104, 
	3112, 3113, 3115, 4106, 4155, 3119, 3129, 3137, 
	3162, 3169, 3194, 4106, 3968, 4223, 3115, 6153, 
	6176, 6184, 6185, 6409, 6432, 6440, 6441, 6665, 
	6688, 6696, 6697, 9482, 9531, 9738, 9787, 10250, 
	10299, 10506, 10555, 10762, 10811, 11274, 11323, 11530, 
	11579, 11786, 11835, 12298, 12347, 12554, 12603, 12810, 
	12859, 3119, 3129, 3137, 3162, 3169, 3194, 7690, 
	8202, 8714, 7552, 7807, 8064, 8319, 8576, 8831, 
	9, 32, 40, 41, 2058, 2107, 2314, 2363, 
	2570, 2619, 48, 57, 65, 70, 97, 102, 
	1034, 896, 1151, 0
};

static const char _zone_scanner_single_lengths[] = {
	0, 36, 16, 34, 16, 11, 8, 8, 
	1, 1, 8, 1, 13, 2, 42, 18, 
	36, 4, 2, 2, 10, 12, 2, 2, 
	2, 10, 6, 2, 2, 2, 10, 4, 
	2, 2, 10, 2, 2, 2, 10, 10, 
	2, 2, 2, 1, 10, 1, 10, 2, 
	2, 2, 2, 10, 4, 6, 34, 2, 
	2, 2, 2, 2, 2, 2, 10, 4, 
	2, 10, 10, 2, 2, 10, 4, 2, 
	2, 2, 10, 10, 4, 2, 2, 2, 
	10, 12, 2, 11, 12, 2, 2, 2, 
	2, 10, 2, 2, 10, 6, 10, 2, 
	2, 2, 10, 10, 8, 2, 10, 2, 
	10, 2, 10, 2, 2, 2, 10, 6, 
	2, 2, 10, 2, 10, 2, 2, 0, 
	10, 1, 36, 4, 6, 34, 16, 6, 
	10, 6, 1, 1, 6, 2, 2, 2, 
	2, 2, 2, 2, 6, 34, 1, 16, 
	34, 1, 6, 10, 6, 1, 16, 40, 
	18, 13, 36, 2, 8, 8, 42, 12, 
	14, 10, 10, 12, 12, 10, 12, 12, 
	10, 14, 16, 14, 2, 14, 2, 2, 
	2, 2, 2, 2, 2, 2, 2, 8, 
	18, 36, 2, 18, 42, 12, 14, 10, 
	10, 12, 12, 10, 12, 12, 10, 14, 
	16, 14, 9, 36, 12, 12, 10, 2, 
	2, 10, 2, 2, 2, 10, 2, 10, 
	2, 8, 8, 12, 10, 1, 12, 10, 
	12, 8, 8, 10, 10, 8, 10, 10, 
	8, 12, 14, 12, 2, 2, 10, 2, 
	1, 1, 5, 3, 6, 5, 0, 0, 
	0, 5, 2, 2, 2, 4, 0, 0, 
	0, 4, 4, 2, 0, 0, 0, 4, 
	6, 6, 18, 8, 1, 8, 10, 8, 
	1, 6, 10, 1, 12, 8, 1, 3, 
	0, 0, 0, 3, 8, 1, 6, 6, 
	8, 12, 1, 12, 8, 1, 3, 0, 
	0, 0, 3, 8, 2, 10, 1, 1, 
	1, 1, 2, 2, 11, 1, 1, 10, 
	38, 16, 2, 2, 10, 1, 4, 2, 
	2, 10, 2, 2, 2, 10, 6, 2, 
	2, 2, 10, 4, 2, 2, 10, 2, 
	2, 2, 10, 10, 2, 2, 2, 1, 
	10, 1, 10, 2, 2, 2, 2, 10, 
	2, 2, 2, 2, 2, 2, 2, 10, 
	4, 2, 10, 10, 2, 2, 10, 4, 
	2, 2, 2, 10, 10, 4, 2, 2, 
	2, 10, 12, 2, 11, 12, 2, 2, 
	2, 2, 10, 2, 2, 10, 6, 10, 
	2, 2, 2, 10, 10, 8, 2, 10, 
	2, 10, 2, 10, 2, 2, 2, 10, 
	6, 2, 2, 10, 2, 10, 2, 2, 
	0, 10, 2, 2, 2, 10, 2, 10, 
	6, 6, 6, 6, 0, 10, 1, 1, 
	1, 6, 7, 8, 6, 0, 10, 1, 
	1, 6, 1, 10, 2, 4, 2, 2, 
	3, 2, 2, 2, 2, 1, 1, 2, 
	2, 2, 1, 2, 2, 4, 1, 2, 
	2, 2, 2, 2, 2, 2, 2, 2, 
	1, 1, 2, 2, 2, 1, 1, 1, 
	2, 1, 1, 2, 2, 2, 1, 1, 
	1, 2, 2, 2, 2, 2, 2, 2, 
	2, 2, 2, 2, 2, 2, 2, 2, 
	4, 2, 2, 2, 2, 2, 2, 2, 
	2, 4, 2, 1, 2, 2, 2, 3, 
	3, 2, 2, 2, 2, 1, 1, 2, 
	2, 2, 1, 2, 1, 1, 2, 1, 
	1, 2, 12, 2, 2, 2, 2, 2, 
	2, 2, 6, 2, 2, 2, 2, 2, 
	2, 4, 2, 2, 2, 2, 2, 2, 
	2, 2, 2, 2, 2, 2, 4, 2, 
	2, 2, 2, 2, 2, 2, 2, 2, 
	2, 2, 2, 1, 3, 3, 2, 3, 
	6, 9, 6, 6, 6, 6, 16, 6, 
	16, 6, 16, 6, 12, 2, 10, 2, 
	1, 6, 10, 6, 1, 6, 10, 6, 
	1, 6, 10, 6, 1, 1, 1, 2, 
	6, 6, 2, 1, 3, 6, 9, 2, 
	1, 0, 6, 9, 2, 1, 2, 10, 
	10, 1, 1, 3, 0, 6, 8, 6, 
	8, 7, 8, 6, 6, 6, 8, 6, 
	8, 7, 8, 6, 7, 0, 12, 10, 
	12, 10, 12, 10, 12, 10, 1, 11, 
	11, 1, 11, 11, 10, 1, 11, 11, 
	10, 1, 11, 11, 10, 1, 6, 1, 
	6, 6, 1, 1, 1, 6, 1, 6, 
	6, 1, 1, 0, 6, 6, 6, 6, 
	6, 9, 2, 1, 1, 1, 0, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	9, 2, 1, 1, 1, 1, 1, 0, 
	6, 6, 6, 6, 6, 7, 2, 1, 
	1, 1, 13, 2, 1, 1, 1, 0, 
	10, 1, 1, 1, 1, 0, 6, 6, 
	6, 6, 6, 6, 0, 10, 1, 1, 
	1, 1, 0, 6, 6, 6, 6, 0, 
	10, 1, 1, 1, 0, 6, 10, 6, 
	6, 6, 7, 34, 7, 2, 1, 14, 
	1, 35, 3, 1, 1, 6, 6, 6, 
	7, 35, 1, 1, 6, 6, 6, 7, 
	35, 1, 1, 6, 6, 6, 9, 34, 
	1, 1, 1, 28, 12, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 9, 6, 7, 2, 1, 1, 1, 
	1, 1, 1, 1, 1, 2, 2, 6, 
	2, 2, 2, 6, 2, 6, 4, 2, 
	2, 6, 2, 2, 2, 6, 6, 2, 
	2, 2, 6, 4, 2, 2, 6, 2, 
	2, 2, 6, 6, 2, 2, 2, 1, 
	6, 1, 6, 2, 2, 2, 2, 6, 
	2, 2, 2, 2, 2, 2, 2, 6, 
	4, 2, 6, 6, 2, 2, 6, 4, 
	2, 2, 2, 6, 6, 4, 2, 2, 
	2, 6, 8, 2, 7, 8, 2, 2, 
	2, 2, 6, 2, 2, 6, 6, 6, 
	2, 2, 2, 6, 6, 8, 2, 6, 
	2, 6, 2, 6, 2, 2, 2, 6, 
	6, 2, 2, 6, 2, 6, 2, 2, 
	0, 6, 3, 2, 2, 0, 6, 6, 
	6, 6, 6, 7, 2, 1, 1, 1, 
	1, 2, 0, 6, 6, 6, 6, 6, 
	7, 6, 6, 0, 1, 0, 1, 1, 
	0, 1, 2, 2, 1, 1, 1, 1, 
	1, 1, 0, 6, 1, 1, 1, 0, 
	6, 6, 6, 6, 6, 7, 2, 0, 
	2, 1, 1, 1, 0, 6, 6, 6, 
	6, 6, 6, 0, 10, 1, 1, 1, 
	1, 0, 0, 1, 0, 0, 3, 0, 
	0, 1, 0, 0, 3, 12, 17, 40, 
	40, 12, 40, 12, 17, 45, 45, 0, 
	0, 0, 4, 0, 0, 0, 10, 0, 
	11, 1, 0, 38, 1, 0, 10, 1, 
	6, 0, 10, 1, 1, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 10, 1, 
	0, 0, 10, 1, 10, 1, 10, 1, 
	10, 1, 0, 0, 0, 0, 13, 1, 
	0, 10, 1, 0, 10, 1, 0, 14, 
	1, 7, 1, 35, 3, 0, 0, 0, 
	0, 0, 0, 0, 10, 1, 0, 0
};

static const char _zone_scanner_range_lengths[] = {
	0, 1, 1, 0, 0, 3, 0, 0, 
	0, 0, 0, 1, 3, 2, 4, 1, 
	0, 0, 0, 0, 0, 1, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 1, 
	1, 1, 1, 0, 0, 1, 1, 1, 
	1, 1, 1, 0, 0, 0, 0, 0, 
	0, 0, 0, 2, 0, 1, 1, 1, 
	1, 1, 1, 1, 1, 1, 0, 4, 
	0, 3, 1, 2, 3, 3, 4, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 2, 0, 0, 0, 
	0, 0, 0, 2, 0, 0, 2, 0, 
	1, 1, 2, 0, 4, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 3, 1, 1, 1, 2, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	2, 3, 3, 2, 2, 1, 1, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 2, 2, 0, 2, 
	0, 0, 3, 2, 5, 5, 1, 1, 
	1, 5, 2, 2, 2, 4, 1, 1, 
	1, 4, 1, 2, 1, 1, 1, 1, 
	0, 1, 1, 0, 0, 1, 1, 1, 
	1, 0, 3, 0, 3, 0, 0, 3, 
	1, 1, 1, 3, 0, 1, 0, 3, 
	0, 3, 0, 3, 0, 0, 3, 1, 
	1, 1, 3, 0, 2, 3, 1, 1, 
	3, 3, 3, 3, 3, 1, 0, 0, 
	0, 0, 0, 0, 0, 1, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	1, 1, 0, 0, 0, 0, 0, 0, 
	0, 1, 1, 3, 3, 3, 1, 1, 
	1, 0, 1, 1, 3, 3, 3, 1, 
	1, 1, 1, 1, 3, 0, 2, 0, 
	2, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 2, 0, 0, 0, 0, 
	0, 0, 0, 2, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	2, 0, 0, 0, 0, 0, 0, 0, 
	0, 2, 0, 0, 0, 0, 0, 0, 
	0, 2, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 2, 0, 0, 2, 0, 
	0, 0, 0, 0, 2, 0, 0, 0, 
	2, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 2, 0, 0, 2, 0, 
	0, 2, 1, 3, 0, 0, 0, 0, 
	0, 2, 0, 0, 0, 0, 0, 0, 
	2, 0, 0, 2, 0, 0, 2, 0, 
	0, 0, 2, 0, 0, 2, 0, 0, 
	2, 0, 0, 2, 0, 0, 0, 2, 
	0, 0, 2, 1, 3, 3, 2, 3, 
	0, 3, 0, 1, 1, 1, 1, 1, 
	1, 1, 1, 1, 3, 3, 1, 3, 
	1, 1, 1, 1, 1, 1, 1, 1, 
	1, 1, 1, 1, 1, 1, 1, 2, 
	0, 3, 2, 1, 3, 0, 3, 2, 
	1, 1, 1, 3, 2, 1, 2, 0, 
	3, 1, 3, 5, 1, 1, 1, 1, 
	1, 1, 0, 0, 1, 1, 1, 1, 
	1, 1, 0, 0, 1, 1, 1, 1, 
	1, 1, 1, 1, 1, 0, 1, 1, 
	1, 1, 1, 1, 0, 1, 1, 1, 
	0, 1, 1, 1, 0, 1, 0, 1, 
	1, 1, 1, 1, 1, 0, 1, 1, 
	1, 1, 1, 1, 1, 1, 1, 1, 
	1, 3, 2, 1, 1, 1, 1, 1, 
	1, 1, 3, 0, 3, 0, 3, 0, 
	3, 2, 1, 1, 1, 1, 1, 3, 
	0, 1, 1, 3, 0, 3, 0, 1, 
	1, 1, 0, 0, 0, 1, 1, 1, 
	1, 1, 0, 3, 3, 1, 1, 3, 
	0, 1, 1, 3, 3, 3, 1, 1, 
	1, 1, 1, 1, 1, 1, 3, 3, 
	3, 1, 1, 1, 1, 1, 0, 0, 
	1, 1, 0, 0, 3, 0, 1, 0, 
	1, 3, 3, 1, 1, 0, 1, 1, 
	1, 1, 1, 1, 0, 1, 1, 3, 
	3, 1, 1, 0, 1, 1, 3, 0, 
	1, 1, 1, 0, 0, 3, 0, 1, 
	1, 1, 1, 1, 1, 1, 1, 1, 
	1, 3, 0, 3, 0, 1, 1, 1, 
	1, 1, 1, 1, 1, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	1, 1, 3, 2, 2, 1, 1, 1, 
	1, 3, 0, 3, 0, 1, 1, 1, 
	3, 0, 1, 1, 1, 1, 1, 1, 
	3, 0, 3, 3, 3, 3, 3, 3, 
	3, 3, 5, 2, 0, 0, 0, 0, 
	0, 1, 3, 3, 1, 1, 1, 1, 
	1, 1, 1, 1, 1, 3, 2, 3, 
	5, 1, 1, 1, 1, 1, 1, 1, 
	1, 1, 3, 3, 3, 1, 1, 1, 
	1, 3, 3, 0, 3, 3, 2, 3, 
	3, 0, 3, 3, 2, 3, 8, 3, 
	4, 3, 4, 3, 8, 9, 9, 0, 
	0, 0, 4, 0, 0, 0, 3, 0, 
	3, 1, 0, 0, 1, 0, 3, 1, 
	3, 0, 3, 1, 1, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 3, 1, 
	0, 0, 0, 1, 1, 1, 1, 1, 
	1, 1, 0, 0, 0, 0, 0, 1, 
	0, 3, 1, 0, 3, 1, 0, 0, 
	1, 3, 1, 3, 3, 0, 0, 0, 
	0, 0, 0, 0, 3, 1, 0, 0
};

static const short _zone_scanner_index_offsets[] = {
	0, 0, 38, 56, 91, 108, 123, 132, 
	141, 143, 145, 154, 157, 174, 179, 226, 
	246, 283, 288, 291, 294, 305, 319, 322, 
	325, 328, 339, 346, 349, 352, 355, 366, 
	371, 374, 377, 388, 391, 394, 397, 408, 
	419, 422, 425, 428, 430, 441, 443, 454, 
	457, 460, 463, 466, 477, 482, 489, 524, 
	527, 530, 533, 536, 539, 542, 545, 556, 
	561, 564, 575, 586, 589, 592, 603, 608, 
	611, 614, 617, 628, 639, 644, 647, 650, 
	653, 664, 677, 680, 692, 705, 708, 711, 
	714, 717, 728, 731, 734, 745, 752, 763, 
	766, 769, 772, 783, 794, 803, 806, 817, 
	820, 831, 834, 845, 848, 851, 854, 865, 
	872, 875, 878, 889, 892, 903, 906, 909, 
	911, 923, 926, 964, 969, 976, 1012, 1030, 
	1038, 1050, 1058, 1061, 1063, 1070, 1073, 1076, 
	1079, 1082, 1085, 1088, 1093, 1100, 1136, 1139, 
	1157, 1193, 1196, 1204, 1216, 1224, 1227, 1244, 
	1289, 1308, 1325, 1363, 1368, 1380, 1392, 1439, 
	1452, 1467, 1478, 1489, 1502, 1515, 1526, 1539, 
	1552, 1563, 1578, 1595, 1610, 1615, 1630, 1633, 
	1636, 1639, 1642, 1645, 1650, 1653, 1656, 1661, 
	1670, 1690, 1728, 1733, 1752, 1799, 1812, 1827, 
	1838, 1849, 1862, 1875, 1886, 1899, 1912, 1923, 
	1938, 1955, 1970, 1983, 2021, 2035, 2049, 2062, 
	2065, 2068, 2079, 2082, 2085, 2088, 2099, 2102, 
	2113, 2118, 2130, 2142, 2157, 2170, 2173, 2187, 
	2198, 2211, 2220, 2229, 2240, 2251, 2260, 2271, 
	2282, 2291, 2304, 2319, 2332, 2337, 2342, 2353, 
	2358, 2360, 2362, 2371, 2377, 2389, 2400, 2402, 
	2404, 2406, 2417, 2422, 2427, 2432, 2441, 2443, 
	2445, 2447, 2456, 2462, 2467, 2469, 2471, 2473, 
	2479, 2486, 2494, 2514, 2523, 2525, 2535, 2547, 
	2557, 2560, 2567, 2581, 2583, 2599, 2608, 2610, 
	2617, 2619, 2621, 2623, 2630, 2639, 2642, 2649, 
	2659, 2668, 2684, 2686, 2702, 2711, 2713, 2720, 
	2722, 2724, 2726, 2733, 2742, 2747, 2761, 2764, 
	2767, 2772, 2777, 2783, 2789, 2804, 2807, 2809, 
	2820, 2859, 2876, 2879, 2882, 2893, 2896, 2901, 
	2904, 2907, 2918, 2921, 2924, 2927, 2938, 2945, 
	2948, 2951, 2954, 2965, 2970, 2973, 2976, 2987, 
	2990, 2993, 2996, 3007, 3018, 3021, 3024, 3027, 
	3029, 3040, 3042, 3053, 3056, 3059, 3062, 3065, 
	3076, 3079, 3082, 3085, 3088, 3091, 3094, 3097, 
	3108, 3113, 3116, 3127, 3138, 3141, 3144, 3155, 
	3160, 3163, 3166, 3169, 3180, 3191, 3196, 3199, 
	3202, 3205, 3216, 3229, 3232, 3244, 3257, 3260, 
	3263, 3266, 3269, 3280, 3283, 3286, 3297, 3304, 
	3315, 3318, 3321, 3324, 3335, 3346, 3355, 3358, 
	3369, 3372, 3383, 3386, 3397, 3400, 3403, 3406, 
	3417, 3424, 3427, 3430, 3441, 3444, 3455, 3458, 
	3461, 3463, 3475, 3478, 3481, 3484, 3495, 3498, 
	3509, 3516, 3524, 3532, 3542, 3546, 3560, 3563, 
	3566, 3569, 3576, 3585, 3595, 3605, 3609, 3623, 
	3626, 3629, 3637, 3640, 3652, 3658, 3663, 3668, 
	3671, 3677, 3680, 3683, 3686, 3689, 3691, 3693, 
	3696, 3699, 3702, 3704, 3709, 3712, 3717, 3719, 
	3722, 3725, 3728, 3731, 3736, 3739, 3742, 3745, 
	3748, 3750, 3752, 3755, 3758, 3761, 3763, 3765, 
	3767, 3772, 3774, 3776, 3779, 3782, 3785, 3787, 
	3789, 3791, 3796, 3799, 3802, 3805, 3808, 3811, 
	3814, 3817, 3822, 3825, 3828, 3831, 3834, 3837, 
	3840, 3845, 3848, 3851, 3856, 3859, 3862, 3867, 
	3870, 3873, 3878, 3881, 3883, 3888, 3891, 3894, 
	3898, 3904, 3907, 3910, 3913, 3916, 3918, 3920, 
	3923, 3926, 3929, 3931, 3936, 3938, 3940, 3945, 
	3947, 3949, 3954, 3968, 3974, 3977, 3980, 3983, 
	3986, 3989, 3994, 4001, 4004, 4007, 4010, 4013, 
	4016, 4021, 4026, 4029, 4034, 4037, 4040, 4045, 
	4048, 4051, 4054, 4059, 4062, 4065, 4070, 4075, 
	4078, 4083, 4086, 4089, 4094, 4097, 4100, 4103, 
	4108, 4111, 4114, 4119, 4122, 4129, 4136, 4141, 
	4148, 4155, 4168, 4175, 4183, 4191, 4199, 4217, 
	4225, 4243, 4251, 4269, 4277, 4293, 4299, 4311, 
	4317, 4320, 4328, 4340, 4348, 4351, 4359, 4371, 
	4379, 4382, 4390, 4402, 4410, 4413, 4416, 4419, 
	4424, 4431, 4441, 4446, 4449, 4456, 4463, 4476, 
	4481, 4484, 4486, 4494, 4507, 4512, 4515, 4520, 
	4531, 4545, 4548, 4553, 4562, 4564, 4572, 4582, 
	4590, 4600, 4609, 4618, 4625, 4633, 4641, 4651, 
	4659, 4669, 4678, 4687, 4694, 4703, 4705, 4719, 
	4731, 4745, 4757, 4771, 4783, 4797, 4808, 4811, 
	4824, 4837, 4840, 4853, 4866, 4877, 4880, 4893, 
	4906, 4917, 4920, 4933, 4946, 4957, 4960, 4967, 
	4970, 4978, 4986, 4989, 4992, 4995, 5002, 5005, 
	5013, 5021, 5024, 5027, 5029, 5037, 5045, 5053, 
	5061, 5069, 5082, 5087, 5090, 5093, 5096, 5098, 
	5106, 5114, 5122, 5132, 5139, 5149, 5156, 5166, 
	5173, 5186, 5191, 5194, 5197, 5200, 5203, 5206, 
	5210, 5217, 5225, 5233, 5243, 5250, 5261, 5264, 
	5267, 5270, 5273, 5287, 5290, 5292, 5295, 5298, 
	5300, 5312, 5315, 5317, 5322, 5327, 5329, 5337, 
	5347, 5354, 5362, 5370, 5380, 5384, 5398, 5401, 
	5404, 5407, 5410, 5412, 5420, 5428, 5436, 5446, 
	5450, 5464, 5467, 5470, 5473, 5475, 5483, 5494, 
	5501, 5509, 5517, 5525, 5560, 5571, 5574, 5577, 
	5592, 5595, 5634, 5641, 5644, 5647, 5654, 5662, 
	5670, 5679, 5716, 5719, 5722, 5729, 5737, 5745, 
	5756, 5795, 5798, 5801, 5808, 5816, 5824, 5837, 
	5872, 5875, 5878, 5881, 5910, 5923, 5933, 5940, 
	5948, 5956, 5964, 5972, 5980, 5988, 5996, 6004, 
	6012, 6020, 6033, 6040, 6051, 6054, 6057, 6060, 
	6063, 6066, 6069, 6072, 6075, 6078, 6081, 6084, 
	6091, 6094, 6097, 6100, 6107, 6110, 6117, 6122, 
	6125, 6128, 6135, 6138, 6141, 6144, 6151, 6158, 
	6161, 6164, 6167, 6174, 6179, 6182, 6185, 6192, 
	6195, 6198, 6201, 6208, 6215, 6218, 6221, 6224, 
	6226, 6233, 6235, 6242, 6245, 6248, 6251, 6254, 
	6261, 6264, 6267, 6270, 6273, 6276, 6279, 6282, 
	6289, 6294, 6297, 6304, 6311, 6314, 6317, 6324, 
	6329, 6332, 6335, 6338, 6345, 6352, 6357, 6360, 
	6363, 6366, 6373, 6382, 6385, 6393, 6402, 6405, 
	6408, 6411, 6414, 6421, 6424, 6427, 6434, 6441, 
	6448, 6451, 6454, 6457, 6464, 6471, 6480, 6483, 
	6490, 6493, 6500, 6503, 6510, 6513, 6516, 6519, 
	6526, 6533, 6536, 6539, 6546, 6549, 6556, 6559, 
	6562, 6564, 6572, 6579, 6584, 6589, 6591, 6599, 
	6607, 6615, 6625, 6632, 6643, 6646, 6649, 6652, 
	6655, 6660, 6663, 6665, 6673, 6681, 6689, 6697, 
	6705, 6716, 6723, 6733, 6737, 6742, 6746, 6751, 
	6756, 6760, 6765, 6773, 6778, 6780, 6782, 6784, 
	6786, 6788, 6791, 6795, 6805, 6808, 6811, 6814, 
	6816, 6824, 6832, 6840, 6848, 6856, 6867, 6872, 
	6876, 6884, 6887, 6890, 6893, 6895, 6903, 6911, 
	6919, 6927, 6935, 6945, 6949, 6963, 6966, 6969, 
	6972, 6975, 6979, 6983, 6985, 6989, 6993, 6999, 
	7003, 7007, 7009, 7013, 7017, 7023, 7039, 7065, 
	7109, 7154, 7170, 7215, 7231, 7257, 7312, 7367, 
	7368, 7369, 7370, 7379, 7380, 7381, 7382, 7396, 
	7397, 7412, 7415, 7416, 7455, 7458, 7459, 7473, 
	7476, 7486, 7487, 7501, 7504, 7507, 7508, 7509, 
	7510, 7511, 7512, 7513, 7514, 7515, 7516, 7530, 
	7533, 7534, 7535, 7546, 7549, 7561, 7564, 7576, 
	7579, 7591, 7594, 7595, 7596, 7597, 7598, 7612, 
	7615, 7616, 7630, 7633, 7634, 7648, 7651, 7652, 
	7667, 7670, 7681, 7684, 7723, 7730, 7731, 7732, 
	7733, 7734, 7735, 7736, 7737, 7751, 7754, 7755
};

static const short _zone_scanner_indicies[] = {
	1, 1, 2, 3, 5, 6, 7, 8, 
	9, 10, 11, 12, 13, 14, 15, 16, 
	17, 18, 5, 6, 7, 8, 9, 10, 
	11, 12, 13, 14, 15, 16, 17, 18, 
	19, 20, 21, 22, 4, 0, 24, 24, 
	25, 26, 28, 29, 30, 31, 32, 28, 
	29, 30, 31, 32, 33, 34, 27, 23, 
	36, 36, 37, 38, 39, 40, 41, 42, 
	43, 44, 45, 46, 47, 48, 49, 50, 
	51, 52, 39, 40, 41, 42, 43, 44, 
	45, 46, 47, 48, 49, 50, 51, 52, 
	53, 54, 35, 56, 56, 57, 58, 59, 
	60, 61, 59, 60, 61, 62, 63, 64, 
	64, 65, 66, 55, 68, 68, 70, 71, 
	72, 73, 74, 75, 75, 76, 77, 67, 
	67, 67, 69, 79, 79, 80, 81, 82, 
	83, 82, 83, 78, 85, 85, 86, 87, 
	88, 89, 88, 89, 84, 88, 89, 91, 
	90, 85, 85, 86, 87, 88, 89, 88, 
	89, 78, 73, 74, 69, 92, 92, 93, 
	94, 72, 88, 89, 88, 95, 96, 97, 
	88, 98, 67, 67, 67, 78, 88, 99, 
	89, 95, 78, 100, 100, 102, 103, 67, 
	105, 106, 107, 108, 109, 110, 111, 112, 
	113, 114, 115, 116, 117, 118, 72, 105, 
	106, 107, 108, 109, 110, 111, 112, 113, 
	114, 115, 116, 117, 118, 19, 20, 119, 
	120, 121, 122, 123, 124, 67, 67, 104, 
	67, 101, 126, 126, 127, 128, 28, 29, 
	30, 31, 32, 28, 29, 30, 31, 32, 
	82, 83, 129, 130, 27, 125, 132, 132, 
	133, 134, 39, 40, 41, 42, 43, 44, 
	45, 46, 47, 48, 49, 50, 51, 52, 
	39, 40, 41, 42, 43, 44, 45, 46, 
	47, 48, 49, 50, 51, 52, 88, 89, 
	135, 136, 131, 137, 138, 137, 138, 35, 
	139, 139, 35, 140, 140, 35, 141, 141, 
	142, 143, 144, 145, 146, 146, 147, 148, 
	55, 85, 88, 85, 86, 87, 89, 149, 
	88, 149, 150, 151, 95, 74, 78, 152, 
	152, 35, 153, 153, 35, 154, 154, 35, 
	155, 155, 156, 157, 158, 159, 160, 160, 
	161, 162, 55, 163, 164, 165, 163, 164, 
	165, 35, 166, 166, 35, 167, 167, 35, 
	168, 168, 35, 169, 169, 170, 171, 172, 
	173, 174, 174, 175, 176, 55, 177, 178, 
	177, 178, 35, 179, 179, 35, 180, 180, 
	35, 181, 181, 182, 183, 184, 185, 186, 
	186, 187, 188, 55, 189, 189, 35, 190, 
	190, 35, 191, 191, 35, 192, 192, 193, 
	194, 195, 196, 197, 197, 198, 199, 55, 
	200, 200, 201, 202, 203, 204, 205, 205, 
	206, 207, 55, 208, 208, 35, 209, 209, 
	35, 210, 211, 35, 212, 35, 213, 213, 
	214, 215, 216, 217, 218, 218, 219, 220, 
	55, 221, 35, 222, 222, 223, 224, 225, 
	226, 227, 227, 228, 229, 55, 230, 230, 
	35, 231, 231, 35, 232, 232, 35, 233, 
	233, 35, 234, 234, 235, 236, 237, 238, 
	239, 239, 240, 241, 55, 242, 243, 242, 
	243, 35, 244, 244, 245, 246, 247, 248, 
	35, 249, 249, 250, 251, 252, 253, 254, 
	255, 256, 257, 258, 259, 260, 261, 262, 
	263, 264, 265, 252, 253, 254, 255, 256, 
	257, 258, 259, 260, 261, 262, 263, 264, 
	265, 266, 267, 35, 243, 243, 35, 268, 
	268, 35, 269, 269, 35, 270, 270, 35, 
	271, 271, 35, 272, 272, 35, 273, 273, 
	35, 274, 274, 275, 276, 277, 278, 279, 
	279, 280, 281, 55, 282, 283, 282, 283, 
	35, 284, 284, 35, 285, 285, 286, 287, 
	288, 289, 290, 290, 291, 292, 55, 293, 
	293, 294, 295, 296, 297, 298, 298, 299, 
	300, 55, 301, 301, 35, 302, 302, 35, 
	303, 303, 304, 305, 306, 307, 308, 308, 
	309, 310, 55, 311, 312, 311, 312, 35, 
	313, 313, 35, 314, 314, 35, 315, 315, 
	35, 316, 316, 317, 318, 319, 320, 321, 
	321, 322, 323, 55, 324, 324, 325, 326, 
	327, 328, 329, 329, 330, 331, 55, 332, 
	333, 332, 333, 35, 334, 334, 35, 335, 
	335, 35, 336, 336, 35, 337, 337, 338, 
	339, 340, 341, 342, 342, 343, 344, 55, 
	345, 345, 346, 347, 348, 348, 349, 350, 
	351, 351, 352, 353, 55, 354, 354, 35, 
	355, 355, 356, 357, 358, 359, 360, 361, 
	361, 362, 363, 55, 364, 364, 365, 366, 
	367, 367, 368, 369, 370, 370, 371, 372, 
	55, 373, 373, 35, 374, 374, 35, 375, 
	375, 35, 376, 376, 35, 377, 377, 378, 
	379, 380, 381, 382, 382, 383, 384, 55, 
	385, 385, 35, 386, 386, 35, 387, 387, 
	388, 389, 390, 391, 392, 392, 393, 394, 
	55, 395, 396, 397, 395, 396, 397, 35, 
	398, 398, 399, 400, 401, 402, 403, 403, 
	404, 405, 55, 406, 406, 35, 407, 407, 
	35, 408, 408, 35, 409, 409, 410, 411, 
	412, 413, 414, 414, 415, 416, 55, 417, 
	417, 418, 419, 420, 421, 422, 422, 423, 
	424, 55, 425, 426, 427, 428, 425, 426, 
	427, 428, 35, 429, 429, 35, 430, 430, 
	431, 432, 433, 434, 435, 435, 436, 437, 
	55, 438, 438, 35, 439, 439, 440, 441, 
	442, 443, 444, 444, 445, 446, 55, 447, 
	447, 35, 448, 448, 449, 450, 451, 452, 
	453, 453, 454, 455, 55, 456, 456, 35, 
	457, 457, 35, 458, 458, 35, 459, 459, 
	460, 461, 462, 463, 464, 464, 465, 466, 
	55, 467, 468, 469, 467, 468, 469, 35, 
	470, 470, 35, 471, 471, 35, 472, 472, 
	473, 474, 475, 476, 477, 477, 478, 479, 
	55, 480, 480, 35, 481, 481, 482, 483, 
	484, 485, 486, 486, 487, 488, 55, 489, 
	489, 35, 490, 490, 35, 492, 491, 494, 
	494, 495, 496, 498, 499, 500, 500, 501, 
	502, 497, 493, 266, 267, 35, 503, 503, 
	504, 505, 5, 6, 7, 8, 9, 10, 
	11, 12, 13, 14, 15, 16, 17, 18, 
	5, 6, 7, 8, 9, 10, 11, 12, 
	13, 14, 15, 16, 17, 18, 19, 20, 
	506, 507, 4, 0, 508, 243, 508, 243, 
	35, 509, 509, 510, 511, 512, 513, 35, 
	514, 514, 515, 516, 518, 519, 520, 521, 
	522, 523, 524, 525, 526, 527, 528, 529, 
	530, 531, 518, 519, 520, 521, 522, 523, 
	524, 525, 526, 527, 528, 529, 530, 531, 
	532, 533, 517, 491, 534, 534, 535, 536, 
	538, 539, 540, 541, 542, 538, 539, 540, 
	541, 542, 543, 544, 537, 23, 534, 534, 
	535, 536, 543, 544, 545, 23, 547, 548, 
	549, 550, 551, 547, 548, 549, 550, 551, 
	546, 23, 552, 552, 553, 554, 556, 557, 
	555, 23, 532, 533, 35, 19, 20, 559, 
	560, 561, 559, 560, 561, 558, 562, 562, 
	558, 563, 563, 558, 564, 564, 558, 565, 
	565, 558, 566, 566, 558, 567, 567, 558, 
	568, 568, 568, 568, 558, 570, 570, 571, 
	572, 573, 574, 569, 575, 575, 576, 577, 
	5, 6, 7, 8, 9, 10, 11, 12, 
	13, 14, 15, 16, 17, 18, 5, 6, 
	7, 8, 9, 10, 11, 12, 13, 14, 
	15, 16, 17, 18, 578, 579, 4, 491, 
	578, 579, 580, 582, 582, 583, 584, 28, 
	29, 30, 31, 32, 28, 29, 30, 31, 
	32, 585, 586, 27, 581, 587, 587, 588, 
	589, 5, 6, 7, 8, 9, 10, 11, 
	12, 13, 14, 15, 16, 17, 18, 5, 
	6, 7, 8, 9, 10, 11, 12, 13, 
	14, 15, 16, 17, 18, 590, 591, 4, 
	491, 590, 591, 35, 24, 24, 25, 26, 
	33, 34, 592, 23, 594, 595, 596, 597, 
	598, 594, 595, 596, 597, 598, 593, 23, 
	599, 599, 600, 601, 603, 604, 602, 23, 
	53, 54, 35, 606, 606, 607, 608, 59, 
	60, 61, 59, 60, 61, 609, 610, 64, 
	64, 611, 612, 605, 613, 613, 614, 615, 
	67, 105, 106, 107, 108, 109, 110, 111, 
	112, 113, 114, 115, 116, 117, 118, 72, 
	105, 106, 107, 108, 109, 110, 111, 112, 
	113, 114, 115, 116, 117, 118, 616, 617, 
	75, 75, 618, 619, 67, 67, 104, 67, 
	493, 621, 621, 622, 623, 59, 60, 61, 
	59, 60, 61, 82, 83, 624, 625, 626, 
	627, 628, 629, 620, 630, 630, 631, 632, 
	72, 88, 89, 99, 95, 96, 97, 633, 
	98, 67, 67, 67, 78, 634, 634, 635, 
	636, 5, 6, 7, 8, 9, 10, 11, 
	12, 13, 14, 15, 16, 17, 18, 5, 
	6, 7, 8, 9, 10, 11, 12, 13, 
	14, 15, 16, 17, 18, 88, 89, 637, 
	638, 4, 0, 88, 637, 89, 638, 84, 
	639, 639, 640, 641, 88, 89, 88, 89, 
	89, 89, 89, 78, 639, 639, 640, 641, 
	88, 89, 88, 89, 89, 89, 89, 84, 
	642, 642, 643, 644, 67, 105, 106, 107, 
	108, 109, 110, 111, 112, 113, 114, 115, 
	116, 117, 118, 72, 105, 106, 107, 108, 
	109, 110, 111, 112, 113, 114, 115, 116, 
	117, 118, 88, 89, 637, 645, 96, 97, 
	637, 646, 67, 67, 104, 67, 101, 79, 
	79, 80, 81, 137, 138, 137, 138, 82, 
	83, 82, 83, 620, 79, 79, 80, 81, 
	163, 164, 165, 163, 164, 165, 82, 83, 
	82, 83, 620, 79, 79, 80, 81, 208, 
	208, 82, 83, 82, 83, 620, 79, 79, 
	80, 81, 230, 230, 82, 83, 82, 83, 
	620, 79, 79, 80, 81, 508, 243, 508, 
	243, 82, 83, 82, 83, 620, 79, 79, 
	80, 81, 282, 283, 282, 283, 82, 83, 
	82, 83, 620, 79, 79, 80, 81, 301, 
	301, 82, 83, 82, 83, 620, 79, 79, 
	80, 81, 311, 312, 311, 312, 82, 83, 
	82, 83, 620, 79, 79, 80, 81, 332, 
	333, 332, 333, 82, 83, 82, 83, 620, 
	79, 79, 80, 81, 385, 385, 82, 83, 
	82, 83, 620, 79, 79, 80, 81, 395, 
	396, 397, 395, 396, 397, 82, 83, 82, 
	83, 620, 79, 79, 80, 81, 425, 426, 
	427, 428, 425, 426, 427, 428, 82, 83, 
	82, 83, 620, 79, 79, 80, 81, 467, 
	468, 469, 467, 468, 469, 82, 83, 82, 
	83, 620, 88, 647, 89, 645, 78, 79, 
	79, 80, 81, 559, 560, 561, 559, 560, 
	561, 82, 83, 82, 83, 648, 649, 649, 
	558, 650, 650, 558, 651, 651, 558, 652, 
	652, 558, 653, 653, 558, 654, 654, 654, 
	654, 558, 655, 655, 558, 656, 656, 558, 
	657, 657, 657, 657, 558, 659, 659, 660, 
	661, 82, 83, 662, 663, 658, 665, 665, 
	666, 667, 28, 29, 30, 31, 32, 28, 
	29, 30, 31, 32, 82, 83, 668, 669, 
	27, 664, 670, 670, 671, 672, 5, 6, 
	7, 8, 9, 10, 11, 12, 13, 14, 
	15, 16, 17, 18, 5, 6, 7, 8, 
	9, 10, 11, 12, 13, 14, 15, 16, 
	17, 18, 88, 89, 673, 674, 4, 0, 
	88, 673, 89, 674, 131, 676, 676, 677, 
	678, 59, 60, 61, 59, 60, 61, 82, 
	83, 679, 680, 626, 627, 681, 682, 675, 
	683, 683, 684, 685, 67, 105, 106, 107, 
	108, 109, 110, 111, 112, 113, 114, 115, 
	116, 117, 118, 72, 105, 106, 107, 108, 
	109, 110, 111, 112, 113, 114, 115, 116, 
	117, 118, 88, 89, 647, 645, 96, 97, 
	686, 646, 67, 67, 104, 67, 101, 659, 
	659, 660, 661, 137, 138, 137, 138, 82, 
	83, 662, 663, 675, 659, 659, 660, 661, 
	163, 164, 165, 163, 164, 165, 82, 83, 
	662, 663, 675, 659, 659, 660, 661, 208, 
	208, 82, 83, 662, 663, 675, 659, 659, 
	660, 661, 230, 230, 82, 83, 662, 663, 
	675, 659, 659, 660, 661, 508, 243, 508, 
	243, 82, 83, 662, 663, 675, 659, 659, 
	660, 661, 282, 283, 282, 283, 82, 83, 
	662, 663, 675, 659, 659, 660, 661, 301, 
	301, 82, 83, 662, 663, 675, 659, 659, 
	660, 661, 311, 312, 311, 312, 82, 83, 
	662, 663, 675, 659, 659, 660, 661, 332, 
	333, 332, 333, 82, 83, 662, 663, 675, 
	659, 659, 660, 661, 385, 385, 82, 83, 
	662, 663, 675, 659, 659, 660, 661, 395, 
	396, 397, 395, 396, 397, 82, 83, 662, 
	663, 675, 659, 659, 660, 661, 425, 426, 
	427, 428, 425, 426, 427, 428, 82, 83, 
	662, 663, 675, 659, 659, 660, 661, 467, 
	468, 469, 467, 468, 469, 82, 83, 662, 
	663, 675, 687, 687, 91, 689, 690, 90, 
	90, 691, 692, 90, 90, 90, 688, 693, 
	693, 694, 695, 5, 6, 7, 8, 9, 
	10, 11, 12, 13, 14, 15, 16, 17, 
	18, 5, 6, 7, 8, 9, 10, 11, 
	12, 13, 14, 15, 16, 17, 18, 82, 
	83, 696, 697, 4, 101, 79, 82, 79, 
	80, 81, 83, 698, 696, 698, 699, 700, 
	697, 579, 78, 85, 88, 85, 86, 87, 
	89, 701, 637, 701, 702, 703, 638, 579, 
	84, 639, 88, 639, 640, 641, 704, 637, 
	704, 705, 706, 89, 645, 78, 707, 707, 
	35, 708, 708, 35, 709, 709, 710, 711, 
	712, 713, 714, 714, 715, 716, 55, 717, 
	717, 35, 718, 718, 35, 719, 719, 35, 
	720, 720, 721, 722, 723, 724, 725, 725, 
	726, 727, 55, 728, 728, 35, 729, 729, 
	730, 731, 732, 733, 734, 734, 735, 736, 
	55, 19, 119, 20, 120, 78, 737, 737, 
	738, 739, 88, 89, 88, 89, 20, 20, 
	20, 78, 737, 737, 738, 739, 88, 89, 
	88, 89, 20, 20, 20, 84, 737, 88, 
	737, 738, 739, 89, 740, 637, 740, 741, 
	742, 645, 20, 120, 78, 639, 88, 639, 
	640, 641, 743, 88, 743, 744, 745, 89, 
	95, 78, 616, 617, 69, 85, 88, 85, 
	86, 87, 89, 746, 637, 746, 747, 748, 
	645, 617, 78, 570, 570, 571, 572, 137, 
	138, 137, 138, 573, 574, 749, 570, 570, 
	571, 572, 163, 164, 165, 163, 164, 165, 
	573, 574, 749, 570, 570, 571, 572, 208, 
	208, 573, 574, 749, 570, 570, 571, 572, 
	230, 230, 573, 574, 749, 570, 570, 571, 
	572, 508, 243, 508, 243, 573, 574, 749, 
	570, 570, 571, 572, 282, 283, 282, 283, 
	573, 574, 749, 570, 570, 571, 572, 301, 
	301, 573, 574, 749, 570, 570, 571, 572, 
	311, 312, 311, 312, 573, 574, 749, 570, 
	570, 571, 572, 332, 333, 332, 333, 573, 
	574, 749, 570, 570, 571, 572, 385, 385, 
	573, 574, 749, 570, 570, 571, 572, 395, 
	396, 397, 395, 396, 397, 573, 574, 749, 
	570, 570, 571, 572, 425, 426, 427, 428, 
	425, 426, 427, 428, 573, 574, 749, 570, 
	570, 571, 572, 467, 468, 469, 467, 468, 
	469, 573, 574, 749, 19, 21, 20, 22, 
	84, 19, 506, 20, 507, 131, 570, 570, 
	571, 572, 242, 243, 242, 243, 573, 574, 
	749, 88, 135, 89, 136, 131, 751, 750, 
	753, 752, 755, 757, 758, 759, 756, 756, 
	756, 756, 754, 760, 761, 760, 760, 760, 
	754, 762, 763, 764, 762, 765, 764, 762, 
	762, 764, 764, 764, 754, 760, 761, 760, 
	767, 766, 760, 760, 766, 766, 766, 754, 
	768, 766, 770, 769, 771, 769, 772, 774, 
	772, 775, 773, 772, 772, 773, 773, 773, 
	769, 762, 762, 762, 762, 754, 776, 776, 
	776, 776, 754, 779, 780, 778, 778, 777, 
	781, 778, 781, 780, 781, 778, 782, 778, 
	777, 783, 778, 785, 784, 786, 784, 787, 
	788, 787, 790, 787, 788, 789, 788, 784, 
	791, 792, 793, 791, 791, 777, 781, 781, 
	781, 781, 794, 795, 791, 796, 784, 797, 
	784, 798, 799, 800, 798, 798, 784, 802, 
	802, 803, 804, 805, 806, 801, 802, 802, 
	803, 804, 805, 806, 808, 807, 810, 810, 
	811, 812, 814, 815, 816, 817, 818, 814, 
	815, 816, 817, 818, 819, 820, 819, 820, 
	813, 809, 810, 810, 811, 812, 819, 820, 
	819, 820, 821, 819, 820, 810, 810, 811, 
	812, 819, 820, 819, 820, 822, 809, 825, 
	826, 827, 828, 829, 825, 826, 827, 828, 
	829, 824, 823, 830, 830, 831, 832, 834, 
	835, 834, 835, 833, 809, 805, 806, 801, 
	837, 837, 838, 839, 840, 841, 836, 837, 
	837, 838, 839, 842, 844, 845, 843, 840, 
	841, 843, 843, 843, 836, 846, 836, 848, 
	848, 849, 850, 851, 852, 853, 852, 854, 
	855, 854, 855, 852, 852, 852, 847, 856, 
	856, 857, 858, 859, 860, 859, 860, 847, 
	859, 860, 846, 862, 861, 861, 861, 861, 
	836, 863, 861, 865, 864, 866, 864, 868, 
	869, 867, 867, 867, 867, 864, 848, 848, 
	849, 850, 854, 855, 854, 855, 847, 840, 
	841, 836, 870, 870, 871, 872, 873, 874, 
	580, 870, 870, 871, 872, 873, 874, 875, 
	875, 875, 876, 878, 878, 879, 880, 881, 
	882, 881, 883, 877, 885, 885, 886, 887, 
	888, 890, 891, 889, 892, 893, 892, 894, 
	889, 889, 889, 884, 896, 895, 897, 897, 
	898, 899, 900, 901, 902, 901, 903, 904, 
	903, 904, 901, 901, 901, 884, 905, 905, 
	906, 907, 892, 893, 892, 893, 84, 892, 
	893, 896, 909, 908, 908, 908, 908, 895, 
	910, 908, 912, 911, 913, 911, 915, 916, 
	914, 914, 914, 914, 911, 897, 897, 898, 
	899, 903, 904, 903, 904, 884, 892, 917, 
	893, 894, 84, 918, 918, 919, 920, 888, 
	890, 891, 889, 921, 922, 889, 889, 889, 
	895, 921, 922, 580, 873, 874, 580, 924, 
	924, 924, 924, 923, 925, 925, 925, 925, 
	923, 926, 927, 926, 926, 926, 923, 928, 
	929, 928, 928, 928, 923, 929, 929, 930, 
	931, 924, 932, 933, 934, 934, 935, 936, 
	924, 924, 924, 923, 932, 933, 923, 929, 
	923, 938, 938, 939, 940, 941, 942, 943, 
	943, 944, 945, 937, 946, 946, 947, 948, 
	949, 950, 951, 952, 953, 954, 955, 956, 
	957, 958, 959, 960, 961, 962, 949, 950, 
	951, 952, 953, 954, 955, 956, 957, 958, 
	959, 960, 961, 962, 963, 964, 965, 965, 
	966, 967, 937, 968, 968, 969, 970, 971, 
	972, 973, 971, 972, 973, 974, 975, 976, 
	976, 977, 978, 937, 979, 979, 937, 980, 
	980, 937, 981, 981, 982, 983, 984, 985, 
	986, 986, 987, 988, 937, 963, 964, 937, 
	989, 990, 989, 990, 937, 991, 991, 937, 
	992, 992, 937, 993, 993, 994, 995, 996, 
	997, 998, 998, 999, 1000, 937, 1001, 1001, 
	937, 1002, 1002, 937, 1003, 1003, 937, 1004, 
	1004, 1005, 1006, 1007, 1008, 1009, 1009, 1010, 
	1011, 937, 1012, 1013, 1014, 1012, 1013, 1014, 
	937, 1015, 1015, 937, 1016, 1016, 937, 1017, 
	1017, 937, 1018, 1018, 1019, 1020, 1021, 1022, 
	1023, 1023, 1024, 1025, 937, 1026, 1027, 1026, 
	1027, 937, 1028, 1028, 937, 1029, 1029, 937, 
	1030, 1030, 1031, 1032, 1033, 1034, 1035, 1035, 
	1036, 1037, 937, 1038, 1038, 937, 1039, 1039, 
	937, 1040, 1040, 937, 1041, 1041, 1042, 1043, 
	1044, 1045, 1046, 1046, 1047, 1048, 937, 1049, 
	1049, 1050, 1051, 1052, 1053, 1054, 1054, 1055, 
	1056, 937, 1057, 1057, 937, 1058, 1058, 937, 
	1059, 1060, 937, 1061, 937, 1062, 1062, 1063, 
	1064, 1065, 1066, 1067, 1067, 1068, 1069, 937, 
	1070, 937, 1071, 1071, 1072, 1073, 1074, 1075, 
	1076, 1076, 1077, 1078, 937, 1079, 1079, 937, 
	1080, 1080, 937, 1081, 1081, 937, 1082, 1082, 
	937, 1083, 1083, 1084, 1085, 1086, 1087, 1088, 
	1088, 1089, 1090, 937, 1091, 1091, 937, 1092, 
	1092, 937, 1093, 1093, 937, 1094, 1094, 937, 
	1095, 1095, 937, 1096, 1096, 937, 1097, 1097, 
	937, 1098, 1098, 1099, 1100, 1101, 1102, 1103, 
	1103, 1104, 1105, 937, 1106, 1107, 1106, 1107, 
	937, 1108, 1108, 937, 1109, 1109, 1110, 1111, 
	1112, 1113, 1114, 1114, 1115, 1116, 937, 1117, 
	1117, 1118, 1119, 1120, 1121, 1122, 1122, 1123, 
	1124, 937, 1125, 1125, 937, 1126, 1126, 937, 
	1127, 1127, 1128, 1129, 1130, 1131, 1132, 1132, 
	1133, 1134, 937, 1135, 1136, 1135, 1136, 937, 
	1137, 1137, 937, 1138, 1138, 937, 1139, 1139, 
	937, 1140, 1140, 1141, 1142, 1143, 1144, 1145, 
	1145, 1146, 1147, 937, 1148, 1148, 1149, 1150, 
	1151, 1152, 1153, 1153, 1154, 1155, 937, 1156, 
	1157, 1156, 1157, 937, 1158, 1158, 937, 1159, 
	1159, 937, 1160, 1160, 937, 1161, 1161, 1162, 
	1163, 1164, 1165, 1166, 1166, 1167, 1168, 937, 
	1169, 1169, 1170, 1171, 1172, 1172, 1173, 1174, 
	1175, 1175, 1176, 1177, 937, 1178, 1178, 937, 
	1179, 1179, 1180, 1181, 1182, 1183, 1184, 1185, 
	1185, 1186, 1187, 937, 1188, 1188, 1189, 1190, 
	1191, 1191, 1192, 1193, 1194, 1194, 1195, 1196, 
	937, 1197, 1197, 937, 1198, 1198, 937, 1199, 
	1199, 937, 1200, 1200, 937, 1201, 1201, 1202, 
	1203, 1204, 1205, 1206, 1206, 1207, 1208, 937, 
	1209, 1209, 937, 1210, 1210, 937, 1211, 1211, 
	1212, 1213, 1214, 1215, 1216, 1216, 1217, 1218, 
	937, 1219, 1220, 1221, 1219, 1220, 1221, 937, 
	1222, 1222, 1223, 1224, 1225, 1226, 1227, 1227, 
	1228, 1229, 937, 1230, 1230, 937, 1231, 1231, 
	937, 1232, 1232, 937, 1233, 1233, 1234, 1235, 
	1236, 1237, 1238, 1238, 1239, 1240, 937, 1241, 
	1241, 1242, 1243, 1244, 1245, 1246, 1246, 1247, 
	1248, 937, 1249, 1250, 1251, 1252, 1249, 1250, 
	1251, 1252, 937, 1253, 1253, 937, 1254, 1254, 
	1255, 1256, 1257, 1258, 1259, 1259, 1260, 1261, 
	937, 1262, 1262, 937, 1263, 1263, 1264, 1265, 
	1266, 1267, 1268, 1268, 1269, 1270, 937, 1271, 
	1271, 937, 1272, 1272, 1273, 1274, 1275, 1276, 
	1277, 1277, 1278, 1279, 937, 1280, 1280, 937, 
	1281, 1281, 937, 1282, 1282, 937, 1283, 1283, 
	1284, 1285, 1286, 1287, 1288, 1288, 1289, 1290, 
	937, 1291, 1292, 1293, 1291, 1292, 1293, 937, 
	1294, 1294, 937, 1295, 1295, 937, 1296, 1296, 
	1297, 1298, 1299, 1300, 1301, 1301, 1302, 1303, 
	937, 1304, 1304, 937, 1305, 1305, 1306, 1307, 
	1308, 1309, 1310, 1310, 1311, 1312, 937, 1313, 
	1313, 937, 1314, 1314, 937, 1315, 937, 1316, 
	1316, 1317, 1318, 1320, 1321, 1322, 1322, 1323, 
	1324, 1319, 937, 1325, 1325, 937, 1326, 1326, 
	937, 1327, 1327, 937, 1328, 1328, 1329, 1330, 
	1331, 1332, 1333, 1333, 1334, 1335, 937, 1336, 
	1336, 937, 1337, 1337, 1338, 1339, 1340, 1341, 
	1342, 1342, 1343, 1344, 937, 1346, 1346, 1347, 
	1348, 1349, 1350, 1345, 1346, 1346, 1347, 1348, 
	1349, 1350, 1352, 1351, 1353, 1353, 1354, 1355, 
	1357, 1358, 1356, 1351, 1360, 1360, 1361, 1362, 
	1364, 1365, 1363, 1363, 1363, 1359, 1366, 1366, 
	1366, 1359, 1367, 1367, 1368, 1369, 1370, 1371, 
	1372, 1372, 1373, 1374, 1363, 1363, 1363, 1359, 
	1370, 1371, 1359, 1364, 1365, 1345, 1349, 1350, 
	1345, 1375, 1375, 1376, 1377, 1378, 1379, 1345, 
	1375, 1375, 1376, 1377, 1380, 1378, 1379, 1381, 
	1351, 1382, 1382, 1383, 1384, 1386, 1386, 1387, 
	1388, 1385, 1351, 1389, 1389, 1390, 1391, 1393, 
	1394, 1392, 1392, 1392, 1359, 1395, 1395, 1395, 
	1359, 1396, 1396, 1397, 1398, 1399, 1400, 1401, 
	1401, 1402, 1403, 1392, 1392, 1392, 1359, 1399, 
	1400, 1359, 1393, 1394, 1345, 1404, 1404, 1405, 
	1406, 1407, 1408, 1385, 1351, 1378, 1379, 1345, 
	1411, 1412, 1413, 1414, 1415, 1411, 1412, 1413, 
	1414, 1415, 1410, 1409, 1416, 1416, 1416, 1416, 
	1417, 1409, 1418, 1419, 1418, 1419, 1409, 1420, 
	1420, 1420, 1420, 1409, 1421, 1421, 1409, 1422, 
	1423, 1422, 1422, 1422, 1409, 1424, 1424, 1409, 
	1425, 1425, 1409, 1426, 1426, 1409, 1427, 1427, 
	1409, 1428, 1409, 1429, 1409, 1430, 1430, 1409, 
	1431, 1431, 1409, 1432, 1432, 1409, 1433, 1409, 
	1434, 1434, 1434, 1434, 1409, 1435, 1435, 1409, 
	1436, 1437, 1436, 1437, 1409, 1438, 1409, 1439, 
	1439, 1409, 1440, 1440, 1409, 1441, 1441, 1409, 
	1442, 1442, 1409, 1443, 1443, 1443, 1443, 1409, 
	1444, 1444, 1409, 1445, 1445, 1409, 1446, 1446, 
	1409, 1447, 1448, 1409, 1449, 1409, 1450, 1409, 
	1451, 1451, 1409, 1452, 1452, 1409, 1453, 1453, 
	1409, 1454, 1409, 1455, 1409, 1456, 1409, 1457, 
	1457, 1457, 1457, 1409, 1458, 1409, 1459, 1409, 
	1460, 1460, 1409, 1461, 1461, 1409, 1462, 1462, 
	1409, 1463, 1409, 1464, 1409, 1465, 1409, 1466, 
	1466, 1466, 1466, 1409, 1467, 1467, 1409, 1468, 
	1468, 1409, 1469, 1469, 1409, 1470, 1470, 1409, 
	1471, 1471, 1409, 1472, 1472, 1409, 1473, 1473, 
	1409, 1474, 1474, 1474, 1474, 1409, 1475, 1475, 
	1409, 1476, 1476, 1409, 1477, 1477, 1409, 1478, 
	1478, 1409, 1479, 1479, 1409, 1480, 1480, 1409, 
	1481, 1482, 1481, 1482, 1409, 1483, 1483, 1409, 
	1484, 1484, 1409, 1485, 1485, 1485, 1485, 1409, 
	1486, 1486, 1409, 1487, 1487, 1409, 1488, 1488, 
	1488, 1488, 1409, 1489, 1489, 1409, 1490, 1490, 
	1409, 1491, 1492, 1491, 1492, 1409, 1493, 1493, 
	1409, 1494, 1409, 1495, 1495, 1495, 1495, 1409, 
	1496, 1496, 1409, 1497, 1497, 1409, 1498, 1499, 
	1500, 1409, 1501, 1502, 1501, 1501, 1501, 1409, 
	1503, 1503, 1409, 1504, 1504, 1409, 1505, 1505, 
	1409, 1506, 1506, 1409, 1507, 1409, 1508, 1409, 
	1509, 1509, 1409, 1510, 1510, 1409, 1511, 1511, 
	1409, 1512, 1409, 1513, 1513, 1513, 1513, 1409, 
	1514, 1409, 1515, 1409, 1516, 1516, 1516, 1516, 
	1409, 1517, 1409, 1518, 1409, 1519, 1519, 1519, 
	1519, 1409, 1522, 1523, 1524, 1525, 1526, 1527, 
	1522, 1523, 1524, 1525, 1526, 1527, 1521, 1520, 
	1528, 1528, 1528, 1528, 1529, 1520, 1530, 1530, 
	1520, 1531, 1531, 1520, 1532, 1532, 1520, 1533, 
	1533, 1520, 1534, 1534, 1520, 1535, 1535, 1535, 
	1535, 1520, 1536, 1537, 1538, 1536, 1537, 1538, 
	1520, 1539, 1539, 1520, 1540, 1540, 1520, 1541, 
	1541, 1520, 1542, 1542, 1520, 1543, 1543, 1520, 
	1544, 1544, 1544, 1544, 1520, 1545, 1546, 1545, 
	1546, 1520, 1547, 1547, 1520, 1548, 1548, 1548, 
	1548, 1520, 1549, 1549, 1520, 1550, 1550, 1520, 
	1551, 1551, 1551, 1551, 1520, 1552, 1552, 1520, 
	1553, 1553, 1520, 1554, 1554, 1520, 1555, 1555, 
	1555, 1555, 1520, 1556, 1556, 1520, 1557, 1557, 
	1520, 1558, 1558, 1558, 1558, 1520, 1559, 1560, 
	1559, 1560, 1520, 1561, 1561, 1520, 1562, 1562, 
	1562, 1562, 1520, 1563, 1563, 1520, 1564, 1564, 
	1520, 1565, 1565, 1565, 1565, 1520, 1566, 1566, 
	1520, 1567, 1567, 1520, 1568, 1568, 1520, 1569, 
	1569, 1569, 1569, 1520, 1570, 1570, 1520, 1571, 
	1571, 1520, 1572, 1572, 1572, 1572, 1520, 1574, 
	1574, 1573, 1575, 1576, 1575, 1575, 1575, 1576, 
	1573, 1577, 1577, 1577, 1577, 1577, 1577, 69, 
	1578, 1578, 1578, 1578, 69, 1579, 1579, 1579, 
	1579, 1579, 1579, 69, 1580, 1580, 1581, 1582, 
	1583, 1584, 69, 1585, 1585, 1586, 1587, 1588, 
	1588, 1588, 1589, 1590, 1588, 1588, 1588, 69, 
	1591, 1591, 1592, 1593, 1594, 1595, 69, 1597, 
	1597, 1598, 1599, 1601, 1602, 1600, 1596, 1603, 
	1603, 1604, 1605, 1607, 1608, 1606, 1596, 1609, 
	1609, 1610, 1611, 1613, 1614, 1612, 1596, 1616, 
	1616, 1617, 1618, 1620, 1621, 1622, 1623, 1624, 
	1620, 1621, 1622, 1623, 1624, 1625, 1626, 1619, 
	1615, 1627, 1627, 1628, 1629, 1631, 1632, 1630, 
	1596, 1633, 1633, 1634, 1635, 1637, 1638, 1639, 
	1640, 1641, 1637, 1638, 1639, 1640, 1641, 1642, 
	1643, 1636, 1615, 1644, 1644, 1645, 1646, 1648, 
	1649, 1647, 1596, 1650, 1650, 1651, 1652, 1654, 
	1655, 1656, 1657, 1658, 1654, 1655, 1656, 1657, 
	1658, 1659, 1660, 1653, 1615, 1661, 1661, 1662, 
	1663, 1665, 1666, 1664, 1596, 1667, 1667, 1669, 
	1670, 1671, 1672, 1673, 1669, 1670, 1671, 1672, 
	1673, 1667, 1667, 1668, 1615, 1667, 1667, 1667, 
	1667, 1674, 1615, 1676, 1677, 1678, 1679, 1680, 
	1676, 1677, 1678, 1679, 1680, 1675, 1615, 1681, 
	1681, 1681, 1681, 1682, 1615, 1665, 1666, 69, 
	1650, 1650, 1651, 1652, 1659, 1660, 1683, 1615, 
	1685, 1686, 1687, 1688, 1689, 1685, 1686, 1687, 
	1688, 1689, 1684, 1615, 1690, 1690, 1691, 1692, 
	1694, 1695, 1693, 1615, 1648, 1649, 69, 1633, 
	1633, 1634, 1635, 1642, 1643, 1696, 1615, 1698, 
	1699, 1700, 1701, 1702, 1698, 1699, 1700, 1701, 
	1702, 1697, 1615, 1703, 1703, 1704, 1705, 1707, 
	1708, 1706, 1615, 1631, 1632, 69, 1616, 1616, 
	1617, 1618, 1625, 1626, 1709, 1615, 1711, 1712, 
	1713, 1714, 1715, 1711, 1712, 1713, 1714, 1715, 
	1710, 1615, 1716, 1716, 1717, 1718, 1720, 1721, 
	1719, 1615, 1613, 1614, 69, 1601, 1602, 69, 
	1589, 1590, 69, 69, 69, 69, 69, 1722, 
	1723, 1723, 1724, 1725, 1726, 1727, 69, 1729, 
	1729, 1730, 1731, 1732, 1733, 1728, 1728, 1728, 
	69, 1734, 1734, 1734, 1734, 69, 1732, 1733, 
	69, 1735, 1735, 1735, 1735, 1735, 1735, 69, 
	1736, 1736, 1737, 1738, 1739, 1740, 69, 1741, 
	1741, 1742, 1743, 1744, 1744, 1744, 1745, 1746, 
	1744, 1744, 1744, 69, 1747, 1747, 1747, 1747, 
	69, 1745, 1746, 69, 1748, 1596, 1749, 1749, 
	1750, 1751, 1753, 1754, 1752, 1596, 1755, 1755, 
	1756, 1757, 1758, 1758, 1758, 1759, 1760, 1758, 
	1758, 1758, 69, 1761, 1761, 1761, 1761, 69, 
	1759, 1760, 69, 69, 69, 69, 69, 1762, 
	1763, 1763, 1764, 1765, 1766, 1767, 1768, 1768, 
	1769, 1770, 69, 1771, 1771, 1772, 1773, 1774, 
	1775, 1776, 1776, 1777, 1778, 1762, 1762, 1762, 
	69, 1774, 1775, 69, 1779, 1779, 1779, 1779, 
	1573, 1780, 1781, 1780, 1780, 1780, 1781, 1781, 
	1781, 1573, 1783, 1782, 1784, 1784, 1785, 1786, 
	1788, 1789, 1787, 1782, 1790, 1790, 1791, 1792, 
	1794, 1795, 1796, 1797, 1793, 1782, 1798, 1798, 
	1799, 1800, 1802, 1803, 1801, 1782, 1804, 1804, 
	1805, 1806, 1794, 1795, 1808, 1809, 1807, 1782, 
	1810, 1810, 1811, 1812, 1813, 1815, 1816, 1814, 
	1782, 1817, 1817, 1818, 1819, 1794, 1795, 1820, 
	1821, 1782, 1822, 1822, 1823, 1824, 1825, 1826, 
	1782, 1822, 1822, 1823, 1824, 1825, 1826, 1827, 
	1782, 1828, 1828, 1829, 1830, 1832, 1833, 1831, 
	1782, 1834, 1834, 1835, 1836, 1838, 1839, 1840, 
	1841, 1837, 1782, 1842, 1842, 1843, 1844, 1846, 
	1847, 1845, 1782, 1848, 1848, 1849, 1850, 1838, 
	1839, 1852, 1853, 1851, 1782, 1854, 1854, 1855, 
	1856, 1857, 1859, 1860, 1858, 1782, 1861, 1861, 
	1862, 1863, 1838, 1839, 1864, 1865, 1782, 1866, 
	1866, 1867, 1868, 1869, 1870, 1782, 1866, 1866, 
	1867, 1868, 1871, 1869, 1870, 1872, 1782, 1873, 
	1782, 1874, 1874, 1875, 1876, 1877, 1879, 1880, 
	1881, 1882, 1882, 1883, 1884, 1878, 1782, 1885, 
	1885, 1886, 1887, 1889, 1890, 1891, 1891, 1892, 
	1893, 1888, 1782, 1894, 1894, 1895, 1896, 1897, 
	1899, 1900, 1901, 1902, 1902, 1903, 1904, 1898, 
	1782, 1905, 1905, 1906, 1907, 1909, 1910, 1891, 
	1891, 1911, 1912, 1908, 1782, 1913, 1913, 1914, 
	1915, 1916, 1918, 1919, 1920, 1921, 1921, 1922, 
	1923, 1917, 1782, 1924, 1924, 1925, 1926, 1928, 
	1929, 1891, 1891, 1930, 1931, 1927, 1782, 1932, 
	1932, 1933, 1934, 1935, 1932, 1937, 1938, 1939, 
	1939, 1940, 1941, 1936, 1782, 1942, 1942, 1943, 
	1944, 1945, 1946, 1891, 1891, 1947, 1948, 1782, 
	1945, 1946, 1782, 1949, 1949, 1950, 1951, 1949, 
	1953, 1954, 1955, 1955, 1956, 1957, 1952, 1782, 
	1932, 1932, 1933, 1934, 1932, 1937, 1938, 1939, 
	1939, 1940, 1941, 1958, 1782, 1928, 1929, 1782, 
	1959, 1959, 1960, 1961, 1963, 1964, 1965, 1966, 
	1966, 1967, 1968, 1962, 1782, 1913, 1913, 1914, 
	1915, 1918, 1919, 1920, 1921, 1921, 1922, 1923, 
	1969, 1782, 1924, 1924, 1925, 1926, 1928, 1929, 
	1891, 1891, 1930, 1931, 1782, 1909, 1910, 1782, 
	1970, 1970, 1971, 1972, 1974, 1975, 1976, 1977, 
	1977, 1978, 1979, 1973, 1782, 1894, 1894, 1895, 
	1896, 1899, 1900, 1901, 1902, 1902, 1903, 1904, 
	1980, 1782, 1905, 1905, 1906, 1907, 1909, 1910, 
	1891, 1891, 1911, 1912, 1782, 1889, 1890, 1782, 
	1981, 1981, 1982, 1983, 1985, 1986, 1987, 1988, 
	1988, 1989, 1990, 1984, 1782, 1874, 1874, 1875, 
	1876, 1879, 1880, 1881, 1882, 1882, 1883, 1884, 
	1991, 1782, 1885, 1885, 1886, 1887, 1889, 1890, 
	1891, 1891, 1892, 1893, 1782, 1869, 1870, 1782, 
	1992, 1992, 1993, 1994, 1995, 1996, 1782, 1864, 
	1865, 1782, 1997, 1997, 1998, 1999, 2001, 2002, 
	2000, 1782, 1854, 1854, 1855, 1856, 1859, 1860, 
	2003, 1782, 1852, 1853, 1782, 1840, 1841, 1782, 
	1825, 1826, 1782, 2004, 2004, 2005, 2006, 2007, 
	2008, 1782, 1820, 1821, 1782, 2009, 2009, 2010, 
	2011, 2013, 2014, 2012, 1782, 1810, 1810, 1811, 
	1812, 1815, 1816, 2015, 1782, 1808, 1809, 1782, 
	1796, 1797, 1782, 2016, 1596, 2017, 2017, 2018, 
	2019, 2021, 2022, 2020, 1596, 2023, 2023, 2024, 
	2025, 2027, 2028, 2026, 1596, 2029, 2029, 2030, 
	2031, 2033, 2034, 2032, 1596, 2035, 2035, 2036, 
	2037, 2039, 2040, 2038, 1596, 2041, 2041, 2042, 
	2043, 2045, 2046, 2044, 1596, 2047, 2047, 2048, 
	2049, 2050, 2050, 2050, 2051, 2052, 2050, 2050, 
	2050, 69, 2053, 2053, 2053, 2053, 69, 2051, 
	2052, 69, 2039, 2040, 69, 2027, 2028, 69, 
	2054, 1596, 2055, 2055, 2056, 2057, 2059, 2060, 
	2058, 1596, 2061, 2061, 2062, 2063, 2065, 2066, 
	2064, 1596, 2067, 2067, 2068, 2069, 2071, 2072, 
	2070, 1596, 2074, 2074, 2075, 2076, 2077, 2078, 
	2073, 2073, 2073, 69, 2079, 2079, 2080, 2081, 
	2082, 2083, 69, 2085, 2085, 2086, 2087, 2088, 
	2089, 2084, 2084, 2084, 69, 2090, 2090, 2091, 
	2092, 2093, 2094, 69, 2096, 2096, 2097, 2098, 
	2099, 2100, 2095, 2095, 2095, 69, 2101, 2101, 
	2102, 2103, 2104, 2105, 69, 2106, 2106, 2107, 
	2108, 2109, 2109, 2109, 2110, 2111, 2109, 2109, 
	2109, 69, 2112, 2112, 2112, 2112, 69, 2110, 
	2111, 69, 2099, 2100, 69, 2088, 2089, 69, 
	2077, 2078, 69, 2065, 2066, 69, 2113, 2113, 
	2113, 69, 2114, 2114, 2115, 2116, 2117, 2118, 
	69, 2114, 2114, 2115, 2116, 2117, 2118, 2119, 
	1596, 2120, 2120, 2121, 2122, 2124, 2125, 2123, 
	1596, 2126, 2126, 2127, 2128, 2130, 2131, 2129, 
	2129, 2129, 69, 2132, 2132, 2133, 2134, 2135, 
	2136, 69, 2132, 2132, 2133, 2134, 2137, 2135, 
	2136, 2137, 2137, 2137, 69, 2138, 2138, 69, 
	2135, 2136, 69, 2130, 2131, 69, 2117, 2118, 
	69, 2140, 2140, 2141, 2142, 2143, 2144, 2145, 
	2146, 2147, 2148, 2148, 2149, 2150, 2139, 2151, 
	2152, 2139, 2153, 2139, 2155, 2155, 2154, 2157, 
	2156, 2154, 2158, 2139, 2159, 2159, 2160, 2161, 
	2163, 2164, 2165, 2165, 2166, 2167, 2162, 2139, 
	2146, 2147, 69, 2168, 2139, 2169, 2169, 2169, 
	2169, 2154, 2171, 2170, 2170, 2170, 2154, 2172, 
	1596, 2173, 2173, 2174, 2175, 2177, 2178, 2176, 
	1596, 2179, 2179, 2180, 2181, 2183, 2184, 2182, 
	2182, 2182, 69, 2185, 2185, 2186, 2187, 2188, 
	2189, 69, 2185, 2185, 2186, 2187, 2188, 2189, 
	2190, 1596, 2191, 2191, 2192, 2193, 2195, 2196, 
	2194, 1596, 2198, 2198, 2199, 2200, 2202, 2203, 
	2201, 2201, 2201, 2197, 2204, 2204, 2204, 2197, 
	2205, 2205, 2206, 2207, 2208, 2209, 2210, 2210, 
	2211, 2212, 2201, 2201, 2201, 2197, 2208, 2209, 
	2197, 2202, 2203, 69, 2188, 2189, 69, 2183, 
	2184, 69, 2213, 1596, 2214, 2214, 2215, 2216, 
	2218, 2219, 2217, 1596, 2220, 2220, 2221, 2222, 
	2224, 2225, 2223, 1596, 2226, 2226, 2227, 2228, 
	2230, 2231, 2229, 1596, 2232, 2232, 2233, 2234, 
	2236, 2237, 2235, 2235, 2235, 2197, 2238, 2238, 
	2238, 2197, 2239, 2239, 2240, 2241, 2242, 2243, 
	2244, 2244, 2245, 2246, 2235, 2235, 2235, 2197, 
	2242, 2243, 2197, 2236, 2237, 69, 2224, 2225, 
	69, 2247, 1596, 2248, 2248, 2249, 2250, 2252, 
	2253, 2251, 1596, 2255, 2255, 2256, 2257, 2258, 
	2259, 2260, 2261, 2262, 2263, 2254, 2264, 2264, 
	2265, 2266, 2267, 2268, 2254, 2264, 2264, 2265, 
	2266, 2267, 2268, 2270, 2269, 2271, 2271, 2272, 
	2273, 2275, 2276, 2274, 2269, 2277, 2277, 2278, 
	2279, 2280, 2281, 2282, 2254, 2284, 2284, 2285, 
	2286, 2287, 2287, 2288, 2289, 2290, 2290, 2291, 
	2292, 2293, 2293, 2293, 2293, 2294, 2295, 2293, 
	2293, 2296, 2297, 2298, 2299, 2293, 2293, 2300, 
	2301, 2302, 2303, 2293, 2293, 2304, 2305, 2283, 
	2284, 2284, 2285, 2286, 2307, 2294, 2295, 2307, 
	2307, 2307, 2306, 2293, 2293, 2306, 2294, 2295, 
	2306, 2287, 2287, 2288, 2289, 2293, 2293, 2293, 
	2293, 2298, 2299, 2293, 2293, 2300, 2301, 2306, 
	2298, 2299, 2306, 2307, 2284, 2284, 2285, 2286, 
	2287, 2287, 2288, 2289, 2290, 2290, 2291, 2292, 
	2293, 2293, 2293, 2293, 2294, 2295, 2293, 2293, 
	2296, 2297, 2298, 2299, 2293, 2293, 2300, 2301, 
	2302, 2303, 2293, 2293, 2304, 2305, 2307, 2307, 
	2307, 2306, 2294, 2298, 2302, 2295, 2299, 2303, 
	2306, 2281, 2282, 2254, 2267, 2268, 2254, 2308, 
	2308, 2309, 2310, 2311, 2312, 2254, 2308, 2308, 
	2309, 2310, 2311, 2312, 2313, 2269, 2314, 2314, 
	2315, 2316, 2318, 2319, 2317, 2269, 2321, 2321, 
	2322, 2323, 2324, 2325, 2326, 2324, 2320, 2328, 
	2329, 2329, 2330, 2331, 2332, 2332, 2333, 2334, 
	2335, 2335, 2336, 2337, 2338, 2338, 2338, 2338, 
	2339, 2340, 2338, 2338, 2341, 2342, 2343, 2344, 
	2338, 2338, 2345, 2346, 2347, 2348, 2338, 2338, 
	2349, 2350, 2328, 2327, 2325, 2326, 2254, 2311, 
	2312, 2254, 2351, 2351, 2352, 2353, 2354, 2355, 
	2254, 2351, 2351, 2352, 2353, 2354, 2355, 2356, 
	2269, 2357, 2357, 2358, 2359, 2361, 2362, 2360, 
	2269, 2363, 2363, 2364, 2365, 2366, 2367, 2368, 
	2366, 2366, 2366, 2320, 2369, 2370, 2370, 2371, 
	2372, 2373, 2373, 2374, 2375, 2376, 2376, 2377, 
	2378, 2379, 2379, 2379, 2379, 2380, 2381, 2379, 
	2379, 2382, 2383, 2384, 2385, 2379, 2379, 2386, 
	2387, 2388, 2389, 2379, 2379, 2390, 2391, 2369, 
	2369, 2369, 2327, 2367, 2368, 2254, 2354, 2355, 
	2254, 2392, 2392, 2393, 2394, 2395, 2396, 2254, 
	2392, 2392, 2393, 2394, 2395, 2396, 2397, 2269, 
	2398, 2398, 2399, 2400, 2402, 2403, 2401, 2269, 
	2404, 2404, 2405, 2406, 2407, 2407, 2407, 2408, 
	2409, 2407, 2407, 2407, 2254, 2410, 2410, 2411, 
	2412, 2413, 2413, 2414, 2415, 2416, 2416, 2417, 
	2418, 2419, 2419, 2419, 2419, 2420, 2421, 2419, 
	2419, 2422, 2423, 2424, 2425, 2419, 2419, 2426, 
	2427, 2428, 2429, 2419, 2419, 2430, 2431, 2283, 
	2408, 2409, 2254, 2395, 2396, 2254, 2262, 2263, 
	69, 2433, 2434, 2435, 2436, 2437, 2438, 2439, 
	2440, 2441, 2442, 2443, 2444, 2445, 2446, 2433, 
	2434, 2435, 2436, 2437, 2438, 2439, 2440, 2441, 
	2442, 2443, 2444, 2445, 2446, 2432, 2447, 2447, 
	2448, 2449, 2450, 2451, 2452, 2450, 2451, 2452, 
	2453, 2454, 2432, 2455, 2455, 2456, 2457, 2459, 
	2460, 2458, 2458, 2458, 69, 2461, 2461, 2462, 
	2463, 2464, 2465, 69, 2461, 2461, 2462, 2463, 
	2464, 2465, 2466, 1596, 2467, 2467, 2468, 2469, 
	2471, 2472, 2470, 1596, 2473, 2473, 2474, 2475, 
	2477, 2478, 2476, 1596, 2479, 2479, 2480, 2481, 
	2483, 2484, 2482, 1596, 2486, 2486, 2487, 2488, 
	2490, 2491, 2489, 2485, 2492, 2492, 2493, 2494, 
	2496, 2497, 2495, 2485, 2498, 2498, 2499, 2500, 
	2502, 2503, 2501, 2485, 2504, 2504, 2505, 2506, 
	2508, 2509, 2507, 2485, 2510, 2510, 2511, 2512, 
	2514, 2515, 2513, 1596, 2516, 2516, 2517, 2518, 
	2520, 2521, 2519, 1596, 2522, 2522, 2523, 2524, 
	2525, 2525, 2525, 2526, 2527, 2525, 2525, 2525, 
	69, 2528, 2528, 2529, 2530, 2531, 2532, 69, 
	2533, 2533, 2534, 2535, 2536, 2537, 2538, 2536, 
	2536, 2536, 69, 2539, 2539, 69, 2537, 2538, 
	69, 2526, 2527, 69, 2514, 2515, 69, 2502, 
	2503, 69, 2490, 2491, 69, 2477, 2478, 69, 
	2464, 2465, 69, 2459, 2460, 69, 2540, 2540, 
	2432, 2541, 2541, 2432, 2542, 2542, 2543, 2544, 
	2545, 2546, 2432, 2547, 2547, 2432, 2548, 2548, 
	2432, 2549, 2549, 2432, 2550, 2550, 2551, 2552, 
	2553, 2554, 2432, 2555, 2555, 2432, 2556, 2556, 
	2557, 2558, 2559, 2560, 2432, 2561, 2562, 2561, 
	2562, 2432, 2563, 2563, 2432, 2564, 2564, 2432, 
	2565, 2565, 2566, 2567, 2568, 2569, 2432, 2570, 
	2570, 2432, 2571, 2571, 2432, 2572, 2572, 2432, 
	2573, 2573, 2574, 2575, 2576, 2577, 2432, 2578, 
	2579, 2580, 2578, 2579, 2580, 2432, 2581, 2581, 
	2432, 2582, 2582, 2432, 2583, 2583, 2432, 2584, 
	2584, 2585, 2586, 2587, 2588, 2432, 2589, 2590, 
	2589, 2590, 2432, 2591, 2591, 2432, 2592, 2592, 
	2432, 2593, 2593, 2594, 2595, 2596, 2597, 2432, 
	2598, 2598, 2432, 2599, 2599, 2432, 2600, 2600, 
	2432, 2601, 2601, 2602, 2603, 2604, 2605, 2432, 
	2606, 2606, 2607, 2608, 2609, 2610, 2432, 2611, 
	2611, 2432, 2612, 2612, 2432, 2613, 2614, 2432, 
	2615, 2432, 2616, 2616, 2617, 2618, 2619, 2620, 
	2432, 2621, 2432, 2622, 2622, 2623, 2624, 2625, 
	2626, 2432, 2627, 2627, 2432, 2628, 2628, 2432, 
	2629, 2629, 2432, 2630, 2630, 2432, 2631, 2631, 
	2632, 2633, 2634, 2635, 2432, 2636, 2636, 2432, 
	2637, 2637, 2432, 2638, 2638, 2432, 2639, 2639, 
	2432, 2640, 2640, 2432, 2641, 2641, 2432, 2642, 
	2642, 2432, 2643, 2643, 2644, 2645, 2646, 2647, 
	2432, 2648, 2649, 2648, 2649, 2432, 2650, 2650, 
	2432, 2651, 2651, 2652, 2653, 2654, 2655, 2432, 
	2656, 2656, 2657, 2658, 2659, 2660, 2432, 2661, 
	2661, 2432, 2662, 2662, 2432, 2663, 2663, 2664, 
	2665, 2666, 2667, 2432, 2668, 2669, 2668, 2669, 
	2432, 2670, 2670, 2432, 2671, 2671, 2432, 2672, 
	2672, 2432, 2673, 2673, 2674, 2675, 2676, 2677, 
	2432, 2678, 2678, 2679, 2680, 2681, 2682, 2432, 
	2683, 2684, 2683, 2684, 2432, 2685, 2685, 2432, 
	2686, 2686, 2432, 2687, 2687, 2432, 2688, 2688, 
	2689, 2690, 2691, 2692, 2432, 2693, 2693, 2694, 
	2695, 2696, 2696, 2697, 2698, 2432, 2699, 2699, 
	2432, 2700, 2700, 2701, 2702, 2703, 2704, 2705, 
	2432, 2706, 2706, 2707, 2708, 2709, 2709, 2710, 
	2711, 2432, 2712, 2712, 2432, 2713, 2713, 2432, 
	2714, 2714, 2432, 2715, 2715, 2432, 2716, 2716, 
	2717, 2718, 2719, 2720, 2432, 2721, 2721, 2432, 
	2722, 2722, 2432, 2723, 2723, 2724, 2725, 2726, 
	2727, 2432, 2728, 2729, 2730, 2728, 2729, 2730, 
	2432, 2731, 2731, 2732, 2733, 2734, 2735, 2432, 
	2736, 2736, 2432, 2737, 2737, 2432, 2738, 2738, 
	2432, 2739, 2739, 2740, 2741, 2742, 2743, 2432, 
	2744, 2744, 2745, 2746, 2747, 2748, 2432, 2749, 
	2750, 2751, 2752, 2749, 2750, 2751, 2752, 2432, 
	2753, 2753, 2432, 2754, 2754, 2755, 2756, 2757, 
	2758, 2432, 2759, 2759, 2432, 2760, 2760, 2761, 
	2762, 2763, 2764, 2432, 2765, 2765, 2432, 2766, 
	2766, 2767, 2768, 2769, 2770, 2432, 2771, 2771, 
	2432, 2772, 2772, 2432, 2773, 2773, 2432, 2774, 
	2774, 2775, 2776, 2777, 2778, 2432, 2779, 2780, 
	2781, 2779, 2780, 2781, 2432, 2782, 2782, 2432, 
	2783, 2783, 2432, 2784, 2784, 2785, 2786, 2787, 
	2788, 2432, 2789, 2789, 2432, 2790, 2790, 2791, 
	2792, 2793, 2794, 2432, 2795, 2795, 2432, 2796, 
	2796, 2432, 2798, 2797, 2799, 2799, 2800, 2801, 
	2803, 2804, 2802, 2797, 2805, 2805, 2805, 2805, 
	2805, 2805, 69, 2806, 2806, 2806, 2806, 69, 
	2807, 2807, 2807, 2807, 69, 2808, 1596, 2809, 
	2809, 2810, 2811, 2813, 2814, 2812, 1596, 2815, 
	2815, 2816, 2817, 2819, 2820, 2818, 1596, 2821, 
	2821, 2822, 2823, 2825, 2826, 2824, 1596, 2827, 
	2827, 2828, 2829, 2831, 2832, 2830, 2830, 2830, 
	69, 2833, 2833, 2834, 2835, 2836, 2837, 69, 
	2833, 2833, 2834, 2835, 2838, 2836, 2837, 2838, 
	2838, 2838, 69, 2839, 2839, 69, 2836, 2837, 
	69, 2831, 2832, 69, 2819, 2820, 69, 2840, 
	2840, 2840, 2840, 69, 2841, 2841, 69, 2842, 
	1596, 2843, 2843, 2844, 2845, 2847, 2848, 2846, 
	1596, 2849, 2849, 2850, 2851, 2853, 2854, 2852, 
	1596, 2855, 2855, 2856, 2857, 2859, 2860, 2858, 
	1596, 2861, 2861, 2862, 2863, 2865, 2866, 2864, 
	1596, 2867, 2867, 2868, 2869, 2871, 2872, 2870, 
	1596, 2873, 2873, 2874, 2875, 2876, 2878, 2879, 
	2877, 2877, 2877, 2197, 2880, 2880, 2881, 2882, 
	2883, 2884, 2197, 2886, 2886, 2887, 2888, 2890, 
	2891, 2889, 2889, 2889, 2885, 2892, 2892, 2892, 
	2885, 2894, 2893, 2893, 2893, 2885, 2895, 2895, 
	2895, 2885, 2897, 2896, 2896, 2896, 2885, 2899, 
	2898, 2898, 2898, 2885, 2900, 2900, 2900, 2885, 
	2902, 2901, 2901, 2901, 2885, 2903, 2903, 2903, 
	2903, 2904, 2904, 2904, 2885, 2905, 2905, 2905, 
	2905, 69, 2906, 2885, 2902, 2885, 2899, 2885, 
	2907, 2885, 2897, 2885, 2890, 2891, 69, 2908, 
	2908, 2908, 2197, 2880, 2880, 2881, 2882, 2883, 
	2884, 2909, 2909, 2909, 2197, 2878, 2879, 69, 
	2865, 2866, 69, 2853, 2854, 69, 2910, 1596, 
	2911, 2911, 2912, 2913, 2915, 2916, 2914, 1596, 
	2917, 2917, 2918, 2919, 2921, 2922, 2920, 1596, 
	2923, 2923, 2924, 2925, 2927, 2928, 2926, 1596, 
	2929, 2929, 2930, 2931, 2933, 2934, 2932, 1596, 
	2935, 2935, 2936, 2937, 2939, 2940, 2938, 1596, 
	2941, 2941, 2942, 2943, 2944, 2946, 2947, 2945, 
	2945, 2945, 2197, 2948, 2948, 2948, 2948, 2197, 
	2949, 2949, 2949, 2197, 2948, 2948, 2948, 2948, 
	2950, 2950, 2950, 2197, 2946, 2947, 69, 2933, 
	2934, 69, 2921, 2922, 69, 2951, 1596, 2952, 
	2952, 2953, 2954, 2956, 2957, 2955, 1596, 2958, 
	2958, 2959, 2960, 2962, 2963, 2961, 1596, 2964, 
	2964, 2965, 2966, 2968, 2969, 2967, 1596, 2970, 
	2970, 2971, 2972, 2974, 2975, 2973, 1596, 2976, 
	2976, 2977, 2978, 2980, 2981, 2979, 1596, 2982, 
	2982, 2983, 2984, 2986, 2987, 2985, 2985, 2985, 
	2197, 2988, 2988, 2988, 2197, 2989, 2989, 2990, 
	2991, 2992, 2993, 2994, 2994, 2995, 2996, 2985, 
	2985, 2985, 2197, 2992, 2993, 2197, 2986, 2987, 
	69, 2974, 2975, 69, 2962, 2963, 69, 2997, 
	2997, 2997, 2197, 2998, 2998, 2998, 2197, 2999, 
	2197, 3000, 3000, 3000, 2197, 3001, 3001, 3001, 
	2197, 3002, 2999, 3002, 3002, 3002, 2197, 3003, 
	3003, 3003, 2197, 3004, 3004, 3004, 2197, 3005, 
	2197, 3006, 3006, 3006, 2197, 3007, 3007, 3007, 
	2197, 3008, 3005, 3008, 3008, 3008, 2197, 3010, 
	3010, 3011, 3012, 3013, 3014, 3014, 3014, 19, 
	20, 3015, 3016, 3014, 3014, 3014, 3009, 3017, 
	3017, 3018, 3019, 3020, 3021, 67, 3022, 3021, 
	19, 20, 3023, 3024, 121, 122, 3025, 3026, 
	67, 67, 3021, 67, 3021, 67, 3021, 67, 
	658, 3028, 3028, 3011, 3029, 3030, 3014, 3031, 
	3032, 3033, 3034, 3035, 3036, 3037, 3038, 3039, 
	3040, 3041, 3042, 3043, 3044, 3014, 3014, 3031, 
	3032, 3033, 3034, 3035, 3036, 3037, 3038, 3039, 
	3040, 3041, 3042, 3043, 3044, 19, 20, 3045, 
	3046, 3014, 3014, 3014, 3027, 3028, 3028, 3011, 
	3029, 3030, 3014, 3049, 3050, 3051, 3052, 3053, 
	3054, 3055, 3056, 3057, 3058, 3059, 3060, 3061, 
	3062, 3014, 3014, 3049, 3050, 3051, 3052, 3053, 
	3054, 3055, 3056, 3057, 3058, 3059, 3060, 3061, 
	3062, 19, 20, 3045, 3046, 3014, 3048, 3014, 
	3014, 3047, 3064, 3064, 3065, 3066, 3067, 3068, 
	3068, 3068, 3069, 3070, 3071, 3072, 3068, 3068, 
	3068, 3063, 3010, 3010, 3011, 3073, 3074, 3014, 
	3049, 3050, 3051, 3052, 3053, 3054, 3055, 3056, 
	3057, 3058, 3059, 3060, 3061, 3062, 3014, 3014, 
	3049, 3050, 3051, 3052, 3053, 3054, 3055, 3056, 
	3057, 3058, 3059, 3060, 3061, 3062, 19, 20, 
	3075, 3016, 3014, 3048, 3014, 3014, 3047, 3076, 
	3076, 3011, 3077, 3078, 3014, 3014, 3014, 88, 
	89, 3079, 3080, 3014, 3014, 3014, 658, 3081, 
	3081, 3018, 3082, 3083, 3021, 67, 3022, 3021, 
	88, 89, 3079, 3084, 96, 97, 3079, 3085, 
	67, 67, 3021, 67, 3021, 67, 3021, 67, 
	658, 3017, 3017, 3018, 3019, 3020, 3021, 67, 
	3088, 3089, 3090, 3091, 3092, 3093, 3094, 3095, 
	3096, 3097, 3098, 3099, 3100, 3101, 3022, 3021, 
	3088, 3089, 3090, 3091, 3092, 3093, 3094, 3095, 
	3096, 3097, 3098, 3099, 3100, 3101, 19, 20, 
	3023, 3024, 121, 122, 3025, 3026, 67, 67, 
	3021, 3087, 67, 3021, 67, 3021, 67, 3086, 
	3081, 3081, 3018, 3082, 3083, 3021, 67, 3088, 
	3089, 3090, 3091, 3092, 3093, 3094, 3095, 3096, 
	3097, 3098, 3099, 3100, 3101, 3022, 3021, 3088, 
	3089, 3090, 3091, 3092, 3093, 3094, 3095, 3096, 
	3097, 3098, 3099, 3100, 3101, 88, 89, 3102, 
	3084, 96, 97, 3102, 3085, 67, 67, 3021, 
	3087, 67, 3021, 67, 3021, 67, 3086, 580, 
	580, 580, 781, 778, 781, 780, 781, 778, 
	782, 778, 777, 580, 580, 580, 918, 918, 
	919, 920, 888, 890, 891, 889, 921, 922, 
	889, 889, 889, 895, 580, 929, 929, 930, 
	931, 924, 932, 933, 934, 934, 935, 936, 
	924, 924, 924, 923, 932, 933, 923, 580, 
	946, 946, 947, 948, 949, 950, 951, 952, 
	953, 954, 955, 956, 957, 958, 959, 960, 
	961, 962, 949, 950, 951, 952, 953, 954, 
	955, 956, 957, 958, 959, 960, 961, 962, 
	963, 964, 965, 965, 966, 967, 937, 963, 
	964, 937, 580, 1367, 1367, 1368, 1369, 1370, 
	1371, 1372, 1372, 1373, 1374, 1363, 1363, 1363, 
	1359, 1370, 1371, 1359, 1389, 1389, 1390, 1391, 
	1393, 1394, 1392, 1392, 1392, 1359, 1345, 1396, 
	1396, 1397, 1398, 1399, 1400, 1401, 1401, 1402, 
	1403, 1392, 1392, 1392, 1359, 1399, 1400, 1359, 
	1393, 1394, 1345, 580, 580, 580, 580, 580, 
	580, 580, 580, 580, 1771, 1771, 1772, 1773, 
	1774, 1775, 1776, 1776, 1777, 1778, 1762, 1762, 
	1762, 69, 1774, 1775, 69, 580, 580, 1942, 
	1942, 1943, 1944, 1945, 1946, 1891, 1891, 1947, 
	1948, 1782, 1945, 1946, 1782, 1924, 1924, 1925, 
	1926, 1928, 1929, 1891, 1891, 1930, 1931, 1927, 
	1782, 1928, 1929, 1782, 1905, 1905, 1906, 1907, 
	1909, 1910, 1891, 1891, 1911, 1912, 1908, 1782, 
	1909, 1910, 1782, 1885, 1885, 1886, 1887, 1889, 
	1890, 1891, 1891, 1892, 1893, 1888, 1782, 1889, 
	1890, 1782, 580, 580, 580, 580, 2140, 2140, 
	2141, 2142, 2143, 2144, 2145, 2146, 2147, 2148, 
	2148, 2149, 2150, 2139, 2146, 2147, 69, 580, 
	2205, 2205, 2206, 2207, 2208, 2209, 2210, 2210, 
	2211, 2212, 2201, 2201, 2201, 2197, 2208, 2209, 
	2197, 580, 2239, 2239, 2240, 2241, 2242, 2243, 
	2244, 2244, 2245, 2246, 2235, 2235, 2235, 2197, 
	2242, 2243, 2197, 580, 2287, 2287, 2288, 2289, 
	2293, 2293, 2293, 2293, 2298, 2299, 2293, 2293, 
	2300, 2301, 2306, 2298, 2299, 2306, 2284, 2284, 
	2285, 2286, 2307, 2294, 2295, 2307, 2307, 2307, 
	2306, 2294, 2295, 2306, 2307, 2284, 2284, 2285, 
	2286, 2287, 2287, 2288, 2289, 2290, 2290, 2291, 
	2292, 2293, 2293, 2293, 2293, 2294, 2295, 2293, 
	2293, 2296, 2297, 2298, 2299, 2293, 2293, 2300, 
	2301, 2302, 2303, 2293, 2293, 2304, 2305, 2307, 
	2307, 2307, 2306, 2294, 2298, 2302, 2295, 2299, 
	2303, 2306, 580, 580, 580, 580, 580, 580, 
	580, 2989, 2989, 2990, 2991, 2992, 2993, 2994, 
	2994, 2995, 2996, 2985, 2985, 2985, 2197, 2992, 
	2993, 2197, 580, 580, 0
};

static const short _zone_scanner_trans_targs[] = {
	0, 1, 1, 1, 2, 4, 17, 26, 
	40, 47, 123, 63, 67, 70, 76, 90, 
	93, 100, 111, 1021, 131, 1026, 236, 0, 
	3, 3, 3, 2, 146, 146, 146, 146, 
	146, 3, 149, 0, 3, 3, 3, 4, 
	17, 26, 40, 47, 52, 63, 67, 70, 
	76, 90, 93, 100, 111, 3, 149, 0, 
	5, 5, 5, 207, 210, 214, 5, 11, 
	10, 12, 21, 6, 5, 0, 5, 5, 
	9, 5, 11, 10, 12, 21, 0, 7, 
	7, 7, 1021, 8, 0, 7, 7, 7, 
	1021, 8, 6, 10, 12, 12, 12, 13, 
	1027, 156, 220, 1022, 14, 0, 14, 14, 
	15, 152, 159, 160, 161, 162, 163, 164, 
	165, 166, 167, 168, 169, 170, 171, 1029, 
	216, 1027, 217, 1030, 219, 0, 16, 16, 
	16, 1023, 239, 0, 16, 16, 16, 1023, 
	239, 18, 22, 19, 20, 5, 5, 5, 
	5, 11, 10, 12, 21, 21, 21, 21, 
	23, 24, 25, 5, 5, 5, 5, 11, 
	10, 12, 21, 27, 31, 39, 28, 29, 
	30, 5, 5, 5, 5, 11, 10, 12, 
	21, 32, 35, 33, 34, 5, 5, 5, 
	5, 11, 10, 12, 21, 36, 37, 38, 
	5, 5, 5, 5, 11, 10, 12, 21, 
	5, 5, 5, 5, 11, 10, 12, 21, 
	41, 42, 43, 45, 44, 5, 5, 5, 
	5, 11, 10, 12, 21, 46, 5, 5, 
	5, 5, 11, 10, 12, 21, 48, 49, 
	50, 51, 5, 5, 5, 5, 11, 10, 
	12, 21, 53, 56, 54, 54, 54, 54, 
	121, 54, 54, 54, 4, 17, 26, 40, 
	47, 55, 63, 67, 70, 76, 90, 93, 
	100, 111, 54, 121, 57, 58, 59, 60, 
	61, 62, 5, 5, 5, 5, 11, 10, 
	12, 21, 64, 66, 65, 5, 5, 5, 
	5, 11, 10, 12, 21, 5, 5, 5, 
	5, 11, 10, 12, 21, 68, 69, 5, 
	5, 5, 5, 11, 10, 12, 21, 71, 
	75, 72, 73, 74, 5, 5, 5, 5, 
	11, 10, 12, 21, 5, 5, 5, 5, 
	11, 10, 12, 21, 77, 81, 78, 79, 
	80, 5, 5, 5, 5, 11, 10, 12, 
	21, 5, 5, 5, 82, 5, 11, 10, 
	12, 21, 83, 5, 5, 5, 84, 5, 
	11, 10, 12, 21, 5, 5, 5, 85, 
	5, 11, 10, 12, 21, 86, 87, 88, 
	89, 5, 5, 5, 5, 11, 10, 12, 
	21, 91, 92, 5, 5, 5, 5, 11, 
	10, 12, 21, 94, 95, 99, 5, 5, 
	5, 5, 11, 10, 12, 21, 96, 97, 
	98, 5, 5, 5, 5, 11, 10, 12, 
	21, 5, 5, 5, 5, 11, 10, 12, 
	21, 101, 103, 105, 107, 102, 5, 5, 
	5, 5, 11, 10, 12, 21, 104, 5, 
	5, 5, 5, 11, 10, 12, 21, 106, 
	5, 5, 5, 5, 11, 10, 12, 21, 
	108, 109, 110, 5, 5, 5, 5, 11, 
	10, 12, 21, 112, 115, 117, 113, 114, 
	5, 5, 5, 5, 11, 10, 12, 21, 
	116, 5, 5, 5, 5, 11, 10, 12, 
	21, 118, 119, 0, 120, 0, 5, 5, 
	5, 120, 5, 11, 10, 12, 21, 122, 
	122, 122, 1024, 237, 124, 125, 125, 125, 
	125, 130, 125, 125, 125, 126, 4, 17, 
	26, 40, 47, 55, 63, 67, 70, 76, 
	90, 93, 100, 111, 125, 130, 54, 54, 
	54, 126, 127, 127, 127, 127, 127, 54, 
	121, 128, 128, 129, 129, 129, 129, 129, 
	54, 54, 54, 128, 54, 121, 0, 133, 
	174, 180, 134, 135, 136, 137, 138, 139, 
	1025, 0, 141, 141, 141, 141, 142, 141, 
	141, 141, 141, 142, 0, 0, 144, 144, 
	144, 144, 145, 144, 144, 144, 144, 145, 
	147, 147, 148, 148, 148, 148, 148, 3, 
	3, 3, 147, 3, 149, 0, 151, 151, 
	151, 151, 221, 158, 222, 151, 151, 151, 
	151, 221, 158, 222, 0, 153, 153, 153, 
	1022, 13, 1027, 156, 1028, 220, 153, 153, 
	153, 1028, 154, 154, 154, 1026, 155, 157, 
	157, 157, 158, 158, 158, 172, 206, 1029, 
	0, 175, 176, 177, 178, 179, 1025, 181, 
	182, 1025, 0, 154, 154, 154, 1026, 155, 
	0, 185, 185, 185, 1024, 186, 185, 185, 
	185, 1024, 186, 0, 188, 188, 188, 1029, 
	172, 1030, 206, 188, 188, 188, 1030, 203, 
	0, 203, 203, 203, 204, 154, 154, 154, 
	1026, 155, 205, 205, 205, 205, 205, 205, 
	206, 206, 206, 208, 209, 5, 5, 5, 
	5, 11, 10, 12, 21, 211, 212, 213, 
	5, 5, 5, 5, 11, 10, 12, 21, 
	215, 5, 5, 5, 5, 11, 10, 12, 
	21, 218, 218, 218, 219, 219, 219, 220, 
	220, 220, 222, 222, 222, 0, 241, 1031, 
	241, 1031, 0, 243, 245, 250, 251, 246, 
	1032, 244, 1032, 243, 245, 246, 245, 246, 
	247, 0, 248, 249, 1032, 245, 244, 246, 
	1032, 0, 253, 258, 254, 1033, 1034, 255, 
	0, 256, 257, 1033, 253, 1034, 254, 258, 
	259, 260, 0, 261, 262, 263, 258, 259, 
	260, 0, 265, 265, 265, 265, 272, 0, 
	266, 0, 267, 267, 267, 266, 269, 269, 
	269, 269, 269, 1035, 268, 0, 270, 0, 
	270, 271, 271, 271, 271, 271, 267, 267, 
	267, 270, 1035, 268, 0, 274, 274, 274, 
	274, 285, 275, 279, 284, 280, 276, 0, 
	277, 277, 277, 275, 279, 280, 1036, 278, 
	277, 277, 277, 1036, 278, 279, 280, 281, 
	0, 282, 283, 279, 276, 280, 287, 287, 
	287, 287, 303, 288, 0, 0, 289, 289, 
	289, 1037, 293, 300, 0, 289, 289, 289, 
	290, 294, 299, 295, 1037, 293, 300, 0, 
	291, 292, 292, 292, 290, 294, 295, 1037, 
	293, 292, 292, 292, 294, 295, 296, 0, 
	297, 298, 294, 291, 295, 1038, 301, 301, 
	301, 301, 302, 0, 305, 306, 307, 310, 
	308, 308, 308, 308, 308, 309, 1039, 1040, 
	1041, 0, 312, 312, 312, 312, 317, 1042, 
	1043, 1044, 312, 312, 312, 313, 318, 326, 
	340, 347, 352, 360, 364, 367, 373, 387, 
	390, 397, 408, 312, 317, 1042, 1043, 1044, 
	312, 312, 312, 314, 418, 422, 312, 317, 
	1042, 1043, 1044, 315, 316, 312, 312, 312, 
	312, 317, 1042, 1043, 1044, 319, 322, 320, 
	321, 312, 312, 312, 312, 317, 1042, 1043, 
	1044, 323, 324, 325, 312, 312, 312, 312, 
	317, 1042, 1043, 1044, 327, 331, 339, 328, 
	329, 330, 312, 312, 312, 312, 317, 1042, 
	1043, 1044, 332, 335, 333, 334, 312, 312, 
	312, 312, 317, 1042, 1043, 1044, 336, 337, 
	338, 312, 312, 312, 312, 317, 1042, 1043, 
	1044, 312, 312, 312, 312, 317, 1042, 1043, 
	1044, 341, 342, 343, 345, 344, 312, 312, 
	312, 312, 317, 1042, 1043, 1044, 346, 312, 
	312, 312, 312, 317, 1042, 1043, 1044, 348, 
	349, 350, 351, 312, 312, 312, 312, 317, 
	1042, 1043, 1044, 353, 354, 355, 356, 357, 
	358, 359, 312, 312, 312, 312, 317, 1042, 
	1043, 1044, 361, 363, 362, 312, 312, 312, 
	312, 317, 1042, 1043, 1044, 312, 312, 312, 
	312, 317, 1042, 1043, 1044, 365, 366, 312, 
	312, 312, 312, 317, 1042, 1043, 1044, 368, 
	372, 369, 370, 371, 312, 312, 312, 312, 
	317, 1042, 1043, 1044, 312, 312, 312, 312, 
	317, 1042, 1043, 1044, 374, 378, 375, 376, 
	377, 312, 312, 312, 312, 317, 1042, 1043, 
	1044, 312, 312, 312, 379, 312, 317, 1042, 
	1043, 1044, 380, 312, 312, 312, 381, 312, 
	317, 1042, 1043, 1044, 312, 312, 312, 382, 
	312, 317, 1042, 1043, 1044, 383, 384, 385, 
	386, 312, 312, 312, 312, 317, 1042, 1043, 
	1044, 388, 389, 312, 312, 312, 312, 317, 
	1042, 1043, 1044, 391, 392, 396, 312, 312, 
	312, 312, 317, 1042, 1043, 1044, 393, 394, 
	395, 312, 312, 312, 312, 317, 1042, 1043, 
	1044, 312, 312, 312, 312, 317, 1042, 1043, 
	1044, 398, 400, 402, 404, 399, 312, 312, 
	312, 312, 317, 1042, 1043, 1044, 401, 312, 
	312, 312, 312, 317, 1042, 1043, 1044, 403, 
	312, 312, 312, 312, 317, 1042, 1043, 1044, 
	405, 406, 407, 312, 312, 312, 312, 317, 
	1042, 1043, 1044, 409, 412, 414, 410, 411, 
	312, 312, 312, 312, 317, 1042, 1043, 1044, 
	413, 312, 312, 312, 312, 317, 1042, 1043, 
	1044, 415, 416, 417, 312, 312, 312, 417, 
	312, 317, 1042, 1043, 1044, 419, 420, 421, 
	312, 312, 312, 312, 317, 1042, 1043, 1044, 
	423, 312, 312, 312, 312, 317, 1042, 1043, 
	1044, 0, 425, 425, 425, 425, 432, 0, 
	426, 427, 427, 427, 426, 427, 431, 0, 
	427, 427, 427, 428, 427, 431, 429, 429, 
	429, 429, 429, 430, 1045, 1046, 1047, 434, 
	434, 434, 434, 442, 435, 441, 1048, 1048, 
	1048, 441, 1049, 1048, 1052, 436, 436, 436, 
	437, 436, 440, 438, 438, 438, 438, 438, 
	439, 1049, 1050, 1051, 436, 436, 436, 436, 
	440, 0, 444, 445, 460, 490, 498, 511, 
	1053, 444, 446, 447, 1053, 448, 1053, 449, 
	450, 451, 452, 453, 454, 455, 456, 457, 
	458, 459, 1053, 461, 462, 468, 463, 464, 
	465, 466, 467, 1053, 469, 470, 471, 472, 
	481, 473, 474, 475, 476, 477, 478, 479, 
	480, 1053, 482, 483, 484, 485, 486, 487, 
	488, 489, 1053, 491, 492, 493, 494, 495, 
	496, 497, 1053, 499, 500, 501, 502, 503, 
	504, 505, 508, 506, 507, 1053, 509, 510, 
	1053, 512, 513, 514, 517, 515, 516, 1053, 
	518, 519, 520, 532, 535, 1053, 521, 522, 
	523, 524, 525, 526, 527, 528, 529, 530, 
	531, 1053, 533, 534, 1053, 536, 537, 1053, 
	0, 539, 540, 546, 563, 566, 572, 576, 
	1054, 539, 541, 542, 543, 544, 545, 1054, 
	547, 553, 559, 548, 549, 550, 551, 552, 
	1054, 554, 556, 555, 1054, 557, 558, 1054, 
	560, 561, 562, 1054, 564, 565, 1054, 567, 
	569, 568, 1054, 570, 571, 1054, 573, 574, 
	575, 1054, 577, 578, 1054, 0, 580, 1055, 
	580, 582, 1056, 584, 585, 585, 585, 585, 
	614, 585, 585, 585, 586, 585, 614, 587, 
	587, 587, 587, 613, 0, 587, 587, 587, 
	588, 587, 613, 589, 589, 589, 588, 589, 
	612, 589, 589, 589, 590, 589, 612, 0, 
	591, 591, 591, 590, 609, 609, 609, 609, 
	609, 591, 608, 591, 591, 591, 592, 591, 
	608, 593, 593, 593, 592, 605, 605, 605, 
	605, 605, 593, 604, 593, 593, 593, 594, 
	593, 604, 595, 595, 595, 594, 601, 601, 
	601, 601, 601, 595, 600, 595, 595, 595, 
	596, 595, 600, 1057, 596, 597, 597, 597, 
	597, 597, 598, 598, 599, 599, 599, 599, 
	599, 1057, 598, 602, 602, 603, 603, 603, 
	603, 603, 595, 595, 595, 602, 595, 600, 
	606, 606, 607, 607, 607, 607, 607, 593, 
	593, 593, 606, 593, 604, 610, 610, 611, 
	611, 611, 611, 611, 591, 591, 591, 610, 
	591, 608, 616, 617, 617, 617, 617, 619, 
	618, 617, 617, 617, 617, 619, 1058, 621, 
	622, 622, 622, 622, 624, 622, 622, 622, 
	623, 622, 624, 1059, 626, 627, 627, 627, 
	626, 627, 629, 627, 627, 627, 628, 627, 
	629, 1060, 631, 632, 632, 632, 632, 633, 
	1061, 1062, 1063, 632, 632, 632, 632, 633, 
	1061, 1062, 1063, 635, 1064, 635, 0, 637, 
	638, 638, 638, 637, 638, 690, 638, 638, 
	638, 639, 643, 685, 638, 690, 640, 640, 
	640, 639, 640, 689, 640, 640, 640, 641, 
	640, 689, 642, 642, 642, 687, 641, 642, 
	686, 642, 642, 642, 642, 686, 644, 644, 
	644, 644, 684, 645, 646, 646, 646, 645, 
	646, 683, 646, 646, 646, 647, 651, 678, 
	646, 683, 648, 648, 648, 647, 648, 682, 
	648, 648, 648, 649, 648, 682, 650, 650, 
	650, 680, 649, 650, 679, 650, 650, 650, 
	650, 679, 652, 652, 652, 652, 677, 653, 
	654, 654, 655, 655, 655, 674, 654, 676, 
	655, 673, 1065, 1072, 1073, 655, 655, 655, 
	656, 655, 673, 1065, 1072, 1073, 657, 657, 
	657, 670, 656, 672, 657, 669, 1065, 1070, 
	1071, 657, 657, 657, 658, 657, 669, 1070, 
	1071, 659, 659, 659, 666, 658, 668, 659, 
	665, 1065, 1068, 1069, 659, 659, 659, 660, 
	659, 665, 1068, 1069, 661, 661, 661, 663, 
	660, 661, 662, 1065, 1066, 1067, 661, 661, 
	661, 661, 662, 1066, 1067, 661, 661, 661, 
	664, 661, 662, 1065, 1066, 1067, 664, 659, 
	659, 659, 667, 668, 659, 665, 1065, 1068, 
	1069, 667, 657, 657, 657, 671, 672, 657, 
	669, 1065, 1070, 1071, 671, 655, 655, 655, 
	675, 676, 655, 673, 1065, 1072, 1073, 675, 
	652, 652, 652, 652, 677, 650, 650, 650, 
	681, 650, 679, 681, 644, 644, 644, 644, 
	684, 642, 642, 642, 688, 642, 686, 688, 
	692, 693, 693, 693, 692, 693, 701, 693, 
	693, 693, 694, 693, 701, 695, 695, 695, 
	694, 695, 700, 695, 695, 695, 696, 695, 
	700, 697, 697, 697, 696, 697, 699, 697, 
	697, 697, 698, 697, 699, 1074, 703, 704, 
	704, 704, 703, 704, 718, 704, 704, 704, 
	705, 704, 718, 706, 706, 706, 705, 706, 
	717, 707, 706, 706, 706, 706, 717, 708, 
	708, 708, 708, 716, 709, 708, 708, 708, 
	708, 716, 710, 710, 710, 710, 715, 711, 
	710, 710, 710, 710, 715, 712, 712, 712, 
	712, 714, 712, 712, 712, 713, 712, 714, 
	1075, 720, 721, 721, 721, 721, 729, 722, 
	723, 723, 723, 722, 723, 728, 723, 723, 
	723, 724, 723, 728, 725, 725, 725, 725, 
	727, 726, 1076, 0, 730, 731, 730, 730, 
	732, 738, 730, 737, 1077, 1078, 1079, 732, 
	738, 733, 0, 734, 734, 735, 736, 730, 
	730, 730, 736, 730, 737, 1077, 1078, 1079, 
	739, 740, 740, 735, 742, 743, 743, 743, 
	742, 743, 753, 743, 743, 743, 744, 743, 
	753, 745, 745, 745, 745, 752, 746, 747, 
	747, 747, 746, 747, 751, 0, 747, 747, 
	747, 748, 747, 751, 749, 749, 749, 749, 
	749, 750, 1080, 1081, 1082, 755, 756, 756, 
	756, 755, 756, 763, 756, 756, 756, 757, 
	756, 763, 758, 758, 758, 757, 758, 762, 
	758, 758, 758, 759, 758, 762, 760, 760, 
	760, 760, 760, 761, 1083, 1084, 1085, 765, 
	766, 766, 766, 765, 766, 802, 0, 766, 
	766, 766, 767, 781, 788, 795, 766, 802, 
	768, 768, 768, 768, 780, 0, 769, 770, 
	770, 770, 769, 770, 779, 770, 770, 770, 
	771, 770, 779, 0, 772, 772, 772, 775, 
	775, 775, 777, 777, 777, 1086, 772, 774, 
	1089, 1090, 775, 776, 1087, 1088, 777, 778, 
	1091, 1092, 0, 773, 782, 782, 782, 782, 
	787, 783, 784, 784, 784, 783, 784, 786, 
	0, 784, 784, 784, 785, 784, 786, 0, 
	785, 772, 772, 772, 775, 775, 775, 777, 
	777, 777, 1086, 772, 774, 1089, 1090, 775, 
	776, 1087, 1088, 777, 778, 1091, 1092, 789, 
	789, 789, 789, 794, 790, 791, 791, 791, 
	790, 791, 793, 791, 791, 791, 792, 791, 
	793, 792, 772, 772, 772, 775, 775, 775, 
	777, 777, 777, 1086, 772, 774, 1089, 1090, 
	775, 776, 1087, 1088, 777, 778, 1091, 1092, 
	796, 796, 796, 796, 801, 797, 798, 798, 
	798, 797, 798, 800, 798, 798, 798, 799, 
	798, 800, 772, 772, 772, 775, 775, 775, 
	777, 777, 777, 1086, 772, 774, 1089, 1090, 
	775, 776, 1087, 1088, 777, 778, 1091, 1092, 
	0, 804, 838, 846, 860, 867, 872, 880, 
	884, 887, 893, 907, 910, 917, 928, 805, 
	805, 805, 829, 832, 836, 805, 828, 805, 
	805, 805, 806, 805, 828, 807, 807, 807, 
	807, 827, 808, 809, 809, 809, 808, 809, 
	826, 809, 809, 809, 810, 809, 826, 811, 
	811, 811, 810, 811, 825, 0, 811, 811, 
	811, 812, 811, 825, 813, 813, 813, 812, 
	813, 824, 813, 813, 813, 814, 813, 824, 
	815, 815, 815, 814, 815, 823, 815, 815, 
	815, 816, 815, 823, 817, 817, 817, 816, 
	817, 822, 817, 817, 817, 818, 817, 822, 
	819, 819, 819, 819, 821, 819, 819, 819, 
	820, 819, 821, 1093, 830, 831, 805, 805, 
	805, 805, 828, 833, 834, 835, 805, 805, 
	805, 805, 828, 837, 805, 805, 805, 805, 
	828, 839, 842, 840, 841, 805, 805, 805, 
	805, 828, 843, 844, 845, 805, 805, 805, 
	805, 828, 847, 851, 859, 848, 849, 850, 
	805, 805, 805, 805, 828, 852, 855, 853, 
	854, 805, 805, 805, 805, 828, 856, 857, 
	858, 805, 805, 805, 805, 828, 805, 805, 
	805, 805, 828, 861, 862, 863, 865, 864, 
	805, 805, 805, 805, 828, 866, 805, 805, 
	805, 805, 828, 868, 869, 870, 871, 805, 
	805, 805, 805, 828, 873, 874, 875, 876, 
	877, 878, 879, 805, 805, 805, 805, 828, 
	881, 883, 882, 805, 805, 805, 805, 828, 
	805, 805, 805, 805, 828, 885, 886, 805, 
	805, 805, 805, 828, 888, 892, 889, 890, 
	891, 805, 805, 805, 805, 828, 805, 805, 
	805, 805, 828, 894, 898, 895, 896, 897, 
	805, 805, 805, 805, 828, 805, 805, 805, 
	899, 805, 828, 900, 805, 805, 805, 901, 
	805, 828, 805, 805, 805, 902, 805, 828, 
	903, 904, 905, 906, 805, 805, 805, 805, 
	828, 908, 909, 805, 805, 805, 805, 828, 
	911, 912, 916, 805, 805, 805, 805, 828, 
	913, 914, 915, 805, 805, 805, 805, 828, 
	805, 805, 805, 805, 828, 918, 920, 922, 
	924, 919, 805, 805, 805, 805, 828, 921, 
	805, 805, 805, 805, 828, 923, 805, 805, 
	805, 805, 828, 925, 926, 927, 805, 805, 
	805, 805, 828, 929, 932, 934, 930, 931, 
	805, 805, 805, 805, 828, 933, 805, 805, 
	805, 805, 828, 935, 936, 0, 937, 805, 
	805, 805, 937, 805, 828, 939, 940, 1094, 
	942, 943, 943, 943, 942, 943, 951, 943, 
	943, 943, 944, 943, 951, 945, 945, 945, 
	944, 945, 950, 945, 945, 945, 946, 945, 
	950, 947, 947, 947, 947, 949, 948, 1095, 
	953, 1096, 955, 956, 956, 956, 955, 956, 
	982, 956, 956, 956, 957, 956, 982, 958, 
	958, 958, 957, 958, 981, 958, 958, 958, 
	959, 958, 981, 960, 960, 960, 959, 960, 
	980, 960, 960, 960, 961, 978, 960, 980, 
	962, 962, 962, 962, 977, 0, 962, 962, 
	962, 963, 962, 977, 964, 965, 975, 966, 
	967, 974, 968, 972, 969, 970, 970, 971, 
	963, 1097, 973, 976, 979, 978, 984, 985, 
	985, 985, 984, 985, 995, 985, 985, 985, 
	986, 985, 995, 987, 987, 987, 986, 987, 
	994, 987, 987, 987, 988, 987, 994, 989, 
	989, 989, 988, 989, 993, 989, 989, 989, 
	990, 991, 989, 993, 1098, 992, 991, 997, 
	998, 998, 998, 997, 998, 1008, 998, 998, 
	998, 999, 998, 1008, 1000, 1000, 1000, 999, 
	1000, 1007, 1000, 1000, 1000, 1001, 1000, 1007, 
	1002, 1002, 1002, 1001, 1002, 1006, 1002, 1002, 
	1002, 1003, 1002, 1006, 1004, 1004, 1004, 1004, 
	1004, 1005, 1099, 1100, 1101, 1010, 1011, 1012, 
	1013, 1014, 1102, 1016, 1017, 1018, 1019, 1020, 
	1103, 0, 1, 132, 1, 1, 140, 1026, 
	236, 14, 173, 14, 14, 183, 202, 1029, 
	216, 1030, 219, 0, 122, 122, 122, 150, 
	223, 224, 225, 226, 238, 228, 229, 230, 
	231, 232, 233, 234, 235, 1024, 237, 0, 
	143, 150, 223, 224, 225, 226, 227, 228, 
	229, 230, 231, 232, 233, 234, 235, 0, 
	1, 132, 1, 1, 140, 1021, 131, 1026, 
	236, 1, 1, 1026, 154, 154, 154, 1026, 
	155, 158, 158, 158, 172, 206, 0, 184, 
	187, 189, 190, 191, 192, 193, 194, 195, 
	196, 197, 198, 199, 200, 201, 1026
};

static const short _zone_scanner_trans_actions[] = {
	1767, 0, 5, 7, 488, 641, 641, 641, 
	641, 641, 641, 641, 641, 641, 641, 641, 
	641, 641, 641, 3, 0, 3, 0, 1907, 
	101, 656, 659, 41, 55, 53, 51, 0, 
	57, 653, 101, 327, 0, 5, 7, 95, 
	95, 95, 95, 95, 95, 95, 95, 95, 
	95, 95, 95, 95, 95, 3, 0, 1499, 
	1502, 2247, 2251, 0, 0, 0, 2243, 1502, 
	2255, 3260, 2255, 321, 0, 319, 5, 7, 
	0, 3, 0, 321, 338, 321, 1478, 325, 
	1487, 1490, 2235, 325, 9, 0, 5, 7, 
	1604, 0, 1493, 323, 0, 5, 7, 0, 
	2231, 321, 321, 341, 0, 2885, 5, 7, 
	1755, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 
	1991, 1991, 1991, 1991, 1991, 1991, 1991, 3, 
	0, 1481, 321, 338, 321, 3541, 662, 1995, 
	1999, 3055, 662, 1496, 0, 5, 7, 341, 
	0, 0, 0, 0, 0, 1556, 2539, 2543, 
	2535, 1556, 2547, 3365, 2547, 0, 5, 7, 
	0, 0, 0, 1508, 2283, 2287, 2279, 1508, 
	2291, 3285, 2291, 0, 0, 0, 0, 0, 
	0, 1583, 2683, 2687, 2679, 1583, 2691, 3410, 
	2691, 0, 0, 0, 0, 1559, 2555, 2559, 
	2551, 1559, 2563, 3370, 2563, 0, 0, 0, 
	1580, 2667, 2671, 2663, 1580, 2675, 3405, 2675, 
	1565, 2587, 2591, 2583, 1565, 2595, 3380, 2595, 
	0, 0, 0, 0, 0, 1598, 2763, 2767, 
	2759, 1598, 2771, 3435, 2771, 0, 1601, 2779, 
	2783, 2775, 1601, 2787, 3440, 2787, 0, 0, 
	0, 0, 1517, 2331, 2335, 2327, 1517, 2339, 
	3300, 2339, 0, 0, 99, 647, 650, 644, 
	99, 0, 5, 7, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 3, 0, 0, 0, 0, 0, 
	0, 0, 1571, 2619, 2623, 2615, 1571, 2627, 
	3390, 2627, 0, 0, 0, 1538, 2443, 2447, 
	2439, 1538, 2451, 3335, 2451, 1553, 2523, 2527, 
	2519, 1553, 2531, 3360, 2531, 0, 0, 1544, 
	2475, 2479, 2471, 1544, 2483, 3345, 2483, 0, 
	0, 0, 0, 0, 1520, 2347, 2351, 2343, 
	1520, 2355, 3305, 2355, 1523, 2363, 2367, 2359, 
	1523, 2371, 3310, 2371, 0, 0, 0, 0, 
	0, 1550, 2507, 2511, 2503, 1550, 2515, 3355, 
	2515, 1505, 2267, 2271, 0, 2263, 1505, 2275, 
	3280, 2275, 0, 1577, 2651, 2655, 0, 2647, 
	1577, 2659, 3400, 2659, 1586, 2699, 2703, 0, 
	2695, 1586, 2707, 3415, 2707, 0, 0, 0, 
	0, 1589, 2715, 2719, 2711, 1589, 2723, 3420, 
	2723, 0, 0, 1514, 2315, 2319, 2311, 1514, 
	2323, 3295, 2323, 0, 0, 0, 1529, 2395, 
	2399, 2391, 1529, 2403, 3320, 2403, 0, 0, 
	0, 1574, 2635, 2639, 2631, 1574, 2643, 3395, 
	2643, 1535, 2427, 2431, 2423, 1535, 2435, 3330, 
	2435, 0, 0, 0, 0, 0, 1511, 2299, 
	2303, 2295, 1511, 2307, 3290, 2307, 0, 1595, 
	2747, 2751, 2743, 1595, 2755, 3430, 2755, 0, 
	1547, 2491, 2495, 2487, 1547, 2499, 3350, 2499, 
	0, 0, 0, 1568, 2603, 2607, 2599, 1568, 
	2611, 3385, 2611, 0, 0, 0, 0, 0, 
	1592, 2731, 2735, 2727, 1592, 2739, 3425, 2739, 
	0, 1526, 2379, 2383, 2375, 1526, 2387, 3315, 
	2387, 0, 0, 500, 488, 1771, 560, 1887, 
	1891, 41, 1883, 560, 1895, 3015, 1895, 0, 
	5, 7, 3, 0, 0, 99, 647, 650, 
	644, 99, 0, 5, 7, 488, 97, 97, 
	97, 97, 97, 97, 97, 97, 97, 97, 
	97, 97, 97, 97, 3, 0, 101, 656, 
	659, 41, 55, 53, 51, 0, 57, 653, 
	101, 1911, 41, 55, 53, 51, 0, 57, 
	581, 1935, 1939, 3025, 1931, 581, 93, 89, 
	89, 89, 0, 0, 0, 0, 0, 0, 
	87, 37, 33, 437, 440, 434, 33, 0, 
	5, 7, 3, 0, 0, 2870, 443, 1691, 
	1699, 1687, 443, 0, 5, 7, 3, 0, 
	1911, 41, 55, 53, 51, 0, 57, 581, 
	1935, 1939, 3025, 1931, 581, 1731, 1715, 2835, 
	2850, 2820, 1715, 3457, 2855, 0, 5, 7, 
	3, 0, 338, 321, 2239, 2259, 3265, 3270, 
	3559, 2259, 3614, 3275, 3607, 3275, 0, 5, 
	7, 1639, 0, 5, 7, 341, 0, 0, 
	5, 7, 0, 5, 7, 0, 321, 341, 
	2223, 0, 0, 0, 0, 0, 79, 0, 
	0, 75, 1723, 446, 1695, 1703, 2810, 446, 
	3572, 1707, 2825, 2840, 3451, 1707, 0, 5, 
	7, 341, 0, 2875, 2860, 3463, 3469, 3565, 
	2860, 3621, 3475, 0, 5, 7, 1639, 1711, 
	461, 2830, 2845, 2815, 1711, 325, 347, 353, 
	1643, 325, 325, 1487, 1490, 0, 5, 7, 
	0, 5, 7, 0, 0, 1541, 2459, 2463, 
	2455, 1541, 2467, 3340, 2467, 0, 0, 0, 
	1532, 2411, 2415, 2407, 1532, 2419, 3325, 2419, 
	0, 1562, 2571, 2575, 2567, 1562, 2579, 3375, 
	2579, 0, 5, 7, 0, 5, 7, 0, 
	5, 7, 0, 5, 7, 464, 362, 2795, 
	11, 1651, 27, 1667, 1667, 25, 0, 401, 
	1655, 17, 386, 365, 365, 13, 15, 0, 
	368, 377, 19, 19, 2800, 371, 374, 21, 
	398, 602, 65, 0, 0, 1, 599, 605, 
	1947, 69, 69, 608, 611, 1943, 71, 65, 
	0, 0, 67, 605, 69, 69, 611, 71, 
	71, 73, 0, 5, 7, 3, 0, 491, 
	488, 3020, 0, 5, 7, 41, 55, 53, 
	51, 0, 57, 1951, 0, 356, 1911, 1899, 
	41, 55, 53, 51, 0, 57, 59, 572, 
	575, 3025, 3030, 59, 77, 0, 5, 7, 
	3, 0, 3035, 3035, 614, 1955, 17, 359, 
	23, 389, 392, 365, 365, 13, 2805, 23, 
	0, 5, 7, 1959, 0, 15, 0, 368, 
	380, 19, 19, 371, 374, 21, 0, 5, 
	7, 3, 0, 617, 83, 626, 81, 620, 
	623, 3040, 81, 81, 632, 0, 5, 7, 
	3045, 3045, 629, 1963, 1967, 0, 0, 85, 
	17, 395, 1659, 1663, 365, 365, 13, 3445, 
	395, 0, 5, 7, 15, 0, 368, 383, 
	19, 19, 371, 374, 21, 1619, 0, 5, 
	7, 3, 0, 125, 117, 119, 121, 0, 
	123, 0, 5, 7, 3, 0, 1, 332, 
	1, 293, 291, 1406, 1409, 1403, 291, 2207, 
	3255, 2207, 0, 5, 7, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 3, 0, 1412, 1627, 1412, 
	223, 1100, 1103, 0, 0, 0, 1097, 223, 
	2071, 3085, 2071, 0, 0, 249, 1217, 1220, 
	1214, 249, 2123, 3150, 2123, 0, 0, 0, 
	0, 259, 1262, 1265, 1259, 259, 2143, 3175, 
	2143, 0, 0, 0, 227, 1118, 1121, 1115, 
	227, 2079, 3095, 2079, 0, 0, 0, 0, 
	0, 0, 277, 1343, 1346, 1340, 277, 2179, 
	3220, 2179, 0, 0, 0, 0, 261, 1271, 
	1274, 1268, 261, 2147, 3180, 2147, 0, 0, 
	0, 275, 1334, 1337, 1331, 275, 2175, 3215, 
	2175, 265, 1289, 1292, 1286, 265, 2155, 3190, 
	2155, 0, 0, 0, 0, 0, 287, 1388, 
	1391, 1385, 287, 2199, 3245, 2199, 0, 289, 
	1397, 1400, 1394, 289, 2203, 3250, 2203, 0, 
	0, 0, 0, 233, 1145, 1148, 1142, 233, 
	2091, 3110, 2091, 0, 0, 0, 0, 0, 
	0, 0, 269, 1307, 1310, 1304, 269, 2163, 
	3200, 2163, 0, 0, 0, 247, 1208, 1211, 
	1205, 247, 2119, 3145, 2119, 257, 1253, 1256, 
	1250, 257, 2139, 3170, 2139, 0, 0, 251, 
	1226, 1229, 1223, 251, 2127, 3155, 2127, 0, 
	0, 0, 0, 0, 235, 1154, 1157, 1151, 
	235, 2095, 3115, 2095, 237, 1163, 1166, 1160, 
	237, 2099, 3120, 2099, 0, 0, 0, 0, 
	0, 255, 1244, 1247, 1241, 255, 2135, 3165, 
	2135, 225, 1109, 1112, 0, 1106, 225, 2075, 
	3090, 2075, 0, 273, 1325, 1328, 0, 1322, 
	273, 2171, 3210, 2171, 279, 1352, 1355, 0, 
	1349, 279, 2183, 3225, 2183, 0, 0, 0, 
	0, 281, 1361, 1364, 1358, 281, 2187, 3230, 
	2187, 0, 0, 231, 1136, 1139, 1133, 231, 
	2087, 3105, 2087, 0, 0, 0, 241, 1181, 
	1184, 1178, 241, 2107, 3130, 2107, 0, 0, 
	0, 271, 1316, 1319, 1313, 271, 2167, 3205, 
	2167, 245, 1199, 1202, 1196, 245, 2115, 3140, 
	2115, 0, 0, 0, 0, 0, 229, 1127, 
	1130, 1124, 229, 2083, 3100, 2083, 0, 285, 
	1379, 1382, 1376, 285, 2195, 3240, 2195, 0, 
	253, 1235, 1238, 1232, 253, 2131, 3160, 2131, 
	0, 0, 0, 267, 1298, 1301, 1295, 267, 
	2159, 3195, 2159, 0, 0, 0, 0, 0, 
	283, 1370, 1373, 1367, 283, 2191, 3235, 2191, 
	0, 239, 1172, 1175, 1169, 239, 2103, 3125, 
	2103, 0, 0, 488, 221, 1091, 1094, 41, 
	1088, 221, 2067, 3080, 2067, 0, 0, 0, 
	243, 1190, 1193, 1187, 243, 2111, 3135, 2111, 
	0, 263, 1280, 1283, 1277, 263, 2151, 3185, 
	2151, 307, 0, 5, 7, 3, 0, 494, 
	488, 49, 566, 569, 41, 563, 49, 2059, 
	0, 5, 7, 113, 3, 0, 115, 0, 
	5, 7, 3, 0, 695, 1623, 695, 0, 
	5, 7, 3, 0, 488, 488, 329, 1611, 
	1615, 41, 1, 1607, 329, 0, 5, 7, 
	113, 3, 0, 115, 0, 5, 7, 3, 
	0, 695, 1623, 695, 49, 566, 569, 563, 
	49, 311, 488, 0, 0, 0, 0, 0, 
	521, 41, 0, 0, 704, 0, 707, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 713, 0, 0, 0, 0, 0, 
	0, 0, 0, 725, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 728, 0, 0, 0, 0, 0, 0, 
	0, 0, 731, 0, 0, 0, 0, 0, 
	0, 0, 734, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 737, 0, 0, 
	740, 0, 0, 0, 0, 0, 0, 701, 
	0, 0, 0, 0, 0, 710, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 716, 0, 0, 719, 0, 0, 722, 
	313, 488, 0, 0, 0, 0, 0, 0, 
	533, 41, 0, 0, 0, 0, 0, 761, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	764, 0, 0, 0, 758, 0, 0, 752, 
	0, 0, 0, 755, 0, 0, 770, 0, 
	0, 0, 749, 0, 0, 743, 0, 0, 
	0, 746, 0, 0, 767, 668, 665, 2011, 
	103, 467, 470, 467, 482, 1743, 1747, 1739, 
	482, 0, 5, 7, 467, 3, 0, 482, 
	1743, 1747, 1739, 482, 497, 0, 5, 7, 
	488, 3, 0, 47, 554, 557, 41, 551, 
	47, 0, 5, 7, 488, 3, 0, 1903, 
	47, 554, 557, 41, 55, 53, 51, 0, 
	57, 551, 47, 0, 5, 7, 488, 3, 
	0, 47, 554, 557, 41, 55, 53, 51, 
	0, 57, 551, 47, 0, 5, 7, 488, 
	3, 0, 47, 554, 557, 41, 55, 53, 
	51, 0, 57, 551, 47, 0, 5, 7, 
	488, 3, 0, 548, 41, 55, 53, 51, 
	0, 57, 1911, 41, 55, 53, 51, 0, 
	57, 1915, 3025, 1911, 41, 55, 53, 51, 
	0, 57, 578, 1923, 1927, 3025, 1919, 578, 
	1911, 41, 55, 53, 51, 0, 57, 578, 
	1923, 1927, 3025, 1919, 578, 1911, 41, 55, 
	53, 51, 0, 57, 578, 1923, 1927, 3025, 
	1919, 578, 404, 31, 419, 422, 416, 31, 
	404, 0, 5, 7, 3, 0, 413, 467, 
	482, 1743, 1747, 1739, 482, 0, 5, 7, 
	467, 3, 0, 470, 488, 545, 1875, 1879, 
	41, 1871, 545, 0, 5, 7, 467, 3, 
	0, 470, 404, 31, 419, 422, 416, 31, 
	413, 1671, 413, 0, 5, 7, 3, 0, 
	1, 332, 1, 665, 2027, 103, 1472, 2211, 
	295, 1418, 1421, 41, 1415, 295, 0, 5, 
	7, 488, 0, 0, 3, 0, 299, 1436, 
	1439, 41, 1433, 299, 0, 5, 7, 3010, 
	3, 0, 503, 1803, 1807, 0, 41, 1799, 
	503, 0, 5, 7, 3, 0, 0, 5, 
	7, 3, 0, 488, 297, 1427, 1430, 41, 
	1424, 297, 0, 5, 7, 488, 0, 0, 
	3, 0, 301, 1445, 1448, 41, 1442, 301, 
	0, 5, 7, 3010, 3, 0, 506, 1815, 
	1819, 0, 41, 1811, 506, 0, 5, 7, 
	3, 0, 0, 5, 7, 3, 0, 0, 
	3005, 3553, 509, 1827, 1831, 0, 41, 509, 
	1823, 509, 2985, 3517, 2985, 0, 5, 7, 
	3005, 3, 0, 1469, 1631, 1469, 512, 1839, 
	1843, 0, 41, 512, 1835, 512, 2990, 3523, 
	2990, 0, 5, 7, 3005, 3, 0, 1631, 
	1469, 515, 1851, 1855, 0, 41, 515, 1847, 
	515, 2995, 3529, 2995, 0, 5, 7, 3005, 
	3, 0, 1631, 1469, 518, 1863, 1867, 0, 
	41, 1859, 518, 3000, 3535, 3000, 0, 5, 
	7, 3, 0, 1631, 1469, 1795, 2975, 2980, 
	2890, 2970, 1795, 3511, 3600, 3511, 485, 1791, 
	2960, 2965, 2890, 1791, 2955, 1791, 3505, 3593, 
	3505, 485, 1787, 2945, 2950, 2890, 1787, 2940, 
	1787, 3499, 3586, 3499, 485, 1783, 2930, 2935, 
	2890, 1783, 2925, 1783, 3493, 3579, 3493, 485, 
	305, 1463, 1466, 1460, 305, 1779, 2915, 2920, 
	2890, 2910, 1779, 485, 303, 1454, 1457, 1451, 
	303, 1775, 2900, 2905, 2890, 2895, 1775, 485, 
	488, 45, 539, 542, 41, 536, 45, 0, 
	5, 7, 488, 3, 0, 45, 539, 542, 
	41, 536, 45, 0, 5, 7, 488, 3, 
	0, 545, 1875, 1879, 41, 1871, 545, 0, 
	5, 7, 467, 3, 0, 470, 488, 45, 
	539, 542, 41, 536, 45, 0, 5, 7, 
	488, 3, 0, 45, 539, 542, 41, 536, 
	45, 404, 0, 5, 7, 3, 0, 31, 
	419, 422, 416, 31, 404, 0, 5, 7, 
	3, 0, 31, 419, 422, 416, 31, 404, 
	0, 5, 7, 3, 0, 425, 1679, 1683, 
	1675, 425, 0, 5, 7, 467, 3, 0, 
	470, 317, 0, 5, 7, 3, 0, 488, 
	45, 539, 542, 41, 536, 45, 0, 5, 
	7, 315, 3, 0, 0, 5, 7, 3, 
	0, 127, 1, 689, 0, 677, 5, 7, 
	680, 683, 3, 0, 1, 332, 1, 109, 
	111, 0, 2003, 665, 103, 105, 488, 686, 
	2051, 2055, 41, 2047, 686, 2043, 3075, 2043, 
	0, 665, 103, 107, 488, 45, 539, 542, 
	41, 536, 45, 0, 5, 7, 315, 3, 
	0, 0, 5, 7, 3, 0, 488, 43, 
	527, 530, 41, 524, 43, 692, 0, 5, 
	7, 113, 3, 0, 115, 0, 5, 7, 
	3, 0, 1, 332, 1, 488, 43, 527, 
	530, 41, 524, 43, 0, 5, 7, 488, 
	3, 0, 43, 527, 530, 41, 524, 43, 
	0, 5, 7, 113, 3, 0, 115, 0, 
	5, 7, 3, 0, 1, 332, 1, 488, 
	43, 527, 530, 41, 524, 43, 773, 0, 
	5, 7, 145, 147, 149, 151, 3, 0, 
	0, 5, 7, 3, 0, 1759, 488, 43, 
	527, 530, 41, 524, 43, 0, 5, 7, 
	0, 3, 0, 2063, 0, 5, 7, 0, 
	5, 7, 0, 5, 7, 1, 3, 0, 
	332, 1, 3, 0, 332, 1, 3, 0, 
	332, 1, 776, 127, 0, 5, 7, 3, 
	0, 488, 43, 527, 530, 41, 524, 43, 
	2007, 0, 5, 7, 665, 3, 0, 3060, 
	103, 671, 2019, 2023, 671, 2019, 2023, 671, 
	2019, 2023, 2011, 2015, 671, 3065, 2011, 2015, 
	671, 3065, 2011, 2015, 671, 3065, 2011, 0, 
	5, 7, 3, 0, 488, 43, 527, 530, 
	41, 524, 43, 0, 5, 7, 665, 3, 
	0, 103, 674, 2035, 2039, 674, 2035, 2039, 
	674, 2035, 2039, 2027, 2031, 674, 3070, 2027, 
	2031, 674, 3070, 2027, 2031, 674, 3070, 2027, 
	0, 5, 7, 3, 0, 488, 43, 527, 
	530, 41, 524, 43, 0, 5, 7, 467, 
	3, 0, 39, 476, 479, 39, 476, 479, 
	39, 476, 479, 470, 473, 39, 1735, 470, 
	473, 39, 1735, 470, 473, 39, 1735, 470, 
	779, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 153, 
	785, 788, 0, 0, 0, 782, 153, 0, 
	5, 7, 315, 3, 0, 0, 5, 7, 
	3, 0, 488, 43, 527, 530, 41, 524, 
	43, 0, 5, 7, 488, 3, 0, 47, 
	554, 557, 41, 551, 47, 596, 0, 5, 
	7, 584, 3, 0, 63, 590, 593, 61, 
	587, 63, 0, 5, 7, 584, 3, 0, 
	63, 590, 593, 61, 587, 63, 0, 5, 
	7, 488, 3, 0, 545, 1875, 1879, 41, 
	1871, 545, 0, 5, 7, 467, 3, 0, 
	482, 1743, 1747, 1739, 482, 0, 5, 7, 
	127, 3, 0, 1, 0, 0, 179, 902, 
	905, 899, 179, 0, 0, 0, 173, 875, 
	878, 872, 173, 0, 193, 965, 968, 962, 
	193, 0, 0, 0, 0, 189, 947, 950, 
	944, 189, 0, 0, 0, 157, 803, 806, 
	800, 157, 0, 0, 0, 0, 0, 0, 
	207, 1028, 1031, 1025, 207, 0, 0, 0, 
	0, 191, 956, 959, 953, 191, 0, 0, 
	0, 205, 1019, 1022, 1016, 205, 195, 974, 
	977, 971, 195, 0, 0, 0, 0, 0, 
	217, 1073, 1076, 1070, 217, 0, 219, 1082, 
	1085, 1079, 219, 0, 0, 0, 0, 163, 
	830, 833, 827, 163, 0, 0, 0, 0, 
	0, 0, 0, 199, 992, 995, 989, 199, 
	0, 0, 0, 177, 893, 896, 890, 177, 
	187, 938, 941, 935, 187, 0, 0, 181, 
	911, 914, 908, 181, 0, 0, 0, 0, 
	0, 165, 839, 842, 836, 165, 167, 848, 
	851, 845, 167, 0, 0, 0, 0, 0, 
	185, 929, 932, 926, 185, 155, 794, 797, 
	0, 791, 155, 0, 203, 1010, 1013, 0, 
	1007, 203, 209, 1037, 1040, 0, 1034, 209, 
	0, 0, 0, 0, 211, 1046, 1049, 1043, 
	211, 0, 0, 161, 821, 824, 818, 161, 
	0, 0, 0, 171, 866, 869, 863, 171, 
	0, 0, 0, 201, 1001, 1004, 998, 201, 
	175, 884, 887, 881, 175, 0, 0, 0, 
	0, 0, 159, 812, 815, 809, 159, 0, 
	215, 1064, 1067, 1061, 215, 0, 183, 920, 
	923, 917, 183, 0, 0, 0, 197, 983, 
	986, 980, 197, 0, 0, 0, 0, 0, 
	213, 1055, 1058, 1052, 213, 0, 169, 857, 
	860, 854, 169, 0, 0, 1763, 488, 45, 
	539, 542, 41, 536, 45, 467, 1751, 1, 
	488, 45, 539, 542, 41, 536, 45, 0, 
	5, 7, 488, 3, 0, 43, 527, 530, 
	41, 524, 43, 0, 5, 7, 315, 3, 
	0, 0, 5, 7, 3, 0, 127, 1, 
	127, 1, 488, 43, 527, 530, 41, 524, 
	43, 0, 5, 7, 488, 3, 0, 43, 
	527, 530, 41, 524, 43, 0, 5, 7, 
	488, 3, 0, 45, 539, 542, 41, 536, 
	45, 0, 5, 7, 29, 407, 3, 0, 
	31, 419, 422, 416, 31, 698, 0, 5, 
	7, 410, 3, 0, 131, 133, 0, 135, 
	137, 0, 139, 0, 141, 143, 0, 428, 
	129, 1, 0, 0, 115, 113, 488, 43, 
	527, 530, 41, 524, 43, 0, 5, 7, 
	488, 3, 0, 43, 527, 530, 41, 524, 
	43, 0, 5, 7, 488, 3, 0, 45, 
	539, 542, 41, 536, 45, 0, 5, 7, 
	29, 407, 3, 0, 413, 115, 113, 488, 
	43, 527, 530, 41, 524, 43, 0, 5, 
	7, 488, 3, 0, 43, 527, 530, 41, 
	524, 43, 0, 5, 7, 488, 3, 0, 
	43, 527, 530, 41, 524, 43, 0, 5, 
	7, 113, 3, 0, 115, 0, 5, 7, 
	3, 0, 1, 332, 1, 1475, 115, 309, 
	113, 115, 2215, 1475, 115, 309, 113, 115, 
	2219, 458, 35, 0, 452, 455, 431, 449, 
	35, 35, 321, 344, 350, 2227, 431, 335, 
	35, 1635, 1484, 1727, 35, 344, 350, 1987, 
	1987, 1987, 1987, 1987, 1987, 1987, 1987, 1987, 
	1987, 1987, 1987, 1987, 1987, 335, 35, 2865, 
	2880, 3050, 3050, 3050, 3050, 3050, 3050, 3050, 
	3050, 3050, 3050, 3050, 3050, 3050, 3050, 1719, 
	638, 91, 1979, 1983, 1971, 635, 91, 1975, 
	638, 344, 350, 335, 35, 344, 350, 2791, 
	35, 35, 344, 350, 35, 1484, 3481, 3487, 
	3547, 3547, 3547, 3547, 3547, 3547, 3547, 3547, 
	3547, 3547, 3547, 3547, 3547, 3547, 1647
};

static const short _zone_scanner_eof_actions[] = {
	0, 1767, 1907, 327, 1499, 319, 1478, 9, 
	9, 319, 1478, 319, 1478, 1478, 2885, 3541, 
	1496, 327, 327, 327, 1499, 1478, 327, 327, 
	327, 1499, 327, 327, 327, 327, 1499, 327, 
	327, 327, 1499, 327, 327, 327, 1499, 1499, 
	327, 327, 327, 327, 1499, 327, 1499, 327, 
	327, 327, 327, 1499, 327, 327, 327, 327, 
	327, 327, 327, 327, 327, 327, 1499, 327, 
	327, 1499, 1499, 327, 327, 1499, 327, 327, 
	327, 327, 1499, 1499, 327, 327, 327, 327, 
	1499, 1499, 327, 1499, 1499, 327, 327, 327, 
	327, 1499, 327, 327, 1499, 327, 1499, 327, 
	327, 327, 1499, 1499, 327, 327, 1499, 327, 
	1499, 327, 1499, 327, 327, 327, 1499, 327, 
	327, 327, 1499, 327, 1499, 327, 327, 500, 
	1771, 327, 1767, 327, 327, 500, 1907, 1907, 
	1907, 1907, 327, 9, 93, 93, 93, 93, 
	93, 93, 93, 93, 37, 500, 0, 2870, 
	500, 327, 1907, 1907, 1907, 327, 1731, 1771, 
	2239, 1478, 1767, 9, 1478, 9, 2885, 2239, 
	2239, 2239, 2239, 2239, 2239, 2239, 2239, 2239, 
	2239, 2239, 2239, 2239, 1478, 2223, 93, 93, 
	93, 93, 93, 93, 93, 93, 93, 1723, 
	3572, 1767, 1496, 2875, 2885, 2875, 2875, 2875, 
	2875, 2875, 2875, 2875, 2875, 2875, 2875, 2875, 
	2875, 2875, 461, 2885, 1478, 9, 1478, 327, 
	327, 1499, 327, 327, 327, 1499, 327, 1499, 
	1478, 1478, 9, 1478, 1478, 319, 1478, 464, 
	464, 464, 464, 464, 464, 464, 464, 464, 
	464, 464, 464, 464, 9, 1496, 464, 1496, 
	0, 0, 27, 27, 27, 27, 377, 377, 
	377, 377, 27, 27, 602, 602, 1947, 1947, 
	1947, 1947, 602, 67, 1947, 1947, 1947, 1947, 
	73, 491, 3020, 356, 356, 3020, 1899, 3020, 
	73, 77, 77, 77, 359, 359, 359, 77, 
	380, 380, 380, 380, 359, 77, 0, 83, 
	626, 632, 85, 632, 9, 9, 85, 383, 
	383, 383, 383, 632, 9, 85, 0, 0, 
	125, 125, 125, 125, 125, 125, 125, 293, 
	293, 293, 293, 293, 293, 293, 293, 293, 
	293, 293, 293, 293, 293, 293, 293, 293, 
	293, 293, 293, 293, 293, 293, 293, 293, 
	293, 293, 293, 293, 293, 293, 293, 293, 
	293, 293, 293, 293, 293, 293, 293, 293, 
	293, 293, 293, 293, 293, 293, 293, 293, 
	293, 293, 293, 293, 293, 293, 293, 293, 
	293, 293, 293, 293, 293, 293, 293, 293, 
	293, 293, 293, 293, 293, 293, 293, 293, 
	293, 293, 293, 293, 293, 293, 293, 293, 
	293, 293, 293, 293, 293, 293, 293, 293, 
	293, 293, 293, 293, 293, 293, 293, 293, 
	293, 293, 293, 293, 293, 293, 293, 293, 
	293, 293, 293, 293, 293, 293, 293, 293, 
	307, 494, 494, 2059, 2059, 2059, 2059, 307, 
	307, 307, 494, 494, 2059, 2059, 2059, 2059, 
	307, 494, 307, 311, 311, 311, 311, 311, 
	311, 311, 311, 311, 311, 311, 311, 311, 
	311, 311, 311, 311, 311, 311, 311, 311, 
	311, 311, 311, 311, 311, 311, 311, 311, 
	311, 311, 311, 311, 311, 311, 311, 311, 
	311, 311, 311, 311, 311, 311, 311, 311, 
	311, 311, 311, 311, 311, 311, 311, 311, 
	311, 311, 311, 311, 311, 311, 311, 311, 
	311, 311, 311, 311, 311, 311, 311, 311, 
	311, 311, 311, 311, 311, 311, 311, 311, 
	311, 311, 311, 311, 311, 311, 311, 311, 
	311, 311, 311, 311, 311, 311, 311, 311, 
	311, 311, 313, 313, 313, 313, 313, 313, 
	313, 313, 313, 313, 313, 313, 313, 313, 
	313, 313, 313, 313, 313, 313, 313, 313, 
	313, 313, 313, 313, 313, 313, 313, 313, 
	313, 313, 313, 313, 313, 313, 313, 313, 
	313, 313, 313, 668, 668, 319, 319, 319, 
	319, 319, 319, 497, 497, 497, 1903, 497, 
	1903, 497, 1903, 497, 1903, 1903, 1903, 1903, 
	319, 1903, 1903, 1903, 319, 1903, 1903, 1903, 
	319, 1903, 1903, 1903, 319, 319, 319, 319, 
	319, 319, 319, 319, 319, 319, 319, 319, 
	319, 497, 497, 319, 319, 319, 319, 319, 
	319, 319, 668, 668, 1472, 1472, 1472, 1472, 
	1472, 1472, 1472, 1472, 1472, 1472, 1472, 1472, 
	1472, 1472, 1472, 1472, 1472, 1472, 1472, 1472, 
	1472, 1472, 1472, 1472, 1472, 1472, 1472, 1472, 
	1472, 1472, 1472, 1472, 1472, 1472, 1472, 1472, 
	1472, 1472, 1472, 1472, 1472, 1472, 1472, 1472, 
	1472, 1472, 1472, 1472, 1472, 1472, 1472, 1472, 
	1472, 1472, 1472, 497, 497, 497, 497, 497, 
	497, 319, 319, 319, 319, 319, 497, 497, 
	497, 497, 319, 319, 319, 319, 319, 319, 
	319, 319, 319, 319, 319, 319, 319, 319, 
	319, 497, 497, 319, 319, 319, 319, 319, 
	319, 319, 689, 689, 689, 2003, 2003, 689, 
	689, 319, 689, 2003, 2003, 497, 497, 319, 
	319, 497, 497, 692, 692, 692, 692, 319, 
	319, 319, 497, 497, 497, 497, 692, 692, 
	692, 692, 319, 319, 497, 497, 773, 773, 
	1759, 1759, 773, 2063, 776, 776, 776, 776, 
	776, 776, 776, 773, 773, 773, 1759, 1759, 
	2007, 3060, 773, 773, 773, 1759, 1759, 2007, 
	3060, 773, 773, 773, 1759, 1759, 773, 2063, 
	773, 773, 319, 779, 779, 319, 319, 497, 
	497, 497, 497, 596, 596, 596, 596, 497, 
	497, 319, 319, 319, 319, 319, 319, 319, 
	319, 319, 319, 319, 319, 779, 779, 779, 
	779, 779, 779, 779, 779, 779, 779, 779, 
	779, 779, 779, 779, 779, 779, 779, 779, 
	779, 779, 779, 779, 779, 779, 779, 779, 
	779, 779, 779, 779, 779, 779, 779, 779, 
	779, 779, 779, 779, 779, 779, 779, 779, 
	779, 779, 779, 779, 779, 779, 779, 779, 
	779, 779, 779, 779, 779, 779, 779, 779, 
	779, 779, 779, 779, 779, 779, 779, 779, 
	779, 779, 779, 779, 779, 779, 779, 779, 
	779, 779, 779, 779, 779, 779, 779, 779, 
	779, 779, 779, 779, 779, 779, 779, 779, 
	779, 779, 779, 779, 779, 779, 779, 779, 
	779, 779, 779, 779, 779, 779, 779, 779, 
	1763, 1763, 319, 319, 319, 497, 497, 497, 
	497, 319, 319, 319, 319, 319, 319, 319, 
	319, 319, 497, 497, 497, 497, 497, 497, 
	692, 692, 698, 698, 698, 698, 698, 698, 
	698, 698, 698, 319, 698, 698, 698, 698, 
	698, 319, 692, 692, 319, 319, 319, 497, 
	497, 497, 497, 497, 497, 692, 692, 692, 
	692, 319, 319, 319, 497, 497, 497, 497, 
	497, 497, 692, 692, 692, 692, 319, 319, 
	319, 692, 692, 692, 692, 692, 692, 692, 
	692, 692, 692, 692, 692, 0, 0, 0, 
	0, 91, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0
};

static const int zone_scanner_start = 1021;
static const int zone_scanner_first_final = 1021;
static const int zone_scanner_error = 0;

static const int zone_scanner_en_err_line = 240;
static const int zone_scanner_en_dname_ = 242;
static const int zone_scanner_en_text_ = 252;
static const int zone_scanner_en_default_ttl_ = 264;
static const int zone_scanner_en_zone_origin_ = 273;
static const int zone_scanner_en_include_file_ = 286;
static const int zone_scanner_en_base64_ = 304;
static const int zone_scanner_en_bitmap_ = 311;
static const int zone_scanner_en_nonempty_hex_r_data = 424;
static const int zone_scanner_en_hex_r_data = 433;
static const int zone_scanner_en_dns_alg_ = 443;
static const int zone_scanner_en_cert_type_ = 538;
static const int zone_scanner_en_r_data_a = 579;
static const int zone_scanner_en_r_data_ns = 581;
static const int zone_scanner_en_r_data_soa = 583;
static const int zone_scanner_en_r_data_hinfo = 615;
static const int zone_scanner_en_r_data_minfo = 620;
static const int zone_scanner_en_r_data_mx = 625;
static const int zone_scanner_en_r_data_txt = 630;
static const int zone_scanner_en_r_data_aaaa = 634;
static const int zone_scanner_en_r_data_loc = 636;
static const int zone_scanner_en_r_data_srv = 691;
static const int zone_scanner_en_r_data_naptr = 702;
static const int zone_scanner_en_r_data_cert = 719;
static const int zone_scanner_en_r_data_apl = 730;
static const int zone_scanner_en_r_data_ds = 741;
static const int zone_scanner_en_r_data_sshfp = 754;
static const int zone_scanner_en_r_data_ipseckey = 764;
static const int zone_scanner_en_r_data_rrsig = 803;
static const int zone_scanner_en_r_data_nsec = 938;
static const int zone_scanner_en_r_data_dnskey = 941;
static const int zone_scanner_en_r_data_dhcid = 952;
static const int zone_scanner_en_r_data_nsec3 = 954;
static const int zone_scanner_en_r_data_nsec3param = 983;
static const int zone_scanner_en_r_data_tlsa = 996;
static const int zone_scanner_en_r_data_eui48 = 1009;
static const int zone_scanner_en_r_data_eui64 = 1015;
static const int zone_scanner_en_main = 1021;


#line 82 "zscanner/scanner.rl"


scanner_t* scanner_create(const char *file_name)
{
	scanner_t *s = calloc(1, sizeof(scanner_t));
	if (s == NULL) {
		return NULL;
	}

	s->file_name = strdup(file_name);
	s->line_counter = 1;

	// Nonzero initial scanner state.
	s->cs = zone_scanner_start;

	return s;
}

void scanner_free(scanner_t *s)
{
	if (s != NULL) {
		free(s->file_name);
		free(s);
	}
}

int scanner_process(const char *start,
		    const char *end,
		    const bool is_last_block,
		    scanner_t  *s)
{
	// Necessary scanner variables.
	const char *p = start;
	const char *pe = end;
	char       *eof = NULL;
	int        stack[RAGEL_STACK_SIZE];

	// Auxiliary variables which are used in scanner body.
	struct in_addr  addr4;
	struct in6_addr addr6;
	uint32_t timestamp;
	int16_t  window;
	int	 ret;

	// Next 2 variables are for better performance.
	// Restoring r_data pointer to next free space.
	uint8_t *rdata_tail = s->r_data + s->r_data_tail;
	// Initialization of the last r_data byte.
	uint8_t *rdata_stop = s->r_data + MAX_RDATA_LENGTH - 1;

	// Restoring scanner states.
	int cs  = s->cs;
	int top = s->top;
	memcpy(stack, s->stack, sizeof(stack));

	// End of file check.
	if (is_last_block == true) {
		eof = (char *)pe;
	}

	// Writing scanner body (in C).
	
#line 4826 "zscanner/scanner.c"
	{
	int _klen;
	unsigned int _trans;
	short _widec;
	const short *_acts;
	unsigned int _nacts;
	const short *_keys;

	if ( p == pe )
		goto _test_eof;
	if ( cs == 0 )
		goto _out;
_resume:
	_widec = (*p);
	_klen = _zone_scanner_cond_lengths[cs];
	_keys = _zone_scanner_cond_keys + (_zone_scanner_cond_offsets[cs]*2);
	if ( _klen > 0 ) {
		const short *_lower = _keys;
		const short *_mid;
		const short *_upper = _keys + (_klen<<1) - 2;
		while (1) {
			if ( _upper < _lower )
				break;

			_mid = _lower + (((_upper-_lower) >> 1) & ~1);
			if ( _widec < _mid[0] )
				_upper = _mid - 2;
			else if ( _widec > _mid[1] )
				_lower = _mid + 2;
			else {
				switch ( _zone_scanner_cond_spaces[_zone_scanner_cond_offsets[cs] + ((_mid - _keys)>>1)] ) {
	case 0: {
		_widec = (short)(640 + ((*p) - -128));
		if ( 
#line 54 "zscanner/scanner_body.rl"
 s->multiline  ) _widec += 256;
		break;
	}
	case 1: {
		_widec = (short)(1152 + ((*p) - -128));
		if ( 
#line 63 "zscanner/scanner_body.rl"
 !s->multiline  ) _widec += 256;
		break;
	}
	case 2: {
		_widec = (short)(128 + ((*p) - -128));
		if ( 
#line 559 "zscanner/scanner_body.rl"
 s->multiline  ) _widec += 256;
		break;
	}
	case 3: {
		_widec = (short)(2688 + ((*p) - -128));
		if ( 
#line 1196 "zscanner/scanner_body.rl"
 s->number64 != 0  ) _widec += 256;
		break;
	}
	case 4: {
		_widec = (short)(4224 + ((*p) - -128));
		if ( 
#line 1197 "zscanner/scanner_body.rl"
 s->number64 == 0  ) _widec += 256;
		break;
	}
	case 5: {
		_widec = (short)(1664 + ((*p) - -128));
		if ( 
#line 54 "zscanner/scanner_body.rl"
 s->multiline  ) _widec += 256;
		if ( 
#line 63 "zscanner/scanner_body.rl"
 !s->multiline  ) _widec += 512;
		break;
	}
	case 6: {
		_widec = (short)(3200 + ((*p) - -128));
		if ( 
#line 54 "zscanner/scanner_body.rl"
 s->multiline  ) _widec += 256;
		if ( 
#line 1196 "zscanner/scanner_body.rl"
 s->number64 != 0  ) _widec += 512;
		break;
	}
	case 7: {
		_widec = (short)(4736 + ((*p) - -128));
		if ( 
#line 54 "zscanner/scanner_body.rl"
 s->multiline  ) _widec += 256;
		if ( 
#line 1197 "zscanner/scanner_body.rl"
 s->number64 == 0  ) _widec += 512;
		break;
	}
	case 8: {
		_widec = (short)(5760 + ((*p) - -128));
		if ( 
#line 1196 "zscanner/scanner_body.rl"
 s->number64 != 0  ) _widec += 256;
		if ( 
#line 1197 "zscanner/scanner_body.rl"
 s->number64 == 0  ) _widec += 512;
		break;
	}
	case 9: {
		_widec = (short)(12928 + ((*p) - -128));
		if ( 
#line 54 "zscanner/scanner_body.rl"
 s->multiline  ) _widec += 256;
		if ( 
#line 63 "zscanner/scanner_body.rl"
 !s->multiline  ) _widec += 512;
		if ( 
#line 1197 "zscanner/scanner_body.rl"
 s->number64 == 0  ) _widec += 1024;
		break;
	}
	case 10: {
		_widec = (short)(6784 + ((*p) - -128));
		if ( 
#line 54 "zscanner/scanner_body.rl"
 s->multiline  ) _widec += 256;
		if ( 
#line 1196 "zscanner/scanner_body.rl"
 s->number64 != 0  ) _widec += 512;
		if ( 
#line 1197 "zscanner/scanner_body.rl"
 s->number64 == 0  ) _widec += 1024;
		break;
	}
	case 11: {
		_widec = (short)(8832 + ((*p) - -128));
		if ( 
#line 54 "zscanner/scanner_body.rl"
 s->multiline  ) _widec += 256;
		if ( 
#line 63 "zscanner/scanner_body.rl"
 !s->multiline  ) _widec += 512;
		if ( 
#line 1196 "zscanner/scanner_body.rl"
 s->number64 != 0  ) _widec += 1024;
		if ( 
#line 1197 "zscanner/scanner_body.rl"
 s->number64 == 0  ) _widec += 2048;
		break;
	}
				}
				break;
			}
		}
	}

	_keys = _zone_scanner_trans_keys + _zone_scanner_key_offsets[cs];
	_trans = _zone_scanner_index_offsets[cs];

	_klen = _zone_scanner_single_lengths[cs];
	if ( _klen > 0 ) {
		const short *_lower = _keys;
		const short *_mid;
		const short *_upper = _keys + _klen - 1;
		while (1) {
			if ( _upper < _lower )
				break;

			_mid = _lower + ((_upper-_lower) >> 1);
			if ( _widec < *_mid )
				_upper = _mid - 1;
			else if ( _widec > *_mid )
				_lower = _mid + 1;
			else {
				_trans += (unsigned int)(_mid - _keys);
				goto _match;
			}
		}
		_keys += _klen;
		_trans += _klen;
	}

	_klen = _zone_scanner_range_lengths[cs];
	if ( _klen > 0 ) {
		const short *_lower = _keys;
		const short *_mid;
		const short *_upper = _keys + (_klen<<1) - 2;
		while (1) {
			if ( _upper < _lower )
				break;

			_mid = _lower + (((_upper-_lower) >> 1) & ~1);
			if ( _widec < _mid[0] )
				_upper = _mid - 2;
			else if ( _widec > _mid[1] )
				_lower = _mid + 2;
			else {
				_trans += (unsigned int)((_mid - _keys)>>1);
				goto _match;
			}
		}
		_trans += _klen;
	}

_match:
	_trans = _zone_scanner_indicies[_trans];
	cs = _zone_scanner_trans_targs[_trans];

	if ( _zone_scanner_trans_actions[_trans] == 0 )
		goto _again;

	_acts = _zone_scanner_actions + _zone_scanner_trans_actions[_trans];
	_nacts = (unsigned int) *_acts++;
	while ( _nacts-- > 0 )
	{
		switch ( *_acts++ )
		{
	case 0:
#line 20 "zscanner/scanner_body.rl"
	{
		p--; {cs = stack[--top]; goto _again;}
	}
	break;
	case 1:
#line 25 "zscanner/scanner_body.rl"
	{
		s->line_counter++;
	}
	break;
	case 2:
#line 29 "zscanner/scanner_body.rl"
	{
		if (s->multiline == true) {
			SCANNER_ERROR(ZSCANNER_ELEFT_PARENTHESIS);
			p--; {cs = 240; goto _again;}
		}
		s->multiline = true;
	}
	break;
	case 3:
#line 36 "zscanner/scanner_body.rl"
	{
		if (s->multiline == false) {
			SCANNER_ERROR(ZSCANNER_ERIGHT_PARENTHESIS);
			p--; {cs = 240; goto _again;}
		}
		s->multiline = false;
	}
	break;
	case 4:
#line 44 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_REST);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 5:
#line 67 "zscanner/scanner_body.rl"
	{
		s->buffer_length = 0;
	}
	break;
	case 6:
#line 70 "zscanner/scanner_body.rl"
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	break;
	case 7:
#line 75 "zscanner/scanner_body.rl"
	{
		// Ending string in buffer.
		s->buffer[s->buffer_length++] = 0;

		// Error counter incrementation.
		s->error_counter++;

		// Initialization of fcall stack.
		top = 0;

		// Process error message.
		s->process_error(s);

		// Reset.
		s->error_code = KNOT_EOK;
		s->multiline = false;

		// In case of serious error, stop scanner.
		if (s->stop == true) {
			return -1;
		}
	}
	break;
	case 8:
#line 100 "zscanner/scanner_body.rl"
	{ {cs = 1021; goto _again;} }
	break;
	case 9:
#line 104 "zscanner/scanner_body.rl"
	{
		s->item_length = 0;
		s->item_length_position = s->dname_tmp_length++;
	}
	break;
	case 10:
#line 108 "zscanner/scanner_body.rl"
	{
		if (s->item_length < MAX_LABEL_LENGTH) {
			(s->dname)[s->dname_tmp_length++] = (*p);
			s->item_length++;
		} else {
			SCANNER_WARNING(ZSCANNER_ELABEL_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 11:
#line 117 "zscanner/scanner_body.rl"
	{
		if (s->dname_tmp_length < MAX_DNAME_LENGTH) {
			(s->dname)[s->item_length_position] =
				(uint8_t)(s->item_length);
		} else {
			SCANNER_WARNING(ZSCANNER_EDNAME_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 12:
#line 127 "zscanner/scanner_body.rl"
	{
		if (s->item_length < MAX_LABEL_LENGTH) {
			(s->dname)[s->dname_tmp_length] = 0;
			s->item_length++;
		} else {
			SCANNER_WARNING(ZSCANNER_ELABEL_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 13:
#line 136 "zscanner/scanner_body.rl"
	{
		(s->dname)[s->dname_tmp_length] *= 10;
		(s->dname)[s->dname_tmp_length] += digit_to_num[(uint8_t)(*p)];
	}
	break;
	case 14:
#line 140 "zscanner/scanner_body.rl"
	{
		s->dname_tmp_length++;
	}
	break;
	case 15:
#line 143 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_NUMBER);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 16:
#line 162 "zscanner/scanner_body.rl"
	{
		(s->dname)[s->dname_tmp_length++] = 0;
	}
	break;
	case 17:
#line 165 "zscanner/scanner_body.rl"
	{
		memcpy(s->dname + s->dname_tmp_length,
		       s->zone_origin,
		       s->zone_origin_length);

		s->dname_tmp_length += s->zone_origin_length;

		if (s->dname_tmp_length > MAX_DNAME_LENGTH) {
			SCANNER_WARNING(ZSCANNER_EDNAME_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 18:
#line 177 "zscanner/scanner_body.rl"
	{
		memcpy(s->dname,
		       s->zone_origin,
		       s->zone_origin_length);

		s->dname_tmp_length = s->zone_origin_length;
	}
	break;
	case 19:
#line 185 "zscanner/scanner_body.rl"
	{
		s->item_length_position = 0;
		s->dname_tmp_length = 0;
	}
	break;
	case 20:
#line 189 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_DNAME_CHAR);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 21:
#line 201 "zscanner/scanner_body.rl"
	{ p--; {stack[top++] = cs; cs = 242; goto _again;} }
	break;
	case 22:
#line 205 "zscanner/scanner_body.rl"
	{
		s->item_length_location = rdata_tail++;
	}
	break;
	case 23:
#line 208 "zscanner/scanner_body.rl"
	{
		s->item_length = rdata_tail - s->item_length_location - 1;

		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			SCANNER_WARNING(ZSCANNER_EITEM_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 24:
#line 219 "zscanner/scanner_body.rl"
	{
		s->r_data_blocks[++(s->r_data_blocks_count)] =
			rdata_tail - s->r_data;
	}
	break;
	case 25:
#line 229 "zscanner/scanner_body.rl"
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	break;
	case 26:
#line 233 "zscanner/scanner_body.rl"
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	break;
	case 27:
#line 236 "zscanner/scanner_body.rl"
	{
		if (s->r_owner_length == 0) {
			SCANNER_WARNING(ZSCANNER_EBAD_PREVIOUS_OWNER);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 28:
#line 242 "zscanner/scanner_body.rl"
	{
		s->r_owner_length = 0;
		SCANNER_WARNING(ZSCANNER_EBAD_OWNER);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 29:
#line 254 "zscanner/scanner_body.rl"
	{
		s->dname = rdata_tail;
	}
	break;
	case 30:
#line 257 "zscanner/scanner_body.rl"
	{
		rdata_tail += s->dname_tmp_length;
	}
	break;
	case 31:
#line 265 "zscanner/scanner_body.rl"
	{
		// Overflow check: 10*(s->number64) + fc - ASCII_0 <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((*p) <= (UINT64_MAX % 10) + ASCII_0)
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			SCANNER_WARNING(ZSCANNER_ENUMBER64_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 32:
#line 282 "zscanner/scanner_body.rl"
	{
		s->number64 = 0;
	}
	break;
	case 33:
#line 285 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_NUMBER);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 34:
#line 293 "zscanner/scanner_body.rl"
	{
		s->decimal_counter = 0;
	}
	break;
	case 35:
#line 296 "zscanner/scanner_body.rl"
	{
		s->number64_tmp = s->number64;
	}
	break;
	case 36:
#line 299 "zscanner/scanner_body.rl"
	{
		s->decimal_counter++;
	}
	break;
	case 37:
#line 303 "zscanner/scanner_body.rl"
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			SCANNER_WARNING(ZSCANNER_EFLOAT_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 38:
#line 320 "zscanner/scanner_body.rl"
	{
		s->decimals = 2;
	}
	break;
	case 39:
#line 323 "zscanner/scanner_body.rl"
	{
		s->decimals = 3;
	}
	break;
	case 40:
#line 332 "zscanner/scanner_body.rl"
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			SCANNER_WARNING(ZSCANNER_ENUMBER8_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 41:
#line 341 "zscanner/scanner_body.rl"
	{
		if (s->number64 <= UINT16_MAX) {
			*((uint16_t *)rdata_tail) = htons((uint16_t)(s->number64));
			rdata_tail += 2;
		} else {
			SCANNER_WARNING(ZSCANNER_ENUMBER16_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 42:
#line 350 "zscanner/scanner_body.rl"
	{
		if (s->number64 <= UINT32_MAX) {
			*((uint32_t *)rdata_tail) = htonl((uint32_t)(s->number64));
			rdata_tail += 4;
		} else {
			SCANNER_WARNING(ZSCANNER_ENUMBER32_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 43:
#line 360 "zscanner/scanner_body.rl"
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_type = (uint16_t)(s->number64);
		} else {
			SCANNER_WARNING(ZSCANNER_ENUMBER16_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 44:
#line 369 "zscanner/scanner_body.rl"
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_data_length = (uint16_t)(s->number64);
		} else {
			SCANNER_WARNING(ZSCANNER_ENUMBER16_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 45:
#line 386 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_TIME_UNIT);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 46:
#line 393 "zscanner/scanner_body.rl"
	{ if (s->number64 <= (UINT32_MAX / 60)) {
	                  s->number64 *= 60;
	              } else {
	                  SCANNER_WARNING(ZSCANNER_ENUMBER32_OVERFLOW);
	                  p--; {cs = 240; goto _again;}
	              }
	            }
	break;
	case 47:
#line 400 "zscanner/scanner_body.rl"
	{ if (s->number64 <= (UINT32_MAX / 3600)) {
	                  s->number64 *= 3600;
	              } else {
	                  SCANNER_WARNING(ZSCANNER_ENUMBER32_OVERFLOW);
	                  p--; {cs = 240; goto _again;}
	              }
	            }
	break;
	case 48:
#line 407 "zscanner/scanner_body.rl"
	{ if (s->number64 <= (UINT32_MAX / 86400)) {
	                  s->number64 *= 86400;
	              } else {
	                  SCANNER_WARNING(ZSCANNER_ENUMBER32_OVERFLOW);
	                  p--; {cs = 240; goto _again;}
	              }
	            }
	break;
	case 49:
#line 414 "zscanner/scanner_body.rl"
	{ if (s->number64 <= (UINT32_MAX / 604800)) {
	                  s->number64 *= 604800;
	              } else {
	                  SCANNER_WARNING(ZSCANNER_ENUMBER32_OVERFLOW);
	                  p--; {cs = 240; goto _again;}
	              }
	            }
	break;
	case 50:
#line 424 "zscanner/scanner_body.rl"
	{
		s->number64_tmp = s->number64;
	}
	break;
	case 51:
#line 427 "zscanner/scanner_body.rl"
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			SCANNER_WARNING(ZSCANNER_ENUMBER32_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 52:
#line 445 "zscanner/scanner_body.rl"
	{
		s->buffer_length = 0;
	}
	break;
	case 53:
#line 448 "zscanner/scanner_body.rl"
	{
		if (s->buffer_length < MAX_RDATA_LENGTH) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			SCANNER_WARNING(ZSCANNER_ERDATA_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 54:
#line 456 "zscanner/scanner_body.rl"
	{
		s->buffer[s->buffer_length] = 0;

		if (s->buffer_length == 14) { // Date; 14 = len("YYYYMMDDHHmmSS").
			ret = date_to_timestamp(s->buffer, &timestamp);

			if (ret == KNOT_EOK) {
				*((uint32_t *)rdata_tail) = htonl(timestamp);
				rdata_tail += 4;
			} else {
				SCANNER_WARNING(ret);
				p--; {cs = 240; goto _again;}
			}
		} else if (s->buffer_length <= 10) { // Timestamp format.
			char *end;

			s->number64 = strtoull((char *)(s->buffer), &end,  10);

			if (end == (char *)(s->buffer) || *end != '\0') {
				SCANNER_WARNING(ZSCANNER_EBAD_TIMESTAMP);
				p--; {cs = 240; goto _again;}
			}

			if (s->number64 <= UINT32_MAX) {
				*((uint32_t *)rdata_tail) = htonl((uint32_t)s->number64);
				rdata_tail += 4;
			} else {
				SCANNER_WARNING(ZSCANNER_ENUMBER32_OVERFLOW);
				p--; {cs = 240; goto _again;}
			}
		} else {
			SCANNER_WARNING(ZSCANNER_EBAD_TIMESTAMP_LENGTH);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 55:
#line 491 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_TIMESTAMP_CHAR);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 56:
#line 501 "zscanner/scanner_body.rl"
	{
		if (rdata_tail <= rdata_stop) {
			*(rdata_tail++) = (*p);
		} else {
			SCANNER_WARNING(ZSCANNER_ETEXT_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 57:
#line 509 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_TEXT_CHAR);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 58:
#line 513 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_TEXT);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 59:
#line 518 "zscanner/scanner_body.rl"
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = 0;
			s->item_length++;
		} else {
			SCANNER_WARNING(ZSCANNER_ETEXT_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 60:
#line 527 "zscanner/scanner_body.rl"
	{
		if ((*rdata_tail < (UINT8_MAX / 10)) ||   // Dominant fast check.
			((*rdata_tail == (UINT8_MAX / 10)) && // Marginal case.
			 ((*p) <= (UINT8_MAX % 10) + ASCII_0)
			)
		   ) {
			*rdata_tail *= 10;
			*rdata_tail += digit_to_num[(uint8_t)(*p)];
		} else {
			SCANNER_WARNING(ZSCANNER_ENUMBER8_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 61:
#line 540 "zscanner/scanner_body.rl"
	{
		rdata_tail++;
	}
	break;
	case 62:
#line 543 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_NUMBER);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 63:
#line 565 "zscanner/scanner_body.rl"
	{ p--; {stack[top++] = cs; cs = 252; goto _again;} }
	break;
	case 64:
#line 575 "zscanner/scanner_body.rl"
	{
		if (s->number64 <= UINT32_MAX) {
			s->default_ttl = (uint32_t)(s->number64);
		} else {
			SCANNER_ERROR(ZSCANNER_ENUMBER32_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 65:
#line 583 "zscanner/scanner_body.rl"
	{
		SCANNER_ERROR(ZSCANNER_EBAD_TTL);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 66:
#line 590 "zscanner/scanner_body.rl"
	{ p--; {stack[top++] = cs; cs = 264; goto _again;} }
	break;
	case 67:
#line 594 "zscanner/scanner_body.rl"
	{
		s->dname = s->zone_origin;
	}
	break;
	case 68:
#line 597 "zscanner/scanner_body.rl"
	{
		s->zone_origin_length = s->dname_tmp_length;
	}
	break;
	case 69:
#line 600 "zscanner/scanner_body.rl"
	{
		SCANNER_ERROR(ZSCANNER_EBAD_ORIGIN);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 70:
#line 607 "zscanner/scanner_body.rl"
	{ p--; {stack[top++] = cs; cs = 273; goto _again;} }
	break;
	case 71:
#line 611 "zscanner/scanner_body.rl"
	{
		rdata_tail = s->r_data;
	}
	break;
	case 72:
#line 614 "zscanner/scanner_body.rl"
	{
		*rdata_tail = 0; // Ending filename string.
		strncpy((char*)(s->include_filename), (char*)(s->r_data),
		        sizeof(s->include_filename));

		// Check for correct string copy.
		if (strlen(s->include_filename) != rdata_tail - s->r_data) {
			SCANNER_ERROR(ZSCANNER_EBAD_INCLUDE_FILENAME);
			p--; {cs = 240; goto _again;}
		}

		// For detection whether origin is not present.
		s->dname = NULL;
	}
	break;
	case 73:
#line 628 "zscanner/scanner_body.rl"
	{
		SCANNER_ERROR(ZSCANNER_EBAD_INCLUDE_FILENAME);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 74:
#line 633 "zscanner/scanner_body.rl"
	{
		s->dname = s->r_data;
	}
	break;
	case 75:
#line 636 "zscanner/scanner_body.rl"
	{
		s->r_data_length = s->dname_tmp_length;
	}
	break;
	case 76:
#line 639 "zscanner/scanner_body.rl"
	{
		SCANNER_ERROR(ZSCANNER_EBAD_INCLUDE_ORIGIN);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 77:
#line 644 "zscanner/scanner_body.rl"
	{
		char text_origin[MAX_DNAME_LENGTH];

		// Origin conversion from wire to text form.
		if (s->dname == NULL) { // Use current origin.
			wire_dname_to_str(s->zone_origin,
			                  s->zone_origin_length,
					  text_origin);
		} else { // Use specified origin.
			wire_dname_to_str(s->r_data,
			                  s->r_data_length,
					  text_origin);
		}

		if (s->include_filename[0] != '/') { // Relative file path.
			// Get absolute path of the current zone file.
			if (realpath(s->file_name, (char*)(s->buffer)) != NULL) {
				char *full_current_zone_file_name =
					strdup((char*)(s->buffer));

				// Creating full include file name.
				snprintf((char*)(s->buffer), sizeof(s->buffer),
				        "%s/%s",
				        dirname(full_current_zone_file_name),
				        s->include_filename);

				free(full_current_zone_file_name);
			} else {
				SCANNER_ERROR(ZSCANNER_EUNPROCESSED_INCLUDE);
				p--; {cs = 240; goto _again;}
			}
		} else {
			strncpy((char*)(s->buffer), (char*)(s->include_filename),
			        sizeof(s->buffer));
		}

		// Create new file loader for included zone file.
		file_loader_t *fl = file_loader_create((char*)(s->buffer),
		                                       text_origin,
		                                       DEFAULT_CLASS,
		                                       DEFAULT_TTL,
		                                       s->process_record,
		                                       s->process_error,
		                                       s->data);
		if (fl != NULL) {
			// Process included zone file.
			ret = file_loader_process(fl);
			file_loader_free(fl);

			if (ret != 0) {
				SCANNER_ERROR(ZSCANNER_EUNPROCESSED_INCLUDE);
				p--; {cs = 240; goto _again;}
			}
		} else {
			SCANNER_ERROR(ZSCANNER_EUNOPENED_INCLUDE);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 78:
#line 710 "zscanner/scanner_body.rl"
	{ p--; {stack[top++] = cs; cs = 286; goto _again;} }
	break;
	case 79:
#line 716 "zscanner/scanner_body.rl"
	{
		s->stop = true;
	}
	break;
	case 80:
#line 720 "zscanner/scanner_body.rl"
	{
		s->stop = false;
	}
	break;
	case 81:
#line 723 "zscanner/scanner_body.rl"
	{
		SCANNER_ERROR(ZSCANNER_EBAD_DIRECTIVE);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 82:
#line 735 "zscanner/scanner_body.rl"
	{
		s->r_class = s->default_class;
	}
	break;
	case 83:
#line 739 "zscanner/scanner_body.rl"
	{
		s->r_ttl = s->default_ttl;
	}
	break;
	case 84:
#line 743 "zscanner/scanner_body.rl"
	{
		s->r_class = KNOT_CLASS_IN;
	}
	break;
	case 85:
#line 747 "zscanner/scanner_body.rl"
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			SCANNER_WARNING(ZSCANNER_ENUMBER32_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 86:
#line 762 "zscanner/scanner_body.rl"
	{
		s->buffer_length = 0;
	}
	break;
	case 87:
#line 765 "zscanner/scanner_body.rl"
	{
		if (s->buffer_length < MAX_RDATA_LENGTH) {
			s->buffer[s->buffer_length++] = (*p);
		}
		else {
			SCANNER_WARNING(ZSCANNER_ERDATA_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 88:
#line 774 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_ADDRESS_CHAR);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 89:
#line 779 "zscanner/scanner_body.rl"
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, &addr4) <= 0) {
			SCANNER_WARNING(ZSCANNER_EBAD_IPV4);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 90:
#line 787 "zscanner/scanner_body.rl"
	{
		memcpy(rdata_tail, &(addr4.s_addr), INET4_ADDR_LENGTH);
		rdata_tail += INET4_ADDR_LENGTH;
	}
	break;
	case 91:
#line 792 "zscanner/scanner_body.rl"
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, &addr6) <= 0) {
			SCANNER_WARNING(ZSCANNER_EBAD_IPV6);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 92:
#line 800 "zscanner/scanner_body.rl"
	{
		memcpy(rdata_tail, &(addr6.s6_addr), INET6_ADDR_LENGTH);
		rdata_tail += INET6_ADDR_LENGTH;
	}
	break;
	case 93:
#line 817 "zscanner/scanner_body.rl"
	{
		memset(&(s->apl), 0, sizeof(s->apl));
	}
	break;
	case 94:
#line 820 "zscanner/scanner_body.rl"
	{
		s->apl.excl_flag = 128; // dec 128  = bin 10000000.
	}
	break;
	case 95:
#line 823 "zscanner/scanner_body.rl"
	{
		s->apl.addr_family = 1;
	}
	break;
	case 96:
#line 826 "zscanner/scanner_body.rl"
	{
		s->apl.addr_family = 2;
	}
	break;
	case 97:
#line 829 "zscanner/scanner_body.rl"
	{
		if ((s->apl.addr_family == 1 && s->number64 <= 32) ||
		    (s->apl.addr_family == 2 && s->number64 <= 128)) {
			s->apl.prefix_length = (uint8_t)(s->number64);
		} else {
			SCANNER_WARNING(ZSCANNER_EBAD_APL);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 98:
#line 838 "zscanner/scanner_body.rl"
	{
		// Write address family.
		*((uint16_t *)rdata_tail) = htons(s->apl.addr_family);
		rdata_tail += 2;
		// Write prefix length in bites.
		*(rdata_tail) = s->apl.prefix_length;
		rdata_tail += 1;
		// Copy address to buffer.
		uint8_t len;
		switch (s->apl.addr_family) {
		case 1:
			len = INET4_ADDR_LENGTH;
			memcpy(s->buffer, &(addr4.s_addr), len);
			break;
		case 2:
			len = INET6_ADDR_LENGTH;
			memcpy(s->buffer, &(addr6.s6_addr), len);
			break;
		default:
			SCANNER_WARNING(ZSCANNER_EBAD_APL);
			p--; {cs = 240; goto _again;}
		}
		// Find prefix without trailing zeroes.
		while (len > 0) {
			if ((s->buffer[len - 1] & 255) != 0) {
				break;
			}
			len--;
		}
		// Write negation flag + prefix length in bytes.
		*(rdata_tail) = len + s->apl.excl_flag;
		rdata_tail += 1;
		// Write address prefix non-null data.
		memcpy(rdata_tail, s->buffer, len);
		rdata_tail += len;
	}
	break;
	case 99:
#line 874 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_APL);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 100:
#line 892 "zscanner/scanner_body.rl"
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_hex_to_num[(uint8_t)(*p)];
		} else {
			SCANNER_WARNING(ZSCANNER_ERDATA_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 101:
#line 900 "zscanner/scanner_body.rl"
	{
		*rdata_tail += second_hex_to_num[(uint8_t)(*p)];
		rdata_tail++;
	}
	break;
	case 102:
#line 904 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_HEX_CHAR);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 103:
#line 918 "zscanner/scanner_body.rl"
	{
		if ((rdata_tail - s->r_data) != s->r_data_length) {
			SCANNER_WARNING(ZSCANNER_EBAD_RDATA_LENGTH);
			p--; {cs = 240; goto _again;}
		}

		ret = find_rdata_blocks(s);
		if (ret != KNOT_EOK) {
			SCANNER_WARNING(ret);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 104:
#line 931 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_HEX_RDATA);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 105:
#line 941 "zscanner/scanner_body.rl"
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_base64_to_num[(uint8_t)(*p)];
		} else {
			SCANNER_WARNING(ZSCANNER_ERDATA_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 106:
#line 949 "zscanner/scanner_body.rl"
	{
		*(rdata_tail++) += second_left_base64_to_num[(uint8_t)(*p)];

		if (rdata_tail <= rdata_stop) {
			*rdata_tail = second_right_base64_to_num[(uint8_t)(*p)];
		} else {
			SCANNER_WARNING(ZSCANNER_ERDATA_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 107:
#line 959 "zscanner/scanner_body.rl"
	{
		*(rdata_tail++) += third_left_base64_to_num[(uint8_t)(*p)];

		if (rdata_tail <= rdata_stop) {
			*rdata_tail = third_right_base64_to_num[(uint8_t)(*p)];
		} else {
			SCANNER_WARNING(ZSCANNER_ERDATA_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 108:
#line 969 "zscanner/scanner_body.rl"
	{
		*(rdata_tail++) += fourth_base64_to_num[(uint8_t)(*p)];
	}
	break;
	case 109:
#line 973 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_BASE64_CHAR);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 110:
#line 995 "zscanner/scanner_body.rl"
	{ p--; {stack[top++] = cs; cs = 304; goto _again;} }
	break;
	case 111:
#line 999 "zscanner/scanner_body.rl"
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_base32hex_to_num[(uint8_t)(*p)];
		} else {
			SCANNER_WARNING(ZSCANNER_ERDATA_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 112:
#line 1007 "zscanner/scanner_body.rl"
	{
		*(rdata_tail++) += second_left_base32hex_to_num[(uint8_t)(*p)];

		if (rdata_tail <= rdata_stop) {
			*rdata_tail = second_right_base32hex_to_num[(uint8_t)(*p)];
		} else {
			SCANNER_WARNING(ZSCANNER_ERDATA_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 113:
#line 1017 "zscanner/scanner_body.rl"
	{
		*rdata_tail += third_base32hex_to_num[(uint8_t)(*p)];
	}
	break;
	case 114:
#line 1020 "zscanner/scanner_body.rl"
	{
		*(rdata_tail++) += fourth_left_base32hex_to_num[(uint8_t)(*p)];

		if (rdata_tail <= rdata_stop) {
			*rdata_tail = fourth_right_base32hex_to_num[(uint8_t)(*p)];
		} else {
			SCANNER_WARNING(ZSCANNER_ERDATA_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 115:
#line 1030 "zscanner/scanner_body.rl"
	{
		*(rdata_tail++) += fifth_left_base32hex_to_num[(uint8_t)(*p)];

		if (rdata_tail <= rdata_stop) {
			*rdata_tail = fifth_right_base32hex_to_num[(uint8_t)(*p)];
		} else {
			SCANNER_WARNING(ZSCANNER_ERDATA_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 116:
#line 1040 "zscanner/scanner_body.rl"
	{
		*rdata_tail += sixth_base32hex_to_num[(uint8_t)(*p)];
	}
	break;
	case 117:
#line 1043 "zscanner/scanner_body.rl"
	{
		*(rdata_tail++) += seventh_left_base32hex_to_num[(uint8_t)(*p)];

		if (rdata_tail <= rdata_stop) {
			*rdata_tail = seventh_right_base32hex_to_num[(uint8_t)(*p)];
		} else {
			SCANNER_WARNING(ZSCANNER_ERDATA_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 118:
#line 1053 "zscanner/scanner_body.rl"
	{
		*(rdata_tail++) += eighth_base32hex_to_num[(uint8_t)(*p)];
	}
	break;
	case 119:
#line 1057 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_BASE32HEX_CHAR);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 120:
#line 1092 "zscanner/scanner_body.rl"
	{
		*(rdata_tail++) = 0;
	}
	break;
	case 121:
#line 1095 "zscanner/scanner_body.rl"
	{
		*(rdata_tail++) = 1;
	}
	break;
	case 122:
#line 1098 "zscanner/scanner_body.rl"
	{
		*(rdata_tail++) = 2;
	}
	break;
	case 123:
#line 1101 "zscanner/scanner_body.rl"
	{
		*(rdata_tail++) = 3;
	}
	break;
	case 124:
#line 1104 "zscanner/scanner_body.rl"
	{
		*(rdata_tail++) = 5;
	}
	break;
	case 125:
#line 1107 "zscanner/scanner_body.rl"
	{
		*(rdata_tail++) = 6;
	}
	break;
	case 126:
#line 1110 "zscanner/scanner_body.rl"
	{
		*(rdata_tail++) = 7;
	}
	break;
	case 127:
#line 1113 "zscanner/scanner_body.rl"
	{
		*(rdata_tail++) = 8;
	}
	break;
	case 128:
#line 1116 "zscanner/scanner_body.rl"
	{
		*(rdata_tail++) = 10;
	}
	break;
	case 129:
#line 1119 "zscanner/scanner_body.rl"
	{
		*(rdata_tail++) = 12;
	}
	break;
	case 130:
#line 1122 "zscanner/scanner_body.rl"
	{
		*(rdata_tail++) = 13;
	}
	break;
	case 131:
#line 1125 "zscanner/scanner_body.rl"
	{
		*(rdata_tail++) = 14;
	}
	break;
	case 132:
#line 1128 "zscanner/scanner_body.rl"
	{
		*(rdata_tail++) = 252;
	}
	break;
	case 133:
#line 1131 "zscanner/scanner_body.rl"
	{
		*(rdata_tail++) = 253;
	}
	break;
	case 134:
#line 1134 "zscanner/scanner_body.rl"
	{
		*(rdata_tail++) = 254;
	}
	break;
	case 135:
#line 1138 "zscanner/scanner_body.rl"
	{
		*((uint16_t *)rdata_tail) = htons(1);
		rdata_tail += 2;
	}
	break;
	case 136:
#line 1142 "zscanner/scanner_body.rl"
	{
		*((uint16_t *)rdata_tail) = htons(2);
		rdata_tail += 2;
	}
	break;
	case 137:
#line 1146 "zscanner/scanner_body.rl"
	{
		*((uint16_t *)rdata_tail) = htons(3);
		rdata_tail += 2;
	}
	break;
	case 138:
#line 1150 "zscanner/scanner_body.rl"
	{
		*((uint16_t *)rdata_tail) = htons(4);
		rdata_tail += 2;
	}
	break;
	case 139:
#line 1154 "zscanner/scanner_body.rl"
	{
		*((uint16_t *)rdata_tail) = htons(5);
		rdata_tail += 2;
	}
	break;
	case 140:
#line 1158 "zscanner/scanner_body.rl"
	{
		*((uint16_t *)rdata_tail) = htons(6);
		rdata_tail += 2;
	}
	break;
	case 141:
#line 1162 "zscanner/scanner_body.rl"
	{
		*((uint16_t *)rdata_tail) = htons(7);
		rdata_tail += 2;
	}
	break;
	case 142:
#line 1166 "zscanner/scanner_body.rl"
	{
		*((uint16_t *)rdata_tail) = htons(8);
		rdata_tail += 2;
	}
	break;
	case 143:
#line 1170 "zscanner/scanner_body.rl"
	{
		*((uint16_t *)rdata_tail) = htons(253);
		rdata_tail += 2;
	}
	break;
	case 144:
#line 1174 "zscanner/scanner_body.rl"
	{
		*((uint16_t *)rdata_tail) = htons(254);
		rdata_tail += 2;
	}
	break;
	case 145:
#line 1181 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_GATEWAY);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 146:
#line 1185 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_GATEWAY_KEY);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 147:
#line 1203 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EUNSUPPORTED_TYPE);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 148:
#line 1209 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_A, &rdata_tail); }
	break;
	case 149:
#line 1210 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_NS, &rdata_tail); }
	break;
	case 150:
#line 1211 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_CNAME, &rdata_tail); }
	break;
	case 151:
#line 1212 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_SOA, &rdata_tail); }
	break;
	case 152:
#line 1213 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_PTR, &rdata_tail); }
	break;
	case 153:
#line 1214 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_HINFO, &rdata_tail); }
	break;
	case 154:
#line 1215 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_MINFO, &rdata_tail); }
	break;
	case 155:
#line 1216 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_MX, &rdata_tail); }
	break;
	case 156:
#line 1217 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_TXT, &rdata_tail); }
	break;
	case 157:
#line 1218 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_RP, &rdata_tail); }
	break;
	case 158:
#line 1219 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_AFSDB, &rdata_tail); }
	break;
	case 159:
#line 1220 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_RT, &rdata_tail); }
	break;
	case 160:
#line 1221 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_KEY, &rdata_tail); }
	break;
	case 161:
#line 1222 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_AAAA, &rdata_tail); }
	break;
	case 162:
#line 1223 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_LOC, &rdata_tail); }
	break;
	case 163:
#line 1224 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_SRV, &rdata_tail); }
	break;
	case 164:
#line 1225 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_NAPTR, &rdata_tail); }
	break;
	case 165:
#line 1226 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_KX, &rdata_tail); }
	break;
	case 166:
#line 1227 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_CERT, &rdata_tail); }
	break;
	case 167:
#line 1228 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_DNAME, &rdata_tail); }
	break;
	case 168:
#line 1229 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_APL, &rdata_tail); }
	break;
	case 169:
#line 1230 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_DS, &rdata_tail); }
	break;
	case 170:
#line 1231 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_SSHFP, &rdata_tail); }
	break;
	case 171:
#line 1232 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_IPSECKEY, &rdata_tail); }
	break;
	case 172:
#line 1233 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_RRSIG, &rdata_tail); }
	break;
	case 173:
#line 1234 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_NSEC, &rdata_tail); }
	break;
	case 174:
#line 1235 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_DNSKEY, &rdata_tail); }
	break;
	case 175:
#line 1236 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_DHCID, &rdata_tail); }
	break;
	case 176:
#line 1237 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_NSEC3, &rdata_tail); }
	break;
	case 177:
#line 1238 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_NSEC3PARAM, &rdata_tail); }
	break;
	case 178:
#line 1239 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_TLSA, &rdata_tail); }
	break;
	case 179:
#line 1240 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_SPF, &rdata_tail); }
	break;
	case 180:
#line 1241 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_EUI48, &rdata_tail); }
	break;
	case 181:
#line 1242 "zscanner/scanner_body.rl"
	{ type_num(KNOT_RRTYPE_EUI64, &rdata_tail); }
	break;
	case 182:
#line 1248 "zscanner/scanner_body.rl"
	{
		if (s->number64 <= UINT16_MAX) {
			window_add_bit(s->number64, s);
		} else {
			SCANNER_WARNING(ZSCANNER_ENUMBER16_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 183:
#line 1261 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_A, s); }
	break;
	case 184:
#line 1262 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_NS, s); }
	break;
	case 185:
#line 1263 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_CNAME, s); }
	break;
	case 186:
#line 1264 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_SOA, s); }
	break;
	case 187:
#line 1265 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_PTR, s); }
	break;
	case 188:
#line 1266 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_HINFO, s); }
	break;
	case 189:
#line 1267 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_MINFO, s); }
	break;
	case 190:
#line 1268 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_MX, s); }
	break;
	case 191:
#line 1269 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_TXT, s); }
	break;
	case 192:
#line 1270 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_RP, s); }
	break;
	case 193:
#line 1271 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_AFSDB, s); }
	break;
	case 194:
#line 1272 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_RT, s); }
	break;
	case 195:
#line 1273 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_KEY, s); }
	break;
	case 196:
#line 1274 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_AAAA, s); }
	break;
	case 197:
#line 1275 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_LOC, s); }
	break;
	case 198:
#line 1276 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_SRV, s); }
	break;
	case 199:
#line 1277 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_NAPTR, s); }
	break;
	case 200:
#line 1278 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_KX, s); }
	break;
	case 201:
#line 1279 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_CERT, s); }
	break;
	case 202:
#line 1280 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_DNAME, s); }
	break;
	case 203:
#line 1281 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_APL, s); }
	break;
	case 204:
#line 1282 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_DS, s); }
	break;
	case 205:
#line 1283 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_SSHFP, s); }
	break;
	case 206:
#line 1284 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_IPSECKEY, s); }
	break;
	case 207:
#line 1285 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_RRSIG, s); }
	break;
	case 208:
#line 1286 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_NSEC, s); }
	break;
	case 209:
#line 1287 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_DNSKEY, s); }
	break;
	case 210:
#line 1288 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_DHCID, s); }
	break;
	case 211:
#line 1289 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_NSEC3, s); }
	break;
	case 212:
#line 1290 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_NSEC3PARAM, s); }
	break;
	case 213:
#line 1291 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_TLSA, s); }
	break;
	case 214:
#line 1292 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_SPF, s); }
	break;
	case 215:
#line 1293 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_EUI48, s); }
	break;
	case 216:
#line 1294 "zscanner/scanner_body.rl"
	{ window_add_bit(KNOT_RRTYPE_EUI64, s); }
	break;
	case 217:
#line 1298 "zscanner/scanner_body.rl"
	{
		memset(s->windows, 0, sizeof(s->windows));
		s->last_window = -1;
	}
	break;
	case 218:
#line 1302 "zscanner/scanner_body.rl"
	{
		for (window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					SCANNER_WARNING(ZSCANNER_ERDATA_OVERFLOW);
					p--; {cs = 240; goto _again;}
				}
			}
		}
	}
	break;
	case 219:
#line 1325 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_BITMAP);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 220:
#line 1333 "zscanner/scanner_body.rl"
	{ p--; {stack[top++] = cs; cs = 311; goto _again;} }
	break;
	case 221:
#line 1337 "zscanner/scanner_body.rl"
	{
		if (s->number64 <= 90) {
			s->loc.d1 = (uint32_t)(s->number64);
		} else {
			SCANNER_WARNING(ZSCANNER_EBAD_NUMBER);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 222:
#line 1345 "zscanner/scanner_body.rl"
	{
		if (s->number64 <= 180) {
			s->loc.d2 = (uint32_t)(s->number64);
		} else {
			SCANNER_WARNING(ZSCANNER_EBAD_NUMBER);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 223:
#line 1353 "zscanner/scanner_body.rl"
	{
		if (s->number64 <= 59) {
			s->loc.m1 = (uint32_t)(s->number64);
		} else {
			SCANNER_WARNING(ZSCANNER_EBAD_NUMBER);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 224:
#line 1361 "zscanner/scanner_body.rl"
	{
		if (s->number64 <= 59) {
			s->loc.m2 = (uint32_t)(s->number64);
		} else {
			SCANNER_WARNING(ZSCANNER_EBAD_NUMBER);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 225:
#line 1369 "zscanner/scanner_body.rl"
	{
		if (s->number64 <= 59999) {
			s->loc.s1 = (uint32_t)(s->number64);
		} else {
			SCANNER_WARNING(ZSCANNER_EBAD_NUMBER);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 226:
#line 1377 "zscanner/scanner_body.rl"
	{
		if (s->number64 <= 59999) {
			s->loc.s2 = (uint32_t)(s->number64);
		} else {
			SCANNER_WARNING(ZSCANNER_EBAD_NUMBER);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 227:
#line 1385 "zscanner/scanner_body.rl"
	{
		if ((s->loc.alt_sign ==  1 && s->number64 <= 4284967295) ||
		    (s->loc.alt_sign == -1 && s->number64 <=   10000000))
		{
			s->loc.alt = (uint32_t)(s->number64);
		} else {
			SCANNER_WARNING(ZSCANNER_EBAD_NUMBER);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 228:
#line 1395 "zscanner/scanner_body.rl"
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.siz = s->number64;
		} else {
			SCANNER_WARNING(ZSCANNER_EBAD_NUMBER);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 229:
#line 1403 "zscanner/scanner_body.rl"
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.hp = s->number64;
		} else {
			SCANNER_WARNING(ZSCANNER_EBAD_NUMBER);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 230:
#line 1411 "zscanner/scanner_body.rl"
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.vp = s->number64;
		} else {
			SCANNER_WARNING(ZSCANNER_EBAD_NUMBER);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 231:
#line 1419 "zscanner/scanner_body.rl"
	{
		s->loc.lat_sign = -1;
	}
	break;
	case 232:
#line 1422 "zscanner/scanner_body.rl"
	{
		s->loc.long_sign = -1;
	}
	break;
	case 233:
#line 1425 "zscanner/scanner_body.rl"
	{
		s->loc.alt_sign = -1;
	}
	break;
	case 234:
#line 1442 "zscanner/scanner_body.rl"
	{
		memset(&(s->loc), 0, sizeof(s->loc));
		// Defaults.
		s->loc.siz = 100;
		s->loc.vp  = 1000;
		s->loc.hp  = 1000000;
		s->loc.lat_sign  = 1;
		s->loc.long_sign = 1;
		s->loc.alt_sign  = 1;
	}
	break;
	case 235:
#line 1452 "zscanner/scanner_body.rl"
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	break;
	case 236:
#line 1478 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_LOC_DATA);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 237:
#line 1491 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_HEX_RDATA);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 238:
#line 1509 "zscanner/scanner_body.rl"
	{
		s->item_length = 0;
	}
	break;
	case 239:
#line 1512 "zscanner/scanner_body.rl"
	{
		s->item_length++;
	}
	break;
	case 240:
#line 1515 "zscanner/scanner_body.rl"
	{
		if (s->item_length != 6) {
			SCANNER_WARNING(ZSCANNER_EBAD_EUI_LENGTH);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 241:
#line 1521 "zscanner/scanner_body.rl"
	{
		if (s->item_length != 8) {
			SCANNER_WARNING(ZSCANNER_EBAD_EUI_LENGTH);
			p--; {cs = 240; goto _again;}
		}
	}
	break;
	case 242:
#line 1536 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_ALGORITHM);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 243:
#line 1540 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_CERT_TYPE);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 244:
#line 1562 "zscanner/scanner_body.rl"
	{ p--; {stack[top++] = cs; cs = 443; goto _again;} }
	break;
	case 245:
#line 1577 "zscanner/scanner_body.rl"
	{ p--; {stack[top++] = cs; cs = 538; goto _again;} }
	break;
	case 246:
#line 1581 "zscanner/scanner_body.rl"
	{
		s->r_data_blocks[0] = 0;
		s->r_data_blocks_count = 0;
		rdata_tail = s->r_data;
	}
	break;
	case 247:
#line 1586 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_RDATA);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 248:
#line 1696 "zscanner/scanner_body.rl"
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = cs; cs = 579; goto _again;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = cs; cs = 581; goto _again;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = cs; cs = 583; goto _again;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = cs; cs = 615; goto _again;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = cs; cs = 620; goto _again;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
			{stack[top++] = cs; cs = 625; goto _again;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
			{stack[top++] = cs; cs = 630; goto _again;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = cs; cs = 634; goto _again;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = cs; cs = 636; goto _again;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = cs; cs = 691; goto _again;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = cs; cs = 702; goto _again;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = cs; cs = 719; goto _again;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = cs; cs = 730; goto _again;}
		case KNOT_RRTYPE_DS:
			{stack[top++] = cs; cs = 741; goto _again;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = cs; cs = 754; goto _again;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = cs; cs = 764; goto _again;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = cs; cs = 803; goto _again;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = cs; cs = 938; goto _again;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
			{stack[top++] = cs; cs = 941; goto _again;}
		case KNOT_RRTYPE_DHCID:
			{stack[top++] = cs; cs = 952; goto _again;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = cs; cs = 954; goto _again;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = cs; cs = 983; goto _again;}
		case KNOT_RRTYPE_TLSA:
			{stack[top++] = cs; cs = 996; goto _again;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = cs; cs = 1009; goto _again;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = cs; cs = 1015; goto _again;}
		default:
			SCANNER_WARNING(ZSCANNER_ECANNOT_TEXT_DATA);
			{cs = 240; goto _again;}
		}
	}
	break;
	case 249:
#line 1763 "zscanner/scanner_body.rl"
	{
		switch (s->r_type) {
		// Next types must not have empty rdata.
		case KNOT_RRTYPE_A:
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
		case KNOT_RRTYPE_SOA:
		case KNOT_RRTYPE_HINFO:
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_RP:
		case KNOT_RRTYPE_AAAA:
		case KNOT_RRTYPE_LOC:
		case KNOT_RRTYPE_SRV:
		case KNOT_RRTYPE_NAPTR:
		case KNOT_RRTYPE_CERT:
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_SSHFP:
		case KNOT_RRTYPE_IPSECKEY:
		case KNOT_RRTYPE_RRSIG:
		case KNOT_RRTYPE_NSEC:
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_NSEC3:
		case KNOT_RRTYPE_NSEC3PARAM:
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_EUI48:
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = cs; cs = 424; goto _again;}
		// Next types can have empty rdata.
		case KNOT_RRTYPE_APL:
		default:
			{stack[top++] = cs; cs = 433; goto _again;}
		}
	}
	break;
	case 250:
#line 1807 "zscanner/scanner_body.rl"
	{
		s->r_data_blocks[++(s->r_data_blocks_count)] =
			(uint16_t)(rdata_tail - s->r_data);
	}
	break;
	case 251:
#line 1815 "zscanner/scanner_body.rl"
	{ p--; }
	break;
	case 252:
#line 1822 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EUNSUPPORTED_TYPE);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 253:
#line 1828 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_A; }
	break;
	case 254:
#line 1829 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_NS; }
	break;
	case 255:
#line 1830 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_CNAME; }
	break;
	case 256:
#line 1831 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_SOA; }
	break;
	case 257:
#line 1832 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_PTR; }
	break;
	case 258:
#line 1833 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_HINFO; }
	break;
	case 259:
#line 1834 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_MINFO; }
	break;
	case 260:
#line 1835 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_MX; }
	break;
	case 261:
#line 1836 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_TXT; }
	break;
	case 262:
#line 1837 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_RP; }
	break;
	case 263:
#line 1838 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_AFSDB; }
	break;
	case 264:
#line 1839 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_RT; }
	break;
	case 265:
#line 1840 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_KEY; }
	break;
	case 266:
#line 1841 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_AAAA; }
	break;
	case 267:
#line 1842 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_LOC; }
	break;
	case 268:
#line 1843 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_SRV; }
	break;
	case 269:
#line 1844 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_NAPTR; }
	break;
	case 270:
#line 1845 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_KX; }
	break;
	case 271:
#line 1846 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_CERT; }
	break;
	case 272:
#line 1847 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_DNAME; }
	break;
	case 273:
#line 1848 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_APL; }
	break;
	case 274:
#line 1849 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_DS; }
	break;
	case 275:
#line 1850 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_SSHFP; }
	break;
	case 276:
#line 1851 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_IPSECKEY; }
	break;
	case 277:
#line 1852 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_RRSIG; }
	break;
	case 278:
#line 1853 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_NSEC; }
	break;
	case 279:
#line 1854 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_DNSKEY; }
	break;
	case 280:
#line 1855 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_DHCID; }
	break;
	case 281:
#line 1856 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_NSEC3; }
	break;
	case 282:
#line 1857 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_NSEC3PARAM; }
	break;
	case 283:
#line 1858 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_TLSA; }
	break;
	case 284:
#line 1859 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_SPF; }
	break;
	case 285:
#line 1860 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_EUI48; }
	break;
	case 286:
#line 1861 "zscanner/scanner_body.rl"
	{ s->r_type = KNOT_RRTYPE_EUI64; }
	break;
	case 287:
#line 1867 "zscanner/scanner_body.rl"
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			SCANNER_WARNING(ZSCANNER_ERDATA_OVERFLOW);
			p--; {cs = 240; goto _again;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->process_record(s);
	}
	break;
#line 7215 "zscanner/scanner.c"
		}
	}

_again:
	if ( cs == 0 )
		goto _out;
	if ( ++p != pe )
		goto _resume;
	_test_eof: {}
	if ( p == eof )
	{
	const short *__acts = _zone_scanner_actions + _zone_scanner_eof_actions[cs];
	unsigned int __nacts = (unsigned int) *__acts++;
	while ( __nacts-- > 0 ) {
		switch ( *__acts++ ) {
	case 4:
#line 44 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_REST);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 15:
#line 143 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_NUMBER);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 20:
#line 189 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_DNAME_CHAR);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 28:
#line 242 "zscanner/scanner_body.rl"
	{
		s->r_owner_length = 0;
		SCANNER_WARNING(ZSCANNER_EBAD_OWNER);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 33:
#line 285 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_NUMBER);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 45:
#line 386 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_TIME_UNIT);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 55:
#line 491 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_TIMESTAMP_CHAR);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 57:
#line 509 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_TEXT_CHAR);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 58:
#line 513 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_TEXT);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 62:
#line 543 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_NUMBER);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 65:
#line 583 "zscanner/scanner_body.rl"
	{
		SCANNER_ERROR(ZSCANNER_EBAD_TTL);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 69:
#line 600 "zscanner/scanner_body.rl"
	{
		SCANNER_ERROR(ZSCANNER_EBAD_ORIGIN);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 73:
#line 628 "zscanner/scanner_body.rl"
	{
		SCANNER_ERROR(ZSCANNER_EBAD_INCLUDE_FILENAME);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 76:
#line 639 "zscanner/scanner_body.rl"
	{
		SCANNER_ERROR(ZSCANNER_EBAD_INCLUDE_ORIGIN);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 80:
#line 720 "zscanner/scanner_body.rl"
	{
		s->stop = false;
	}
	break;
	case 81:
#line 723 "zscanner/scanner_body.rl"
	{
		SCANNER_ERROR(ZSCANNER_EBAD_DIRECTIVE);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 88:
#line 774 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_ADDRESS_CHAR);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 99:
#line 874 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_APL);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 102:
#line 904 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_HEX_CHAR);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 104:
#line 931 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_HEX_RDATA);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 109:
#line 973 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_BASE64_CHAR);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 119:
#line 1057 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_BASE32HEX_CHAR);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 145:
#line 1181 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_GATEWAY);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 146:
#line 1185 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_GATEWAY_KEY);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 147:
#line 1203 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EUNSUPPORTED_TYPE);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 219:
#line 1325 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_BITMAP);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 236:
#line 1478 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_LOC_DATA);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 237:
#line 1491 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_HEX_RDATA);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 242:
#line 1536 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_ALGORITHM);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 243:
#line 1540 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_CERT_TYPE);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 247:
#line 1586 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EBAD_RDATA);
		p--; {cs = 240; goto _again;}
	}
	break;
	case 252:
#line 1822 "zscanner/scanner_body.rl"
	{
		SCANNER_WARNING(ZSCANNER_EUNSUPPORTED_TYPE);
		p--; {cs = 240; goto _again;}
	}
	break;
#line 7455 "zscanner/scanner.c"
		}
	}
	}

	_out: {}
	}

#line 144 "zscanner/scanner.rl"

	// Check if scanner state machine is in uncovered state.
	if (cs == zone_scanner_error) {
		SCANNER_ERROR(ZSCANNER_UNCOVERED_STATE);
		s->error_counter++;

		// Fill error context data.
		for (s->buffer_length = 0;
		     ((p + s->buffer_length) < pe) &&
		     (s->buffer_length < sizeof(s->buffer) - 1);
		     s->buffer_length++)
		{
			// Only rest of the current line.
			if (*(p + s->buffer_length) == '\n') {
				break;
			}
			s->buffer[s->buffer_length] = *(p + s->buffer_length);
		}

		// Ending string in buffer.
		s->buffer[s->buffer_length++] = 0;

		// Processing error.
		s->process_error(s);

		return -1;
	}

	// Storing scanner states.
	s->cs  = cs;
	s->top = top;
	memcpy(s->stack, stack, sizeof(stack));

	// Storing r_data pointer.
	s->r_data_tail = rdata_tail - s->r_data;

	// Check if any errors has occured.
	if (s->error_counter > 0) {
		return -1;
	}

	return 0;
}

